declare const _default: {
    "batchPath": string;
    "revision": string;
    "documentationLink": string;
    "id": string;
    "title": string;
    "discoveryVersion": string;
    "ownerName": string;
    "version_module": boolean;
    "resources": {
        "statements": {
            "methods": {
                "list": {
                    "description": string;
                    "httpMethod": string;
                    "parameterOrder": never[];
                    "response": {
                        "$ref": string;
                    };
                    "parameters": {
                        "source.androidApp.certificate.sha256Fingerprint": {
                            "description": string;
                            "type": string;
                            "location": string;
                        };
                        "relation": {
                            "location": string;
                            "description": string;
                            "type": string;
                        };
                        "source.web.site": {
                            "location": string;
                            "description": string;
                            "type": string;
                        };
                        "source.androidApp.packageName": {
                            "location": string;
                            "description": string;
                            "type": string;
                        };
                    };
                    "flatPath": string;
                    "id": string;
                    "path": string;
                };
            };
        };
        "assetlinks": {
            "methods": {
                "check": {
                    "flatPath": string;
                    "path": string;
                    "id": string;
                    "description": string;
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": never[];
                    "httpMethod": string;
                    "parameters": {
                        "target.androidApp.packageName": {
                            "location": string;
                            "description": string;
                            "type": string;
                        };
                        "source.androidApp.certificate.sha256Fingerprint": {
                            "description": string;
                            "type": string;
                            "location": string;
                        };
                        "relation": {
                            "location": string;
                            "description": string;
                            "type": string;
                        };
                        "target.web.site": {
                            "description": string;
                            "type": string;
                            "location": string;
                        };
                        "target.androidApp.certificate.sha256Fingerprint": {
                            "description": string;
                            "type": string;
                            "location": string;
                        };
                        "source.androidApp.packageName": {
                            "description": string;
                            "type": string;
                            "location": string;
                        };
                        "source.web.site": {
                            "description": string;
                            "type": string;
                            "location": string;
                        };
                    };
                };
            };
        };
    };
    "parameters": {
        "fields": {
            "description": string;
            "type": string;
            "location": string;
        };
        "uploadType": {
            "location": string;
            "description": string;
            "type": string;
        };
        "callback": {
            "location": string;
            "description": string;
            "type": string;
        };
        "oauth_token": {
            "description": string;
            "type": string;
            "location": string;
        };
        "$.xgafv": {
            "enumDescriptions": string[];
            "location": string;
            "enum": string[];
            "description": string;
            "type": string;
        };
        "alt": {
            "enum": string[];
            "type": string;
            "enumDescriptions": string[];
            "location": string;
            "description": string;
            "default": string;
        };
        "access_token": {
            "description": string;
            "type": string;
            "location": string;
        };
        "key": {
            "description": string;
            "type": string;
            "location": string;
        };
        "upload_protocol": {
            "location": string;
            "description": string;
            "type": string;
        };
        "prettyPrint": {
            "location": string;
            "description": string;
            "type": string;
            "default": string;
        };
        "quotaUser": {
            "location": string;
            "description": string;
            "type": string;
        };
    };
    "schemas": {
        "Asset": {
            "description": string;
            "type": string;
            "properties": {
                "web": {
                    "$ref": string;
                    "description": string;
                };
                "androidApp": {
                    "$ref": string;
                    "description": string;
                };
            };
            "id": string;
        };
        "CheckResponse": {
            "description": string;
            "type": string;
            "properties": {
                "linked": {
                    "description": string;
                    "type": string;
                };
                "debugString": {
                    "description": string;
                    "type": string;
                };
                "maxAge": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "errorCode": {
                    "enumDescriptions": string[];
                    "description": string;
                    "type": string;
                    "items": {
                        "enum": string[];
                        "type": string;
                    };
                };
            };
            "id": string;
        };
        "WebAsset": {
            "properties": {
                "site": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
            "description": string;
            "type": string;
        };
        "ListResponse": {
            "properties": {
                "errorCode": {
                    "enumDescriptions": string[];
                    "description": string;
                    "type": string;
                    "items": {
                        "type": string;
                        "enum": string[];
                    };
                };
                "statements": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "debugString": {
                    "description": string;
                    "type": string;
                };
                "maxAge": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
            };
            "id": string;
            "description": string;
            "type": string;
        };
        "Statement": {
            "description": string;
            "type": string;
            "properties": {
                "target": {
                    "description": string;
                    "$ref": string;
                };
                "source": {
                    "description": string;
                    "$ref": string;
                };
                "relation": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "CertificateInfo": {
            "description": string;
            "type": string;
            "properties": {
                "sha256Fingerprint": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "AndroidAppAsset": {
            "description": string;
            "type": string;
            "properties": {
                "certificate": {
                    "description": string;
                    "$ref": string;
                };
                "packageName": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
    };
    "icons": {
        "x32": string;
        "x16": string;
    };
    "protocol": string;
    "version": string;
    "baseUrl": string;
    "kind": string;
    "description": string;
    "servicePath": string;
    "rootUrl": string;
    "basePath": string;
    "ownerDomain": string;
    "name": string;
};
export default _default;
//# sourceMappingURL=digitalassetlinks-v1.d.ts.map