"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "kind": "discovery#restDescription", "description": "Transfers data from partner SaaS applications to Google BigQuery on a scheduled, managed basis.", "servicePath": "", "basePath": "", "revision": "20181207", "documentationLink": "https://cloud.google.com/bigquery/", "id": "bigquerydatatransfer:v1", "discoveryVersion": "v1", "version_module": true, "schemas": { "Status": { "description": "The `Status` type defines a logical error model that is suitable for different\nprogramming environments, including REST APIs and RPC APIs. It is used by\n[gRPC](https://github.com/grpc). The error model is designed to be:\n\n- Simple to use and understand for most users\n- Flexible enough to meet unexpected needs\n\n# Overview\n\nThe `Status` message contains three pieces of data: error code, error message,\nand error details. The error code should be an enum value of\ngoogle.rpc.Code, but it may accept additional error codes if needed.  The\nerror message should be a developer-facing English message that helps\ndevelopers *understand* and *resolve* the error. If a localized user-facing\nerror message is needed, put the localized message in the error details or\nlocalize it in the client. The optional error details may contain arbitrary\ninformation about the error. There is a predefined set of error detail types\nin the package `google.rpc` that can be used for common error conditions.\n\n# Language mapping\n\nThe `Status` message is the logical representation of the error model, but it\nis not necessarily the actual wire format. When the `Status` message is\nexposed in different client libraries and different wire protocols, it can be\nmapped differently. For example, it will likely be mapped to some exceptions\nin Java, but more likely mapped to some error codes in C.\n\n# Other uses\n\nThe error model and the `Status` message can be used in a variety of\nenvironments, either with or without APIs, to provide a\nconsistent developer experience across different environments.\n\nExample uses of this error model include:\n\n- Partial errors. If a service needs to return partial errors to the client,\n    it may embed the `Status` in the normal response to indicate the partial\n    errors.\n\n- Workflow errors. A typical workflow has multiple steps. Each step may\n    have a `Status` message for error reporting.\n\n- Batch operations. If a client uses batch request and batch response, the\n    `Status` message should be used directly inside batch response, one for\n    each error sub-response.\n\n- Asynchronous operations. If an API call embeds asynchronous operation\n    results in its response, the status of those operations should be\n    represented directly using the `Status` message.\n\n- Logging. If some API errors are stored in logs, the message `Status` could\n    be used directly after any stripping needed for security/privacy reasons.", "type": "object", "properties": { "message": { "description": "A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.", "type": "string" }, "details": { "description": "A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.", "type": "array", "items": { "type": "object", "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." } } }, "code": { "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32", "type": "integer" } }, "id": "Status" }, "ScheduleTransferRunsRequest": { "description": "A request to schedule transfer runs for a time range.", "type": "object", "properties": { "endTime": { "description": "End time of the range of transfer runs. For example,\n`\"2017-05-30T00:00:00+00:00\"`.", "format": "google-datetime", "type": "string" }, "startTime": { "type": "string", "description": "Start time of the range of transfer runs. For example,\n`\"2017-05-25T00:00:00+00:00\"`.", "format": "google-datetime" } }, "id": "ScheduleTransferRunsRequest" }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "Empty" }, "Location": { "description": "A resource that represents Google Cloud Platform location.", "type": "object", "properties": { "name": { "description": "Resource name for the location, which may vary between implementations.\nFor example: `\"projects/example-project/locations/us-east1\"`", "type": "string" }, "locationId": { "type": "string", "description": "The canonical id for this location. For example: `\"us-east1\"`." }, "displayName": { "description": "The friendly name for this location, typically a nearby city name.\nFor example, \"Tokyo\".", "type": "string" }, "metadata": { "description": "Service-specific metadata. For example the available capacity at the given\nlocation.", "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" } }, "labels": { "type": "object", "additionalProperties": { "type": "string" }, "description": "Cross-service attributes for the location. For example\n\n    {\"cloud.googleapis.com/region\": \"us-east1\"}" } }, "id": "Location" }, "TransferConfig": { "description": "Represents a data transfer configuration. A transfer configuration\ncontains all metadata needed to perform a data transfer. For example,\n`destination_dataset_id` specifies where data should be stored.\nWhen a new transfer configuration is created, the specified\n`destination_dataset_id` is created when needed and shared with the\nappropriate data source service account.", "type": "object", "properties": { "datasetRegion": { "description": "Output only. Region in which BigQuery dataset is located.", "type": "string" }, "displayName": { "description": "User specified display name for the data transfer.", "type": "string" }, "disabled": { "description": "Is this config disabled. When set to true, no runs are scheduled\nfor a given transfer.", "type": "boolean" }, "nextRunTime": { "description": "Output only. Next time when data transfer will run.", "format": "google-datetime", "type": "string" }, "updateTime": { "type": "string", "description": "Output only. Data transfer modification time. Ignored by server on input.", "format": "google-datetime" }, "schedule": { "description": "Data transfer schedule.\nIf the data source does not support a custom schedule, this should be\nempty. If it is empty, the default value for the data source will be\nused.\nThe specified times are in UTC.\nExamples of valid format:\n`1st,3rd monday of month 15:30`,\n`every wed,fri of jan,jun 13:15`, and\n`first sunday of quarter 00:00`.\nSee more explanation about the format here:\nhttps://cloud.google.com/appengine/docs/flexible/python/scheduling-jobs-with-cron-yaml#the_schedule_format\nNOTE: the granularity should be at least 8 hours, or less frequent.", "type": "string" }, "dataRefreshWindowDays": { "type": "integer", "description": "The number of days to look back to automatically refresh the data.\nFor example, if `data_refresh_window_days = 10`, then every day\nBigQuery reingests data for [today-10, today-1], rather than ingesting data\nfor just [today-1].\nOnly valid if the data source supports the feature. Set the value to  0\nto use the default value.", "format": "int32" }, "dataSourceId": { "description": "Data source id. Cannot be changed once data transfer is created.", "type": "string" }, "state": { "enumDescriptions": ["State placeholder.", "Data transfer is scheduled and is waiting to be picked up by\ndata transfer backend.", "Data transfer is in progress.", "Data transfer completed successfully.", "Data transfer failed.", "Data transfer is cancelled."], "enum": ["TRANSFER_STATE_UNSPECIFIED", "PENDING", "RUNNING", "SUCCEEDED", "FAILED", "CANCELLED"], "description": "Output only. State of the most recently updated transfer run.", "type": "string" }, "destinationDatasetId": { "description": "The BigQuery target dataset id.", "type": "string" }, "userId": { "description": "Output only. Unique ID of the user on whose behalf transfer is done.\nApplicable only to data sources that do not support service accounts.\nWhen set to 0, the data source service account credentials are used.\nMay be negative. Note, that this identifier is not stable.\nIt may change over time even for the same user.", "format": "int64", "type": "string" }, "name": { "description": "The resource name of the transfer config.\nTransfer config names have the form of\n`projects/{project_id}/location/{region}/transferConfigs/{config_id}`.\nThe name is automatically generated based on the config_id specified in\nCreateTransferConfigRequest along with project_id and region. If config_id\nis not provided, usually a uuid, even though it is not guaranteed or\nrequired, will be generated for config_id.", "type": "string" }, "params": { "description": "Data transfer specific parameters.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } } }, "id": "TransferConfig" }, "TransferRun": { "properties": { "scheduleTime": { "description": "Minimum time after which a transfer run can be started.", "format": "google-datetime", "type": "string" }, "errorStatus": { "$ref": "Status", "description": "Status of the transfer run." }, "schedule": { "description": "Output only. Describes the schedule of this transfer run if it was\ncreated as part of a regular schedule. For batch transfer runs that are\nscheduled manually, this is empty.\nNOTE: the system might choose to delay the schedule depending on the\ncurrent load, so `schedule_time` doesn't always match this.", "type": "string" }, "updateTime": { "description": "Output only. Last time the data transfer run state was updated.", "format": "google-datetime", "type": "string" }, "runTime": { "description": "For batch transfer runs, specifies the date and time that\ndata should be ingested.", "format": "google-datetime", "type": "string" }, "dataSourceId": { "description": "Output only. Data source id.", "type": "string" }, "state": { "description": "Data transfer run state. Ignored for input requests.", "type": "string", "enumDescriptions": ["State placeholder.", "Data transfer is scheduled and is waiting to be picked up by\ndata transfer backend.", "Data transfer is in progress.", "Data transfer completed successfully.", "Data transfer failed.", "Data transfer is cancelled."], "enum": ["TRANSFER_STATE_UNSPECIFIED", "PENDING", "RUNNING", "SUCCEEDED", "FAILED", "CANCELLED"] }, "destinationDatasetId": { "description": "Output only. The BigQuery target dataset id.", "type": "string" }, "name": { "description": "The resource name of the transfer run.\nTransfer run names have the form\n`projects/{project_id}/locations/{location}/transferConfigs/{config_id}/runs/{run_id}`.\nThe name is ignored when creating a transfer run.", "type": "string" }, "userId": { "description": "Output only. Unique ID of the user on whose behalf transfer is done.\nApplicable only to data sources that do not support service accounts.\nWhen set to 0, the data source service account credentials are used.\nMay be negative. Note, that this identifier is not stable.\nIt may change over time even for the same user.", "format": "int64", "type": "string" }, "params": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Output only. Data transfer specific parameters.", "type": "object" }, "endTime": { "description": "Output only. Time when transfer run ended.\nParameter ignored by server for input requests.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "Output only. Time when transfer run was started.\nParameter ignored by server for input requests.", "format": "google-datetime", "type": "string" } }, "id": "TransferRun", "description": "Represents a data transfer run.", "type": "object" }, "CheckValidCredsRequest": { "description": "A request to determine whether the user has valid credentials. This method\nis used to limit the number of OAuth popups in the user interface. The\nuser id is inferred from the API call context.\nIf the data source has the Google+ authorization type, this method\nreturns false, as it cannot be determined whether the credentials are\nalready valid merely based on the user id.", "type": "object", "properties": {}, "id": "CheckValidCredsRequest" }, "CheckValidCredsResponse": { "description": "A response indicating whether the credentials exist and are valid.", "type": "object", "properties": { "hasValidCreds": { "description": "If set to `true`, the credentials exist and are valid.", "type": "boolean" } }, "id": "CheckValidCredsResponse" }, "ScheduleTransferRunsResponse": { "description": "A response to schedule transfer runs for a time range.", "type": "object", "properties": { "runs": { "description": "The transfer runs that were scheduled.", "type": "array", "items": { "$ref": "TransferRun" } } }, "id": "ScheduleTransferRunsResponse" }, "TransferMessage": { "description": "Represents a user facing message for a particular data transfer run.", "type": "object", "properties": { "messageTime": { "description": "Time when message was logged.", "format": "google-datetime", "type": "string" }, "severity": { "enumDescriptions": ["No severity specified.", "Informational message.", "Warning message.", "Error message."], "enum": ["MESSAGE_SEVERITY_UNSPECIFIED", "INFO", "WARNING", "ERROR"], "description": "Message severity.", "type": "string" }, "messageText": { "description": "Message text.", "type": "string" } }, "id": "TransferMessage" }, "ListTransferLogsResponse": { "id": "ListTransferLogsResponse", "description": "The returned list transfer run messages.", "type": "object", "properties": { "transferMessages": { "description": "Output only. The stored pipeline transfer messages.", "type": "array", "items": { "$ref": "TransferMessage" } }, "nextPageToken": { "description": "Output only. The next-pagination token. For multiple-page list results,\nthis token can be used as the\n`GetTransferRunLogRequest.page_token`\nto request the next page of list results.", "type": "string" } } }, "ListDataSourcesResponse": { "type": "object", "properties": { "nextPageToken": { "description": "Output only. The next-pagination token. For multiple-page list results,\nthis token can be used as the\n`ListDataSourcesRequest.page_token`\nto request the next page of list results.", "type": "string" }, "dataSources": { "description": "List of supported data sources and their transfer settings.", "type": "array", "items": { "$ref": "DataSource" } } }, "id": "ListDataSourcesResponse", "description": "Returns list of supported data sources and their metadata." }, "DataSourceParameter": { "properties": { "description": { "description": "Parameter description.", "type": "string" }, "allowedValues": { "description": "All possible values for the parameter.", "type": "array", "items": { "type": "string" } }, "validationHelpUrl": { "description": "URL to a help document to further explain the naming requirements.", "type": "string" }, "minValue": { "description": "For integer and double values specifies minimum allowed value.", "format": "double", "type": "number" }, "validationRegex": { "description": "Regular expression which can be used for parameter validation.", "type": "string" }, "paramId": { "description": "Parameter identifier.", "type": "string" }, "required": { "description": "Is parameter required.", "type": "boolean" }, "repeated": { "description": "Deprecated. This field has no effect.", "type": "boolean" }, "displayName": { "type": "string", "description": "Parameter display name in the user interface." }, "validationDescription": { "description": "Description of the requirements for this field, in case the user input does\nnot fulfill the regex pattern or min/max values.", "type": "string" }, "immutable": { "description": "Cannot be changed after initial creation.", "type": "boolean" }, "fields": { "type": "array", "items": { "$ref": "DataSourceParameter" }, "description": "Deprecated. This field has no effect." }, "maxValue": { "description": "For integer and double values specifies maxminum allowed value.", "format": "double", "type": "number" }, "type": { "type": "string", "enumDescriptions": ["Type unspecified.", "String parameter.", "Integer parameter (64-bits).\nWill be serialized to json as string.", "Double precision floating point parameter.", "Boolean parameter.", "Deprecated. This field has no effect.", "Page ID for a Google+ Page."], "enum": ["TYPE_UNSPECIFIED", "STRING", "INTEGER", "DOUBLE", "BOOLEAN", "RECORD", "PLUS_PAGE"], "description": "Parameter type." }, "recurse": { "description": "Deprecated. This field has no effect.", "type": "boolean" } }, "id": "DataSourceParameter", "description": "Represents a data source parameter with validation rules, so that\nparameters can be rendered in the UI. These parameters are given to us by\nsupported data sources, and include all needed information for rendering\nand validation.\nThus, whoever uses this api can decide to generate either generic ui,\nor custom data source specific forms.", "type": "object" }, "ListTransferRunsResponse": { "description": "The returned list of pipelines in the project.", "type": "object", "properties": { "transferRuns": { "description": "Output only. The stored pipeline transfer runs.", "type": "array", "items": { "$ref": "TransferRun" } }, "nextPageToken": { "description": "Output only. The next-pagination token. For multiple-page list results,\nthis token can be used as the\n`ListTransferRunsRequest.page_token`\nto request the next page of list results.", "type": "string" } }, "id": "ListTransferRunsResponse" }, "ListLocationsResponse": { "id": "ListLocationsResponse", "description": "The response message for Locations.ListLocations.", "type": "object", "properties": { "nextPageToken": { "description": "The standard List next-page token.", "type": "string" }, "locations": { "description": "A list of locations that matches the specified filter in the request.", "type": "array", "items": { "$ref": "Location" } } } }, "ListTransferConfigsResponse": { "properties": { "nextPageToken": { "description": "Output only. The next-pagination token. For multiple-page list results,\nthis token can be used as the\n`ListTransferConfigsRequest.page_token`\nto request the next page of list results.", "type": "string" }, "transferConfigs": { "description": "Output only. The stored pipeline transfer configurations.", "type": "array", "items": { "$ref": "TransferConfig" } } }, "id": "ListTransferConfigsResponse", "description": "The returned list of pipelines in the project.", "type": "object" }, "DataSource": { "description": "Represents data source metadata. Metadata is sufficient to\nrender UI and request proper OAuth tokens.", "type": "object", "properties": { "dataSourceId": { "description": "Data source id.", "type": "string" }, "scopes": { "description": "Api auth scopes for which refresh token needs to be obtained. These are\nscopes needed by a data source to prepare data and ingest them into\nBigQuery, e.g., https://www.googleapis.com/auth/bigquery", "type": "array", "items": { "type": "string" } }, "name": { "type": "string", "description": "Output only. Data source resource name." }, "minimumScheduleInterval": { "description": "The minimum interval for scheduler to schedule runs.", "format": "google-duration", "type": "string" }, "clientId": { "description": "Data source client id which should be used to receive refresh token.", "type": "string" }, "authorizationType": { "description": "Indicates the type of authorization.", "type": "string", "enumDescriptions": ["Type unspecified.", "Use OAuth 2 authorization codes that can be exchanged\nfor a refresh token on the backend.", "Return an authorization code for a given Google+ page that can then be\nexchanged for a refresh token on the backend."], "enum": ["AUTHORIZATION_TYPE_UNSPECIFIED", "AUTHORIZATION_CODE", "GOOGLE_PLUS_AUTHORIZATION_CODE"] }, "supportsCustomSchedule": { "description": "Specifies whether the data source supports a user defined schedule, or\noperates on the default schedule.\nWhen set to `true`, user can override default schedule.", "type": "boolean" }, "displayName": { "type": "string", "description": "User friendly data source name." }, "updateDeadlineSeconds": { "description": "The number of seconds to wait for an update from the data source\nbefore the Data Transfer Service marks the transfer as FAILED.", "format": "int32", "type": "integer" }, "dataRefreshType": { "description": "Specifies whether the data source supports automatic data refresh for the\npast few days, and how it's supported.\nFor some data sources, data might not be complete until a few days later,\nso it's useful to refresh data automatically.", "type": "string", "enumDescriptions": ["The data source won't support data auto refresh, which is default value.", "The data source supports data auto refresh, and runs will be scheduled\nfor the past few days. Does not allow custom values to be set for each\ntransfer config.", "The data source supports data auto refresh, and runs will be scheduled\nfor the past few days. Allows custom values to be set for each transfer\nconfig."], "enum": ["DATA_REFRESH_TYPE_UNSPECIFIED", "SLIDING_WINDOW", "CUSTOM_SLIDING_WINDOW"] }, "parameters": { "description": "Data source parameters.", "type": "array", "items": { "$ref": "DataSourceParameter" } }, "helpUrl": { "description": "Url for the help document for this data source.", "type": "string" }, "defaultSchedule": { "description": "Default data transfer schedule.\nExamples of valid schedules include:\n`1st,3rd monday of month 15:30`,\n`every wed,fri of jan,jun 13:15`, and\n`first sunday of quarter 00:00`.", "type": "string" }, "supportsMultipleTransfers": { "description": "Deprecated. This field has no effect.", "type": "boolean" }, "defaultDataRefreshWindowDays": { "description": "Default data refresh window on days.\nOnly meaningful when `data_refresh_type` = `SLIDING_WINDOW`.", "format": "int32", "type": "integer" }, "manualRunsDisabled": { "description": "Disables backfilling and manual run scheduling\nfor the data source.", "type": "boolean" }, "transferType": { "enum": ["TRANSFER_TYPE_UNSPECIFIED", "BATCH", "STREAMING"], "description": "Deprecated. This field has no effect.", "type": "string", "enumDescriptions": ["Invalid or Unknown transfer type placeholder.", "Batch data transfer.", "Streaming data transfer. Streaming data source currently doesn't\nsupport multiple transfer configs per project."] }, "description": { "description": "User friendly data source description string.", "type": "string" } }, "id": "DataSource" } }, "protocol": "rest", "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "canonicalName": "BigQuery Data Transfer", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform.read-only": { "description": "View your data across Google Cloud Platform services" }, "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" }, "https://www.googleapis.com/auth/bigquery": { "description": "View and manage your data in Google BigQuery" } } } }, "rootUrl": "https://bigquerydatatransfer.googleapis.com/", "ownerDomain": "google.com", "name": "bigquerydatatransfer", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "BigQuery Data Transfer API", "ownerName": "Google", "resources": { "projects": { "resources": { "locations": { "methods": { "list": { "description": "Lists information about the supported locations for this service.", "httpMethod": "GET", "response": { "$ref": "ListLocationsResponse" }, "parameterOrder": ["name"], "parameters": { "pageSize": { "description": "The standard list page size.", "format": "int32", "type": "integer", "location": "query" }, "filter": { "location": "query", "description": "The standard list filter.", "type": "string" }, "name": { "location": "path", "description": "The resource that owns the locations collection, if applicable.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" }, "pageToken": { "description": "The standard list page token.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/locations", "id": "bigquerydatatransfer.projects.locations.list", "path": "v1/{+name}/locations" }, "get": { "description": "Gets information about a location.", "response": { "$ref": "Location" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+$", "location": "path", "description": "Resource name for the location." } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}", "path": "v1/{+name}", "id": "bigquerydatatransfer.projects.locations.get" } }, "resources": { "dataSources": { "methods": { "get": { "response": { "$ref": "DataSource" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/dataSources/[^/]+$", "location": "path", "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/dataSources/{data_source_id}`" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/dataSources/{dataSourcesId}", "path": "v1/{+name}", "id": "bigquerydatatransfer.projects.locations.dataSources.get", "description": "Retrieves a supported data source and returns its settings,\nwhich can be used for UI rendering." }, "list": { "description": "Lists supported data sources and returns their settings,\nwhich can be used for UI rendering.", "httpMethod": "GET", "response": { "$ref": "ListDataSourcesResponse" }, "parameterOrder": ["parent"], "parameters": { "pageSize": { "location": "query", "description": "Page size. The default page size is the maximum value of 1000 results.", "format": "int32", "type": "integer" }, "parent": { "description": "The BigQuery project id for which data sources should be returned.\nMust be in the form: `projects/{project_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+$", "location": "path" }, "pageToken": { "location": "query", "description": "Pagination token, which can be used to request a specific page\nof `ListDataSourcesRequest` list results. For multiple-page\nresults, `ListDataSourcesResponse` outputs\na `next_page` token, which can be used as the\n`page_token` value to request the next page of list results.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/dataSources", "id": "bigquerydatatransfer.projects.locations.dataSources.list", "path": "v1/{+parent}/dataSources" }, "checkValidCreds": { "path": "v1/{+name}:checkValidCreds", "id": "bigquerydatatransfer.projects.locations.dataSources.checkValidCreds", "request": { "$ref": "CheckValidCredsRequest" }, "description": "Returns true if valid credentials exist for the given data source and\nrequesting user.\nSome data sources doesn't support service account, so we need to talk to\nthem on behalf of the end user. This API just checks whether we have OAuth\ntoken for the particular user, which is a pre-requisite before user can\ncreate a transfer config.", "response": { "$ref": "CheckValidCredsResponse" }, "parameterOrder": ["name"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "name": { "location": "path", "description": "The data source in the form:\n`projects/{project_id}/dataSources/{data_source_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/dataSources/[^/]+$" } }, "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/dataSources/{dataSourcesId}:checkValidCreds" } } }, "transferConfigs": { "methods": { "patch": { "request": { "$ref": "TransferConfig" }, "description": "Updates a data transfer configuration.\nAll fields must be set, even if they are not updated.", "response": { "$ref": "TransferConfig" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "location": "path", "description": "The resource name of the transfer config.\nTransfer config names have the form of\n`projects/{project_id}/location/{region}/transferConfigs/{config_id}`.\nThe name is automatically generated based on the config_id specified in\nCreateTransferConfigRequest along with project_id and region. If config_id\nis not provided, usually a uuid, even though it is not guaranteed or\nrequired, will be generated for config_id.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/transferConfigs/[^/]+$" }, "authorizationCode": { "location": "query", "description": "Optional OAuth2 authorization code to use with this transfer configuration.\nIf it is provided, the transfer configuration will be associated with the\nauthorizing user.\nIn order to obtain authorization_code, please make a\nrequest to\nhttps://www.gstatic.com/bigquerydatatransfer/oauthz/auth?client_id=<datatransferapiclientid>&scope=<data_source_scopes>&redirect_uri=<redirect_uri>\n\n* client_id should be OAuth client_id of BigQuery DTS API for the given\n  data source returned by ListDataSources method.\n* data_source_scopes are the scopes returned by ListDataSources method.\n* redirect_uri is an optional parameter. If not specified, then\n  authorization code is posted to the opener of authorization flow window.\n  Otherwise it will be sent to the redirect uri. A special value of\n  urn:ietf:wg:oauth:2.0:oob means that authorization code should be\n  returned in the title bar of the browser, with the page text prompting\n  the user to copy the code and paste it in the application.", "type": "string" }, "updateMask": { "type": "string", "location": "query", "description": "Required list of fields to be updated in this request.", "format": "google-fieldmask" } }, "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs/{transferConfigsId}", "path": "v1/{+name}", "id": "bigquerydatatransfer.projects.locations.transferConfigs.patch" }, "get": { "response": { "$ref": "TransferConfig" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "name": { "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/transferConfigs/{config_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/transferConfigs/[^/]+$", "location": "path" } }, "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs/{transferConfigsId}", "path": "v1/{+name}", "id": "bigquerydatatransfer.projects.locations.transferConfigs.get", "description": "Returns information about a data transfer config." }, "delete": { "parameters": { "name": { "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/transferConfigs/{config_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/transferConfigs/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs/{transferConfigsId}", "id": "bigquerydatatransfer.projects.locations.transferConfigs.delete", "path": "v1/{+name}", "description": "Deletes a data transfer configuration,\nincluding any associated transfer runs and logs.", "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "Empty" } }, "list": { "description": "Returns information about all data transfers in the project.", "response": { "$ref": "ListTransferConfigsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "pageSize": { "location": "query", "description": "Page size. The default page size is the maximum value of 1000 results.", "format": "int32", "type": "integer" }, "parent": { "description": "The BigQuery project id for which data sources\nshould be returned: `projects/{project_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+$", "location": "path" }, "dataSourceIds": { "repeated": true, "location": "query", "description": "When specified, only configurations of requested data sources are returned.", "type": "string" }, "pageToken": { "type": "string", "location": "query", "description": "Pagination token, which can be used to request a specific page\nof `ListTransfersRequest` list results. For multiple-page\nresults, `ListTransfersResponse` outputs\na `next_page` token, which can be used as the\n`page_token` value to request the next page of list results." } }, "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs", "path": "v1/{+parent}/transferConfigs", "id": "bigquerydatatransfer.projects.locations.transferConfigs.list" }, "create": { "response": { "$ref": "TransferConfig" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "authorizationCode": { "description": "Optional OAuth2 authorization code to use with this transfer configuration.\nThis is required if new credentials are needed, as indicated by\n`CheckValidCreds`.\nIn order to obtain authorization_code, please make a\nrequest to\nhttps://www.gstatic.com/bigquerydatatransfer/oauthz/auth?client_id=<datatransferapiclientid>&scope=<data_source_scopes>&redirect_uri=<redirect_uri>\n\n* client_id should be OAuth client_id of BigQuery DTS API for the given\n  data source returned by ListDataSources method.\n* data_source_scopes are the scopes returned by ListDataSources method.\n* redirect_uri is an optional parameter. If not specified, then\n  authorization code is posted to the opener of authorization flow window.\n  Otherwise it will be sent to the redirect uri. A special value of\n  urn:ietf:wg:oauth:2.0:oob means that authorization code should be\n  returned in the title bar of the browser, with the page text prompting\n  the user to copy the code and paste it in the application.", "type": "string", "location": "query" }, "parent": { "description": "The BigQuery project id where the transfer configuration should be created.\nMust be in the format projects/{project_id}/locations/{location_id}\nIf specified location and location of the destination bigquery dataset\ndo not match - the request will fail.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs", "path": "v1/{+parent}/transferConfigs", "id": "bigquerydatatransfer.projects.locations.transferConfigs.create", "description": "Creates a new data transfer configuration.", "request": { "$ref": "TransferConfig" } }, "scheduleRuns": { "request": { "$ref": "ScheduleTransferRunsRequest" }, "description": "Creates transfer runs for a time range [start_time, end_time].\nFor each date - or whatever granularity the data source supports - in the\nrange, one transfer run is created.\nNote that runs are created per UTC time in the time range.", "response": { "$ref": "ScheduleTransferRunsResponse" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "Transfer configuration name in the form:\n`projects/{project_id}/transferConfigs/{config_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/transferConfigs/[^/]+$" } }, "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs/{transferConfigsId}:scheduleRuns", "path": "v1/{+parent}:scheduleRuns", "id": "bigquerydatatransfer.projects.locations.transferConfigs.scheduleRuns" } }, "resources": { "runs": { "methods": { "get": { "httpMethod": "GET", "response": { "$ref": "TransferRun" }, "parameterOrder": ["name"], "parameters": { "name": { "location": "path", "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/transferConfigs/[^/]+/runs/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs/{transferConfigsId}/runs/{runsId}", "id": "bigquerydatatransfer.projects.locations.transferConfigs.runs.get", "path": "v1/{+name}", "description": "Returns information about the particular transfer run." }, "list": { "description": "Returns information about running and completed jobs.", "response": { "$ref": "ListTransferRunsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "runAttempt": { "type": "string", "location": "query", "enum": ["RUN_ATTEMPT_UNSPECIFIED", "LATEST"], "description": "Indicates how run attempts are to be pulled." }, "parent": { "description": "Name of transfer configuration for which transfer runs should be retrieved.\nFormat of transfer configuration resource name is:\n`projects/{project_id}/transferConfigs/{config_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/transferConfigs/[^/]+$", "location": "path" }, "pageToken": { "location": "query", "description": "Pagination token, which can be used to request a specific page\nof `ListTransferRunsRequest` list results. For multiple-page\nresults, `ListTransferRunsResponse` outputs\na `next_page` token, which can be used as the\n`page_token` value to request the next page of list results.", "type": "string" }, "states": { "location": "query", "enum": ["TRANSFER_STATE_UNSPECIFIED", "PENDING", "RUNNING", "SUCCEEDED", "FAILED", "CANCELLED"], "description": "When specified, only transfer runs with requested states are returned.", "type": "string", "repeated": true }, "pageSize": { "description": "Page size. The default page size is the maximum value of 1000 results.", "format": "int32", "type": "integer", "location": "query" } }, "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs/{transferConfigsId}/runs", "path": "v1/{+parent}/runs", "id": "bigquerydatatransfer.projects.locations.transferConfigs.runs.list" }, "delete": { "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs/{transferConfigsId}/runs/{runsId}", "id": "bigquerydatatransfer.projects.locations.transferConfigs.runs.delete", "path": "v1/{+name}", "description": "Deletes the specified transfer run.", "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "Empty" }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/transferConfigs/[^/]+/runs/[^/]+$", "location": "path" } } } }, "resources": { "transferLogs": { "methods": { "list": { "response": { "$ref": "ListTransferLogsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "pageToken": { "location": "query", "description": "Pagination token, which can be used to request a specific page\nof `ListTransferLogsRequest` list results. For multiple-page\nresults, `ListTransferLogsResponse` outputs\na `next_page` token, which can be used as the\n`page_token` value to request the next page of list results.", "type": "string" }, "pageSize": { "description": "Page size. The default page size is the maximum value of 1000 results.", "format": "int32", "type": "integer", "location": "query" }, "messageTypes": { "description": "Message types to return. If not populated - INFO, WARNING and ERROR\nmessages are returned.", "type": "string", "repeated": true, "location": "query", "enum": ["MESSAGE_SEVERITY_UNSPECIFIED", "INFO", "WARNING", "ERROR"] }, "parent": { "description": "Transfer run name in the form:\n`projects/{project_id}/transferConfigs/{config_Id}/runs/{run_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/transferConfigs/[^/]+/runs/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/locations/{locationsId}/transferConfigs/{transferConfigsId}/runs/{runsId}/transferLogs", "path": "v1/{+parent}/transferLogs", "id": "bigquerydatatransfer.projects.locations.transferConfigs.runs.transferLogs.list", "description": "Returns user facing log messages for the data transfer run." } } } } } } } } }, "dataSources": { "methods": { "get": { "path": "v1/{+name}", "id": "bigquerydatatransfer.projects.dataSources.get", "description": "Retrieves a supported data source and returns its settings,\nwhich can be used for UI rendering.", "response": { "$ref": "DataSource" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "name": { "pattern": "^projects/[^/]+/dataSources/[^/]+$", "location": "path", "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/dataSources/{data_source_id}`", "required": true, "type": "string" } }, "flatPath": "v1/projects/{projectsId}/dataSources/{dataSourcesId}" }, "list": { "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "ListDataSourcesResponse" }, "parameters": { "pageToken": { "type": "string", "location": "query", "description": "Pagination token, which can be used to request a specific page\nof `ListDataSourcesRequest` list results. For multiple-page\nresults, `ListDataSourcesResponse` outputs\na `next_page` token, which can be used as the\n`page_token` value to request the next page of list results." }, "pageSize": { "description": "Page size. The default page size is the maximum value of 1000 results.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "location": "path", "description": "The BigQuery project id for which data sources should be returned.\nMust be in the form: `projects/{project_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/dataSources", "id": "bigquerydatatransfer.projects.dataSources.list", "path": "v1/{+parent}/dataSources", "description": "Lists supported data sources and returns their settings,\nwhich can be used for UI rendering." }, "checkValidCreds": { "response": { "$ref": "CheckValidCredsResponse" }, "parameterOrder": ["name"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/dataSources/[^/]+$", "location": "path", "description": "The data source in the form:\n`projects/{project_id}/dataSources/{data_source_id}`" } }, "flatPath": "v1/projects/{projectsId}/dataSources/{dataSourcesId}:checkValidCreds", "path": "v1/{+name}:checkValidCreds", "id": "bigquerydatatransfer.projects.dataSources.checkValidCreds", "request": { "$ref": "CheckValidCredsRequest" }, "description": "Returns true if valid credentials exist for the given data source and\nrequesting user.\nSome data sources doesn't support service account, so we need to talk to\nthem on behalf of the end user. This API just checks whether we have OAuth\ntoken for the particular user, which is a pre-requisite before user can\ncreate a transfer config." } } }, "transferConfigs": { "methods": { "delete": { "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "Empty" }, "parameters": { "name": { "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/transferConfigs/{config_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/transferConfigs/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/projects/{projectsId}/transferConfigs/{transferConfigsId}", "id": "bigquerydatatransfer.projects.transferConfigs.delete", "path": "v1/{+name}", "description": "Deletes a data transfer configuration,\nincluding any associated transfer runs and logs." }, "list": { "httpMethod": "GET", "response": { "$ref": "ListTransferConfigsResponse" }, "parameterOrder": ["parent"], "parameters": { "pageToken": { "description": "Pagination token, which can be used to request a specific page\nof `ListTransfersRequest` list results. For multiple-page\nresults, `ListTransfersResponse` outputs\na `next_page` token, which can be used as the\n`page_token` value to request the next page of list results.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "Page size. The default page size is the maximum value of 1000 results.", "format": "int32", "type": "integer" }, "parent": { "location": "path", "description": "The BigQuery project id for which data sources\nshould be returned: `projects/{project_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" }, "dataSourceIds": { "type": "string", "repeated": true, "location": "query", "description": "When specified, only configurations of requested data sources are returned." } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/transferConfigs", "id": "bigquerydatatransfer.projects.transferConfigs.list", "path": "v1/{+parent}/transferConfigs", "description": "Returns information about all data transfers in the project." }, "create": { "response": { "$ref": "TransferConfig" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "authorizationCode": { "location": "query", "description": "Optional OAuth2 authorization code to use with this transfer configuration.\nThis is required if new credentials are needed, as indicated by\n`CheckValidCreds`.\nIn order to obtain authorization_code, please make a\nrequest to\nhttps://www.gstatic.com/bigquerydatatransfer/oauthz/auth?client_id=<datatransferapiclientid>&scope=<data_source_scopes>&redirect_uri=<redirect_uri>\n\n* client_id should be OAuth client_id of BigQuery DTS API for the given\n  data source returned by ListDataSources method.\n* data_source_scopes are the scopes returned by ListDataSources method.\n* redirect_uri is an optional parameter. If not specified, then\n  authorization code is posted to the opener of authorization flow window.\n  Otherwise it will be sent to the redirect uri. A special value of\n  urn:ietf:wg:oauth:2.0:oob means that authorization code should be\n  returned in the title bar of the browser, with the page text prompting\n  the user to copy the code and paste it in the application.", "type": "string" }, "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path", "description": "The BigQuery project id where the transfer configuration should be created.\nMust be in the format projects/{project_id}/locations/{location_id}\nIf specified location and location of the destination bigquery dataset\ndo not match - the request will fail." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/projects/{projectsId}/transferConfigs", "path": "v1/{+parent}/transferConfigs", "id": "bigquerydatatransfer.projects.transferConfigs.create", "description": "Creates a new data transfer configuration.", "request": { "$ref": "TransferConfig" } }, "scheduleRuns": { "flatPath": "v1/projects/{projectsId}/transferConfigs/{transferConfigsId}:scheduleRuns", "path": "v1/{+parent}:scheduleRuns", "id": "bigquerydatatransfer.projects.transferConfigs.scheduleRuns", "description": "Creates transfer runs for a time range [start_time, end_time].\nFor each date - or whatever granularity the data source supports - in the\nrange, one transfer run is created.\nNote that runs are created per UTC time in the time range.", "request": { "$ref": "ScheduleTransferRunsRequest" }, "response": { "$ref": "ScheduleTransferRunsResponse" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "pattern": "^projects/[^/]+/transferConfigs/[^/]+$", "location": "path", "description": "Transfer configuration name in the form:\n`projects/{project_id}/transferConfigs/{config_id}`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform"] }, "patch": { "flatPath": "v1/projects/{projectsId}/transferConfigs/{transferConfigsId}", "path": "v1/{+name}", "id": "bigquerydatatransfer.projects.transferConfigs.patch", "description": "Updates a data transfer configuration.\nAll fields must be set, even if they are not updated.", "request": { "$ref": "TransferConfig" }, "response": { "$ref": "TransferConfig" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "updateMask": { "location": "query", "description": "Required list of fields to be updated in this request.", "format": "google-fieldmask", "type": "string" }, "name": { "description": "The resource name of the transfer config.\nTransfer config names have the form of\n`projects/{project_id}/location/{region}/transferConfigs/{config_id}`.\nThe name is automatically generated based on the config_id specified in\nCreateTransferConfigRequest along with project_id and region. If config_id\nis not provided, usually a uuid, even though it is not guaranteed or\nrequired, will be generated for config_id.", "required": true, "type": "string", "pattern": "^projects/[^/]+/transferConfigs/[^/]+$", "location": "path" }, "authorizationCode": { "type": "string", "location": "query", "description": "Optional OAuth2 authorization code to use with this transfer configuration.\nIf it is provided, the transfer configuration will be associated with the\nauthorizing user.\nIn order to obtain authorization_code, please make a\nrequest to\nhttps://www.gstatic.com/bigquerydatatransfer/oauthz/auth?client_id=<datatransferapiclientid>&scope=<data_source_scopes>&redirect_uri=<redirect_uri>\n\n* client_id should be OAuth client_id of BigQuery DTS API for the given\n  data source returned by ListDataSources method.\n* data_source_scopes are the scopes returned by ListDataSources method.\n* redirect_uri is an optional parameter. If not specified, then\n  authorization code is posted to the opener of authorization flow window.\n  Otherwise it will be sent to the redirect uri. A special value of\n  urn:ietf:wg:oauth:2.0:oob means that authorization code should be\n  returned in the title bar of the browser, with the page text prompting\n  the user to copy the code and paste it in the application." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "get": { "response": { "$ref": "TransferConfig" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "name": { "location": "path", "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/transferConfigs/{config_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/transferConfigs/[^/]+$" } }, "flatPath": "v1/projects/{projectsId}/transferConfigs/{transferConfigsId}", "path": "v1/{+name}", "id": "bigquerydatatransfer.projects.transferConfigs.get", "description": "Returns information about a data transfer config." } }, "resources": { "runs": { "methods": { "get": { "parameters": { "name": { "location": "path", "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/transferConfigs/[^/]+/runs/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/transferConfigs/{transferConfigsId}/runs/{runsId}", "id": "bigquerydatatransfer.projects.transferConfigs.runs.get", "path": "v1/{+name}", "description": "Returns information about the particular transfer run.", "httpMethod": "GET", "parameterOrder": ["name"], "response": { "$ref": "TransferRun" } }, "list": { "description": "Returns information about running and completed jobs.", "response": { "$ref": "ListTransferRunsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "runAttempt": { "enum": ["RUN_ATTEMPT_UNSPECIFIED", "LATEST"], "description": "Indicates how run attempts are to be pulled.", "type": "string", "location": "query" }, "parent": { "location": "path", "description": "Name of transfer configuration for which transfer runs should be retrieved.\nFormat of transfer configuration resource name is:\n`projects/{project_id}/transferConfigs/{config_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/transferConfigs/[^/]+$" }, "pageToken": { "type": "string", "location": "query", "description": "Pagination token, which can be used to request a specific page\nof `ListTransferRunsRequest` list results. For multiple-page\nresults, `ListTransferRunsResponse` outputs\na `next_page` token, which can be used as the\n`page_token` value to request the next page of list results." }, "states": { "repeated": true, "location": "query", "enum": ["TRANSFER_STATE_UNSPECIFIED", "PENDING", "RUNNING", "SUCCEEDED", "FAILED", "CANCELLED"], "description": "When specified, only transfer runs with requested states are returned.", "type": "string" }, "pageSize": { "description": "Page size. The default page size is the maximum value of 1000 results.", "format": "int32", "type": "integer", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/projects/{projectsId}/transferConfigs/{transferConfigsId}/runs", "path": "v1/{+parent}/runs", "id": "bigquerydatatransfer.projects.transferConfigs.runs.list" }, "delete": { "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "The field will contain name of the resource requested, for example:\n`projects/{project_id}/transferConfigs/{config_id}/runs/{run_id}`", "required": true, "type": "string", "pattern": "^projects/[^/]+/transferConfigs/[^/]+/runs/[^/]+$", "location": "path" } }, "flatPath": "v1/projects/{projectsId}/transferConfigs/{transferConfigsId}/runs/{runsId}", "path": "v1/{+name}", "id": "bigquerydatatransfer.projects.transferConfigs.runs.delete", "description": "Deletes the specified transfer run." } }, "resources": { "transferLogs": { "methods": { "list": { "description": "Returns user facing log messages for the data transfer run.", "response": { "$ref": "ListTransferLogsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/bigquery", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "pageSize": { "location": "query", "description": "Page size. The default page size is the maximum value of 1000 results.", "format": "int32", "type": "integer" }, "messageTypes": { "description": "Message types to return. If not populated - INFO, WARNING and ERROR\nmessages are returned.", "type": "string", "repeated": true, "location": "query", "enum": ["MESSAGE_SEVERITY_UNSPECIFIED", "INFO", "WARNING", "ERROR"] }, "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/transferConfigs/[^/]+/runs/[^/]+$", "location": "path", "description": "Transfer run name in the form:\n`projects/{project_id}/transferConfigs/{config_Id}/runs/{run_id}`." }, "pageToken": { "description": "Pagination token, which can be used to request a specific page\nof `ListTransferLogsRequest` list results. For multiple-page\nresults, `ListTransferLogsResponse` outputs\na `next_page` token, which can be used as the\n`page_token` value to request the next page of list results.", "type": "string", "location": "query" } }, "flatPath": "v1/projects/{projectsId}/transferConfigs/{transferConfigsId}/runs/{runsId}/transferLogs", "path": "v1/{+parent}/transferLogs", "id": "bigquerydatatransfer.projects.transferConfigs.runs.transferLogs.list" } } } } } } } } } }, "parameters": { "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "type": "string", "location": "query" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "type": "string", "location": "query", "description": "OAuth 2.0 token for the current user." }, "$.xgafv": { "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"], "description": "V1 error format." }, "alt": { "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string" }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" } }, "version": "v1", "baseUrl": "https://bigquerydatatransfer.googleapis.com/" };
//# sourceMappingURL=bigquerydatatransfer-v1.js.map