"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "discoveryVersion": "v1", "version_module": true, "schemas": { "GoogleCloudDialogflowV2WebhookRequest": { "description": "The request message for a webhook call.", "type": "object", "properties": { "responseId": { "description": "The unique identifier of the response. Contains the same value as\n`[Streaming]DetectIntentResponse.response_id`.", "type": "string" }, "session": { "description": "The unique identifier of detectIntent request session.\nCan be used to identify end-user inside webhook implementation.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`.", "type": "string" }, "queryResult": { "description": "The result of the conversational query or event processing. Contains the\nsame value as `[Streaming]DetectIntentResponse.query_result`.", "$ref": "GoogleCloudDialogflowV2QueryResult" }, "originalDetectIntentRequest": { "$ref": "GoogleCloudDialogflowV2OriginalDetectIntentRequest", "description": "Optional. The contents of the original request that was passed to\n`[Streaming]DetectIntent` call." } }, "id": "GoogleCloudDialogflowV2WebhookRequest" }, "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo": { "type": "object", "properties": { "followupIntentName": { "description": "The unique identifier of the followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "parentFollowupIntentName": { "description": "The unique identifier of the followup intent's parent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo", "description": "Represents a single followup intent in the chain." }, "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesRequest": { "description": "The request message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "languageCode": { "description": "Optional. The language of entity synonyms defined in `entity_types`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "entityTypeBatchUri": { "description": "The URI to a Google Cloud Storage file containing entity types to update\nor create. The file format can either be a serialized proto (of\nEntityBatch type) or a JSON object. Note: The URI must start with\n\"gs://\".", "type": "string" }, "entityTypeBatchInline": { "description": "The collection of entity types to update or create.", "$ref": "GoogleCloudDialogflowV2beta1EntityTypeBatch" } }, "id": "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesRequest" }, "GoogleCloudDialogflowV2ExportAgentResponse": { "description": "The response message for Agents.ExportAgent.", "type": "object", "properties": { "agentContent": { "type": "string", "description": "The exported agent.\n\nExample for how to export an agent to a zip file via a command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2/projects/&lt;project_name&gt;/agent:export'\\\n  -X POST \\\n  -H 'Authorization: Bearer '$(gcloud auth application-default\n  print-access-token) \\\n  -H 'Accept: application/json' \\\n  -H 'Content-Type: application/json' \\\n  --compressed \\\n  --data-binary '{}' \\\n| grep agentContent | sed -e 's/.*\"agentContent\": \"\\([^\"]*\\)\".*/\\1/' \\\n| base64 --decode > &lt;agent zip file&gt;</pre>", "format": "byte" }, "agentUri": { "type": "string", "description": "The URI to a file containing the exported agent. This field is populated\nonly if `agent_uri` is specified in `ExportAgentRequest`." } }, "id": "GoogleCloudDialogflowV2ExportAgentResponse" }, "GoogleCloudDialogflowV2beta1DetectIntentRequest": { "description": "The request to detect user's intent.", "type": "object", "properties": { "outputAudioConfig": { "$ref": "GoogleCloudDialogflowV2beta1OutputAudioConfig", "description": "Optional. Instructs the speech synthesizer how to generate the output\naudio. If this field is not set and agent-level speech synthesizer is not\nconfigured, no output audio is generated." }, "inputAudio": { "type": "string", "description": "Optional. The natural language speech audio to be processed. This field\nshould be populated iff `query_input` is set to an input audio config.\nA single request can contain up to 1 minute of speech audio data.", "format": "byte" }, "queryInput": { "$ref": "GoogleCloudDialogflowV2beta1QueryInput", "description": "Required. The input specification. It can be set to:\n\n1.  an audio config\n    which instructs the speech recognizer how to process the speech audio,\n\n2.  a conversational query in the form of text, or\n\n3.  an event that specifies which intent to trigger." }, "queryParams": { "description": "Optional. The parameters of this query.", "$ref": "GoogleCloudDialogflowV2beta1QueryParameters" } }, "id": "GoogleCloudDialogflowV2beta1DetectIntentRequest" }, "GoogleCloudDialogflowV2beta1VoiceSelectionParams": { "description": "Description of which voice to use for speech synthesis.", "type": "object", "properties": { "name": { "description": "Optional. The name of the voice. If not set, the service will choose a\nvoice based on the other parameters such as language_code and gender.", "type": "string" }, "ssmlGender": { "description": "Optional. The preferred gender of the voice. If not set, the service will\nchoose a voice based on the other parameters such as language_code and\nname. Note that this is only a preference, not requirement. If a\nvoice of the appropriate gender is not available, the synthesizer should\nsubstitute a voice with a different gender rather than failing the request.", "type": "string", "enumDescriptions": ["An unspecified gender, which means that the client doesn't care which\ngender the selected voice will have.", "A male voice.", "A female voice.", "A gender-neutral voice."], "enum": ["SSML_VOICE_GENDER_UNSPECIFIED", "SSML_VOICE_GENDER_MALE", "SSML_VOICE_GENDER_FEMALE", "SSML_VOICE_GENDER_NEUTRAL"] } }, "id": "GoogleCloudDialogflowV2beta1VoiceSelectionParams" }, "GoogleCloudDialogflowV2beta1ImportAgentRequest": { "type": "object", "properties": { "agentContent": { "description": "The agent to import.\n\nExample for how to import an agent via the command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2beta1/projects/&lt;project_name&gt;/agent:import\\\n   -X POST \\\n   -H 'Authorization: Bearer '$(gcloud auth application-default\n   print-access-token) \\\n   -H 'Accept: application/json' \\\n   -H 'Content-Type: application/json' \\\n   --compressed \\\n   --data-binary \"{\n      'agentContent': '$(cat &lt;agent zip file&gt; | base64 -w 0)'\n   }\"</pre>", "format": "byte", "type": "string" }, "agentUri": { "description": "The URI to a Google Cloud Storage file containing the agent to import.\nNote: The URI must start with \"gs://\".", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1ImportAgentRequest", "description": "The request message for Agents.ImportAgent." }, "GoogleCloudDialogflowV2beta1EntityTypeEntity": { "description": "Optional. Represents an entity.", "type": "object", "properties": { "value": { "type": "string", "description": "Required.\nFor `KIND_MAP` entity types:\n  A canonical name to be used in place of synonyms.\nFor `KIND_LIST` entity types:\n  A string that can contain references to other entity types (with or\n  without aliases)." }, "synonyms": { "description": "Required. A collection of synonyms. For `KIND_LIST` entity types this\nmust contain exactly one synonym equal to `value`.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2beta1EntityTypeEntity" }, "GoogleCloudDialogflowV2beta1BatchUpdateIntentsRequest": { "description": "The request message for Intents.BatchUpdateIntents.", "type": "object", "properties": { "intentBatchUri": { "description": "The URI to a Google Cloud Storage file containing intents to update or\ncreate. The file format can either be a serialized proto (of IntentBatch\ntype) or JSON object. Note: The URI must start with \"gs://\".", "type": "string" }, "intentView": { "description": "Optional. The resource view to apply to the returned intent.", "type": "string", "enumDescriptions": ["Training phrases field is not populated in the response.", "All fields are populated."], "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"] }, "intentBatchInline": { "$ref": "GoogleCloudDialogflowV2beta1IntentBatch", "description": "The collection of intents to update or create." }, "languageCode": { "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intents`. If not specified, the agent's default language is\nused. [More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1BatchUpdateIntentsRequest" }, "GoogleCloudDialogflowV2IntentMessageCardButton": { "description": "Optional. Contains information about a button.", "type": "object", "properties": { "text": { "description": "Optional. The text to show on the button.", "type": "string" }, "postback": { "description": "Optional. The text to send back to the Dialogflow API or a URI to\nopen.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageCardButton" }, "GoogleCloudDialogflowV2WebhookResponse": { "description": "The response message for a webhook call.", "type": "object", "properties": { "source": { "type": "string", "description": "Optional. This value is passed directly to `QueryResult.webhook_source`." }, "followupEventInput": { "$ref": "GoogleCloudDialogflowV2EventInput", "description": "Optional. Makes the platform immediately invoke another `DetectIntent` call\ninternally with the specified event as input." }, "outputContexts": { "description": "Optional. The collection of output contexts. This value is passed directly\nto `QueryResult.output_contexts`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "fulfillmentText": { "description": "Optional. The text to be shown on the screen. This value is passed directly\nto `QueryResult.fulfillment_text`.", "type": "string" }, "fulfillmentMessages": { "description": "Optional. The collection of rich messages to present to the user. This\nvalue is passed directly to `QueryResult.fulfillment_messages`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This value is passed directly to `QueryResult.webhook_payload`.\nSee the related `fulfillment_messages[i].payload field`, which may be used\nas an alternative to this field.\n\nThis field can be used for Actions on Google responses.\nIt should have a structure similar to the JSON message shown here. For more\ninformation, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"google\": {\n    \"expectUserResponse\": true,\n    \"richResponse\": {\n      \"items\": [\n        {\n          \"simpleResponse\": {\n            \"textToSpeech\": \"this is a simple response\"\n          }\n        }\n      ]\n    }\n  }\n}</pre>", "type": "object" } }, "id": "GoogleCloudDialogflowV2WebhookResponse" }, "GoogleCloudDialogflowV2beta1ReloadDocumentRequest": { "description": "Request message for Documents.ReloadDocument.", "type": "object", "properties": {}, "id": "GoogleCloudDialogflowV2beta1ReloadDocumentRequest" }, "GoogleCloudDialogflowV2beta1KnowledgeAnswers": { "description": "Represents the result of querying a Knowledge base.", "type": "object", "properties": { "answers": { "description": "A list of answers from Knowledge Connector.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer" } } }, "id": "GoogleCloudDialogflowV2beta1KnowledgeAnswers" }, "GoogleCloudDialogflowV2beta1SentimentAnalysisResult": { "description": "The result of sentiment analysis as configured by\n`sentiment_analysis_request_config`.", "type": "object", "properties": { "queryTextSentiment": { "$ref": "GoogleCloudDialogflowV2beta1Sentiment", "description": "The sentiment analysis result for `query_text`." } }, "id": "GoogleCloudDialogflowV2beta1SentimentAnalysisResult" }, "GoogleCloudDialogflowV2beta1ExportAgentResponse": { "description": "The response message for Agents.ExportAgent.", "type": "object", "properties": { "agentContent": { "description": "The exported agent.\n\nExample for how to export an agent to a zip file via a command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2beta1/projects/&lt;project_name&gt;/agent:export'\\\n  -X POST \\\n  -H 'Authorization: Bearer '$(gcloud auth application-default\n  print-access-token) \\\n  -H 'Accept: application/json' \\\n  -H 'Content-Type: application/json' \\\n  --compressed \\\n  --data-binary '{}' \\\n| grep agentContent | sed -e 's/.*\"agentContent\": \"\\([^\"]*\\)\".*/\\1/' \\\n| base64 --decode > &lt;agent zip file&gt;</pre>", "format": "byte", "type": "string" }, "agentUri": { "description": "The URI to a file containing the exported agent. This field is populated\nonly if `agent_uri` is specified in `ExportAgentRequest`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1ExportAgentResponse" }, "GoogleCloudDialogflowV2OriginalDetectIntentRequest": { "id": "GoogleCloudDialogflowV2OriginalDetectIntentRequest", "description": "Represents the contents of the original request that was passed to\nthe `[Streaming]DetectIntent` call.", "type": "object", "properties": { "payload": { "description": "Optional. This field is set to the value of the `QueryParameters.payload`\nfield passed in the request. Some integrations that query a Dialogflow\nagent may provide additional information in the payload.\n\nIn particular for the Telephony Gateway this field has the form:\n<pre>{\n \"telephony\": {\n   \"caller_id\": \"+18558363987\"\n }\n}</pre>\nNote: The caller ID field (`caller_id`) will be redacted for Standard\nEdition agents and populated with the caller ID in [E.164\nformat](https://en.wikipedia.org/wiki/E.164) for Enterprise Edition agents.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "source": { "type": "string", "description": "The source of this request, e.g., `google`, `facebook`, `slack`. It is set\nby Dialogflow-owned servers." }, "version": { "description": "Optional. The version of the protocol used for this request.\nThis field is AoG-specific.", "type": "string" } } }, "GoogleLongrunningOperation": { "description": "This resource represents a long-running operation that is the result of a\nnetwork API call.", "type": "object", "properties": { "done": { "description": "If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.", "type": "boolean" }, "response": { "description": "The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`.", "type": "object", "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." } }, "name": { "description": "The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should have the format of `operations/some/unique/name`.", "type": "string" }, "error": { "$ref": "GoogleRpcStatus", "description": "The error result of the operation in case of failure or cancellation." }, "metadata": { "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any." } }, "id": "GoogleLongrunningOperation" }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall": { "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall", "description": "Transfers the call in Telephony Gateway.", "type": "object", "properties": { "phoneNumber": { "description": "Required. The phone number to transfer the call to\nin [E.164 format](https://en.wikipedia.org/wiki/E.164).\n\nWe currently only allow transferring to US numbers (+1xxxyyyzzzz).", "type": "string" } } }, "GoogleCloudDialogflowV2beta1IntentMessageImage": { "id": "GoogleCloudDialogflowV2beta1IntentMessageImage", "description": "The image response message.", "type": "object", "properties": { "imageUri": { "type": "string", "description": "Optional. The public URI to an image file." }, "accessibilityText": { "description": "A text description of the image to be used for accessibility,\ne.g., screen readers. Required if image_uri is set for CarouselSelect.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1SentimentAnalysisRequestConfig": { "type": "object", "properties": { "analyzeQueryTextSentiment": { "description": "Optional. Instructs the service to perform sentiment analysis on\n`query_text`. If not provided, sentiment analysis is not performed on\n`query_text`.", "type": "boolean" } }, "id": "GoogleCloudDialogflowV2beta1SentimentAnalysisRequestConfig", "description": "Configures the types of sentiment analysis to perform." }, "GoogleCloudDialogflowV2beta1SearchAgentsResponse": { "properties": { "agents": { "description": "The list of agents. There will be a maximum number of items returned based\non the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Agent" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1SearchAgentsResponse", "description": "The response message for Agents.SearchAgents.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem": { "description": "An item in the carousel.", "type": "object", "properties": { "title": { "type": "string", "description": "Required. Title of the carousel item." }, "image": { "description": "Optional. The image to display.", "$ref": "GoogleCloudDialogflowV2IntentMessageImage" }, "description": { "description": "Optional. The body text of the card.", "type": "string" }, "info": { "description": "Required. Additional info about the option item.", "$ref": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo" } }, "id": "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem" }, "GoogleCloudDialogflowV2IntentMessageSimpleResponse": { "type": "object", "properties": { "textToSpeech": { "description": "One of text_to_speech or ssml must be provided. The plain text of the\nspeech output. Mutually exclusive with ssml.", "type": "string" }, "ssml": { "description": "One of text_to_speech or ssml must be provided. Structured spoken\nresponse to the user in the SSML format. Mutually exclusive with\ntext_to_speech.", "type": "string" }, "displayText": { "description": "Optional. The text to display.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageSimpleResponse", "description": "The simple response message containing speech or text." }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton": { "description": "The button object that appears at the bottom of a card.", "type": "object", "properties": { "openUriAction": { "description": "Required. Action to take when a user taps on the button.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction" }, "title": { "description": "Required. The title of the button.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton" }, "GoogleCloudDialogflowV2beta1Agent": { "id": "GoogleCloudDialogflowV2beta1Agent", "description": "Represents a conversational agent.", "type": "object", "properties": { "description": { "description": "Optional. The description of this agent.\nThe maximum length is 500 characters. If exceeded, the request is rejected.", "type": "string" }, "displayName": { "type": "string", "description": "Required. The name of this agent." }, "parent": { "description": "Required. The project of this agent.\nFormat: `projects/<Project ID>`.", "type": "string" }, "matchMode": { "enum": ["MATCH_MODE_UNSPECIFIED", "MATCH_MODE_HYBRID", "MATCH_MODE_ML_ONLY"], "description": "Optional. Determines how intents are detected from user queries.", "type": "string", "enumDescriptions": ["Not specified.", "Best for agents with a small number of examples in intents and/or wide\nuse of templates syntax and composite entities.", "Can be used for agents with a large number of examples in intents,\nespecially the ones using @sys.any or very large developer entities."] }, "supportedLanguageCodes": { "description": "Optional. The list of all languages supported by this agent (except for the\n`default_language_code`).", "type": "array", "items": { "type": "string" } }, "enableLogging": { "description": "Optional. Determines whether this agent should log conversation queries.", "type": "boolean" }, "avatarUri": { "description": "Optional. The URI of the agent's avatar.\nAvatars are used throughout the Dialogflow console and in the self-hosted\n[Web Demo](https://dialogflow.com/docs/integrations/web-demo) integration.", "type": "string" }, "classificationThreshold": { "description": "Optional. To filter out false positive results and still get variety in\nmatched natural language inputs for your agent, you can tune the machine\nlearning classification threshold. If the returned score value is less than\nthe threshold value, then a fallback intent is be triggered or, if there\nare no fallback intents defined, no intent will be triggered. The score\nvalues range from 0.0 (completely uncertain) to 1.0 (completely certain).\nIf set to 0.0, the default of 0.3 is used.", "format": "float", "type": "number" }, "defaultLanguageCode": { "type": "string", "description": "Required. The default language of the agent as a language tag. See\n[Language Support](https://dialogflow.com/docs/reference/language) for a\nlist of the currently supported language codes.\nThis field cannot be set by the `Update` method." }, "timeZone": { "description": "Required. The time zone of this agent from the\n[time zone database](https://www.iana.org/time-zones), e.g.,\nAmerica/New_York, Europe/Paris.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1QueryInput": { "properties": { "text": { "$ref": "GoogleCloudDialogflowV2beta1TextInput", "description": "The natural language text to be processed." }, "audioConfig": { "$ref": "GoogleCloudDialogflowV2beta1InputAudioConfig", "description": "Instructs the speech recognizer how to process the speech audio." }, "event": { "description": "The event to be processed.", "$ref": "GoogleCloudDialogflowV2beta1EventInput" } }, "id": "GoogleCloudDialogflowV2beta1QueryInput", "description": "Represents the query input. It can contain either:\n\n1.  An audio config which\n    instructs the speech recognizer how to process the speech audio.\n\n2.  A conversational query in the form of text,.\n\n3.  An event that specifies which intent to trigger.", "type": "object" }, "GoogleCloudDialogflowV2IntentTrainingPhrase": { "id": "GoogleCloudDialogflowV2IntentTrainingPhrase", "description": "Represents an example or template that the agent is trained on.", "type": "object", "properties": { "parts": { "description": "Required. The collection of training phrase parts (can be annotated).\nFields: `entity_type`, `alias` and `user_defined` should be populated\nonly for the annotated parts of the training phrase.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentTrainingPhrasePart" } }, "name": { "description": "Output only. The unique identifier of this training phrase.", "type": "string" }, "timesAddedCount": { "description": "Optional. Indicates how many times this example or template was added to\nthe intent. Each time a developer adds an existing sample by editing an\nintent or training, this counter is increased.", "format": "int32", "type": "integer" }, "type": { "enumDescriptions": ["Not specified. This value should never be used.", "Examples do not contain @-prefixed entity type names, but example parts\ncan be annotated with entity types.", "Templates are not annotated with entity types, but they can contain\n@-prefixed entity type names as substrings."], "enum": ["TYPE_UNSPECIFIED", "EXAMPLE", "TEMPLATE"], "description": "Required. The type of the training phrase.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1BatchCreateEntitiesRequest": { "description": "The request message for EntityTypes.BatchCreateEntities.", "type": "object", "properties": { "entities": { "description": "Required. The entities to create.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityTypeEntity" } }, "languageCode": { "type": "string", "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used." } }, "id": "GoogleCloudDialogflowV2beta1BatchCreateEntitiesRequest" }, "GoogleCloudDialogflowV2beta1RestoreAgentRequest": { "description": "The request message for Agents.RestoreAgent.", "type": "object", "properties": { "agentContent": { "description": "The agent to restore.\n\nExample for how to restore an agent via the command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2beta1/projects/&lt;project_name&gt;/agent:restore\\\n   -X POST \\\n   -H 'Authorization: Bearer '$(gcloud auth application-default\n   print-access-token) \\\n   -H 'Accept: application/json' \\\n   -H 'Content-Type: application/json' \\\n   --compressed \\\n   --data-binary \"{\n       'agentContent': '$(cat &lt;agent zip file&gt; | base64 -w 0)'\n   }\"</pre>", "format": "byte", "type": "string" }, "agentUri": { "description": "The URI to a Google Cloud Storage file containing the agent to restore.\nNote: The URI must start with \"gs://\".", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1RestoreAgentRequest" }, "GoogleCloudDialogflowV2beta1DetectIntentResponse": { "description": "The message returned from the DetectIntent method.", "type": "object", "properties": { "queryResult": { "$ref": "GoogleCloudDialogflowV2beta1QueryResult", "description": "The selected results of the conversational query or event processing.\nSee `alternative_query_results` for additional potential results." }, "webhookStatus": { "description": "Specifies the status of the webhook request.", "$ref": "GoogleRpcStatus" }, "alternativeQueryResults": { "description": "If Knowledge Connectors are enabled, there could be more than one result\nreturned for a given query or event, and this field will contain all\nresults except for the top one, which is captured in query_result. The\nalternative results are ordered by decreasing\n`QueryResult.intent_detection_confidence`. If Knowledge Connectors are\ndisabled, this field will be empty until multiple responses for regular\nintents are supported, at which point those additional results will be\nsurfaced here.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1QueryResult" } }, "responseId": { "description": "The unique identifier of the response. It can be used to\nlocate a response in the training example set or for reporting issues.", "type": "string" }, "outputAudioConfig": { "description": "Instructs the speech synthesizer how to generate the output audio. This\nfield is populated from the agent-level speech synthesizer configuration,\nif enabled.", "$ref": "GoogleCloudDialogflowV2beta1OutputAudioConfig" }, "outputAudio": { "description": "The audio data bytes encoded as specified in the request.", "format": "byte", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1DetectIntentResponse" }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio": { "description": "Plays audio from a file in Telephony Gateway.", "type": "object", "properties": { "audioUri": { "description": "Required. URI to a Google Cloud Storage object containing the audio to\nplay, e.g., \"gs://bucket/object\". The object must contain a single\nchannel (mono) of linear PCM audio (2 bytes / sample) at 8kHz.\n\nThis object must be readable by the `service-<Project\nNumber>@gcp-sa-dialogflow.iam.gserviceaccount.com` service account\nwhere <Project Number> is the number of the Telephony Gateway project\n(usually the same as the Dialogflow agent project). If the Google Cloud\nStorage bucket is in the Telephony Gateway project, this permission is\nadded by default when enabling the Dialogflow V2 API.\n\nFor audio from other sources, consider using the\n`TelephonySynthesizeSpeech` message with SSML.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio" }, "GoogleCloudDialogflowV2beta1WebhookRequest": { "id": "GoogleCloudDialogflowV2beta1WebhookRequest", "description": "The request message for a webhook call.", "type": "object", "properties": { "responseId": { "description": "The unique identifier of the response. Contains the same value as\n`[Streaming]DetectIntentResponse.response_id`.", "type": "string" }, "session": { "description": "The unique identifier of detectIntent request session.\nCan be used to identify end-user inside webhook implementation.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`.", "type": "string" }, "queryResult": { "$ref": "GoogleCloudDialogflowV2beta1QueryResult", "description": "The result of the conversational query or event processing. Contains the\nsame value as `[Streaming]DetectIntentResponse.query_result`." }, "originalDetectIntentRequest": { "$ref": "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest", "description": "Optional. The contents of the original request that was passed to\n`[Streaming]DetectIntent` call." }, "alternativeQueryResults": { "description": "Alternative query results from KnowledgeService.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1QueryResult" } } } }, "GoogleCloudDialogflowV2IntentMessageListSelect": { "description": "The card for presenting a list of options to select from.", "type": "object", "properties": { "title": { "description": "Optional. The overall title of the list.", "type": "string" }, "items": { "description": "Required. List items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageListSelectItem" } } }, "id": "GoogleCloudDialogflowV2IntentMessageListSelect" }, "GoogleCloudDialogflowV2beta1IntentMessageCardButton": { "description": "Optional. Contains information about a button.", "type": "object", "properties": { "postback": { "description": "Optional. The text to send back to the Dialogflow API or a URI to\nopen.", "type": "string" }, "text": { "description": "Optional. The text to show on the button.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCardButton" }, "GoogleProtobufEmpty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "GoogleProtobufEmpty" }, "GoogleCloudDialogflowV2beta1ConversationEvent": { "description": "Represents a notification sent to Cloud Pub/Sub subscribers for conversation\nlifecycle events.", "type": "object", "properties": { "type": { "enum": ["TYPE_UNSPECIFIED", "CONVERSATION_STARTED", "CONVERSATION_FINISHED", "UNRECOVERABLE_ERROR"], "description": "Required. The type of the event that this notification refers to.", "type": "string", "enumDescriptions": ["Type not set.", "A new conversation has been opened. This is fired when a telephone call\nis answered, or a conversation is created via the API.", "An existing conversation has closed. This is fired when a telephone call\nis terminated, or a conversation is closed via the API.", "Unrecoverable error during a telephone call.\n\nIn general non-recoverable errors only occur if something was\nmisconfigured in the ConversationProfile corresponding to the call. After\na non-recoverable error, Dialogflow may stop responding.\n\nWe don't fire this event:\n* in an API call because we can directly return the error, or,\n* when we can recover from an error."] }, "conversation": { "description": "Required. The unique identifier of the conversation this notification\nrefers to. Format: `projects/<Project ID>/conversations/<Conversation ID>`.", "type": "string" }, "errorStatus": { "$ref": "GoogleRpcStatus", "description": "Optional. More detailed information about an error. Only set for type\nUNRECOVERABLE_ERROR_IN_PHONE_CALL." } }, "id": "GoogleCloudDialogflowV2beta1ConversationEvent" }, "GoogleCloudDialogflowV2IntentMessageListSelectItem": { "id": "GoogleCloudDialogflowV2IntentMessageListSelectItem", "description": "An item in the list.", "type": "object", "properties": { "info": { "$ref": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo", "description": "Required. Additional information about this option." }, "title": { "description": "Required. The title of the list item.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "Optional. The image to display." }, "description": { "description": "Optional. The main text describing the item.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1BatchDeleteIntentsRequest": { "description": "The request message for Intents.BatchDeleteIntents.", "type": "object", "properties": { "intents": { "description": "Required. The collection of intents to delete. Only intent `name` must be\nfilled in.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Intent" } } }, "id": "GoogleCloudDialogflowV2beta1BatchDeleteIntentsRequest" }, "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest": { "description": "Represents the contents of the original request that was passed to\nthe `[Streaming]DetectIntent` call.", "type": "object", "properties": { "version": { "description": "Optional. The version of the protocol used for this request.\nThis field is AoG-specific.", "type": "string" }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This field is set to the value of the `QueryParameters.payload`\nfield passed in the request. Some integrations that query a Dialogflow\nagent may provide additional information in the payload.\n\nIn particular for the Telephony Gateway this field has the form:\n<pre>{\n \"telephony\": {\n   \"caller_id\": \"+18558363987\"\n }\n}</pre>\nNote: The caller ID field (`caller_id`) will be redacted for Standard\nEdition agents and populated with the caller ID in [E.164\nformat](https://en.wikipedia.org/wiki/E.164) for Enterprise Edition agents.", "type": "object" }, "source": { "description": "The source of this request, e.g., `google`, `facebook`, `slack`. It is set\nby Dialogflow-owned servers.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest" }, "GoogleCloudDialogflowV2beta1WebhookResponse": { "description": "The response message for a webhook call.", "type": "object", "properties": { "fulfillmentText": { "description": "Optional. The text to be shown on the screen. This value is passed directly\nto `QueryResult.fulfillment_text`.", "type": "string" }, "fulfillmentMessages": { "description": "Optional. The collection of rich messages to present to the user. This\nvalue is passed directly to `QueryResult.fulfillment_messages`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" } }, "payload": { "description": "Optional. This value is passed directly to `QueryResult.webhook_payload`.\nSee the related `fulfillment_messages[i].payload field`, which may be used\nas an alternative to this field.\n\nThis field can be used for Actions on Google responses.\nIt should have a structure similar to the JSON message shown here. For more\ninformation, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"google\": {\n    \"expectUserResponse\": true,\n    \"richResponse\": {\n      \"items\": [\n        {\n          \"simpleResponse\": {\n            \"textToSpeech\": \"this is a simple response\"\n          }\n        }\n      ]\n    }\n  }\n}</pre>", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "source": { "type": "string", "description": "Optional. This value is passed directly to `QueryResult.webhook_source`." }, "endInteraction": { "description": "Optional. Indicates that this intent ends an interaction. Some integrations\n(e.g., Actions on Google or Dialogflow phone gateway) use this information\nto close interaction with an end user. Default is false.", "type": "boolean" }, "followupEventInput": { "description": "Optional. Makes the platform immediately invoke another `DetectIntent` call\ninternally with the specified event as input.", "$ref": "GoogleCloudDialogflowV2beta1EventInput" }, "outputContexts": { "description": "Optional. The collection of output contexts. This value is passed directly\nto `QueryResult.output_contexts`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } } }, "id": "GoogleCloudDialogflowV2beta1WebhookResponse" }, "GoogleCloudDialogflowV2IntentMessageSelectItemInfo": { "properties": { "synonyms": { "description": "Optional. A list of synonyms that can also be used to trigger this\nitem in dialog.", "type": "array", "items": { "type": "string" } }, "key": { "description": "Required. A unique key that will be sent back to the agent if this\nresponse is given.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo", "description": "Additional info about the select item for when it is triggered in a\ndialog.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction": { "properties": { "uri": { "description": "Required. The HTTP or HTTPS scheme URI.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction", "description": "Opens the given URI.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageQuickReplies": { "description": "The quick replies response message.", "type": "object", "properties": { "quickReplies": { "description": "Optional. The collection of quick replies.", "type": "array", "items": { "type": "string" } }, "title": { "description": "Optional. The title of the collection of quick replies.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageQuickReplies" }, "GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse": { "id": "GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse", "description": "The response message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "entityTypes": { "description": "The collection of updated or created entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityType" } } } }, "GoogleCloudDialogflowV2beta1Document": { "id": "GoogleCloudDialogflowV2beta1Document", "description": "A document resource.\n\nNote: resource `projects.agent.knowledgeBases.documents` is deprecated,\nplease use `projects.knowledgeBases.documents` instead.", "type": "object", "properties": { "name": { "description": "The document resource name.\nThe name must be empty when creating a document.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "type": "string" }, "content": { "description": "The raw content of the document. This field is only permitted for\nEXTRACTIVE_QA and FAQ knowledge types.\nNote: This field is in the process of being deprecated, please use\nraw_content instead.", "type": "string" }, "mimeType": { "description": "Required. The MIME type of this document.", "type": "string" }, "knowledgeTypes": { "type": "array", "items": { "type": "string", "enum": ["KNOWLEDGE_TYPE_UNSPECIFIED", "FAQ", "EXTRACTIVE_QA"] }, "enumDescriptions": ["The type is unspecified or arbitrary.", "The document content contains question and answer pairs as either HTML or\nCSV. Typical FAQ HTML formats are parsed accurately, but unusual formats\nmay fail to be parsed.\n\nCSV must have questions in the first column and answers in the second,\nwith no header. Because of this explicit format, they are always parsed\naccurately.", "Documents for which unstructured text is extracted and used for\nquestion answering."], "description": "Required. The knowledge type of document content." }, "rawContent": { "description": "The raw content of the document. This field is only permitted for\nEXTRACTIVE_QA and FAQ knowledge types.", "format": "byte", "type": "string" }, "displayName": { "description": "Required. The display name of the document. The name must be 1024 bytes or\nless; otherwise, the creation request fails.", "type": "string" }, "contentUri": { "description": "The URI where the file content is located.\n\nFor documents stored in Google Cloud Storage, these URIs must have\nthe form `gs://<bucket-name>/<object-name>`.\n\nNOTE: External URLs must correspond to public webpages, i.e., they must\nbe indexed by Google Search. In particular, URLs for showing documents in\nGoogle Cloud Storage (i.e. the URL in your browser) are not supported.\nInstead use the `gs://` format URI described above.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1EntityType": { "type": "object", "properties": { "entities": { "description": "Optional. The collection of entities associated with the entity type.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityTypeEntity" } }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of the entity type. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "type": "string" }, "displayName": { "description": "Required. The name of the entity type.", "type": "string" }, "kind": { "type": "string", "enumDescriptions": ["Not specified. This value should be never used.", "Map entity types allow mapping of a group of synonyms to a canonical\nvalue.", "List entity types contain a set of entries that do not map to canonical\nvalues. However, list entity types can contain references to other entity\ntypes (with or without aliases)."], "enum": ["KIND_UNSPECIFIED", "KIND_MAP", "KIND_LIST"], "description": "Required. Indicates the kind of entity type." }, "autoExpansionMode": { "enumDescriptions": ["Auto expansion disabled for the entity.", "Allows an agent to recognize values that have not been explicitly\nlisted in the entity."], "enum": ["AUTO_EXPANSION_MODE_UNSPECIFIED", "AUTO_EXPANSION_MODE_DEFAULT"], "description": "Optional. Indicates whether the entity type can be automatically\nexpanded.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1EntityType", "description": "Represents an entity type.\nEntity types serve as a tool for extracting parameter values from natural\nlanguage queries." }, "GoogleCloudDialogflowV2beta1QueryParameters": { "description": "Represents the parameters of the conversational query.", "type": "object", "properties": { "timeZone": { "description": "Optional. The time zone of this conversational query from the\n[time zone database](https://www.iana.org/time-zones), e.g.,\nAmerica/New_York, Europe/Paris. If not provided, the time zone specified in\nagent settings is used.", "type": "string" }, "sessionEntityTypes": { "description": "Optional. Additional session entity types to replace or extend developer\nentity types with. The entity synonyms apply to all languages and persist\nfor the session of this query.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" } }, "payload": { "description": "Optional. This field can be used to pass custom data into the webhook\nassociated with the agent. Arbitrary JSON objects are supported.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "geoLocation": { "$ref": "GoogleTypeLatLng", "description": "Optional. The geo location of this conversational query." }, "resetContexts": { "description": "Optional. Specifies whether to delete all contexts in the current session\nbefore the new ones are activated.", "type": "boolean" }, "contexts": { "description": "Optional. The collection of contexts to be activated before this query is\nexecuted.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "knowledgeBaseNames": { "description": "Optional. KnowledgeBases to get alternative results from. If not set, the\nKnowledgeBases enabled in the agent (through UI) will be used.\nFormat:  `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "type": "array", "items": { "type": "string" } }, "sentimentAnalysisRequestConfig": { "$ref": "GoogleCloudDialogflowV2beta1SentimentAnalysisRequestConfig", "description": "Optional. Configures the type of sentiment analysis to perform. If not\nprovided, sentiment analysis is not performed.\nNote: Sentiment Analysis is only currently available for Enterprise Edition\nagents." } }, "id": "GoogleCloudDialogflowV2beta1QueryParameters" }, "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse": { "description": "The simple response message containing speech or text.", "type": "object", "properties": { "textToSpeech": { "type": "string", "description": "One of text_to_speech or ssml must be provided. The plain text of the\nspeech output. Mutually exclusive with ssml." }, "ssml": { "description": "One of text_to_speech or ssml must be provided. Structured spoken\nresponse to the user in the SSML format. Mutually exclusive with\ntext_to_speech.", "type": "string" }, "displayText": { "type": "string", "description": "Optional. The text to display." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse" }, "GoogleCloudDialogflowV2beta1SessionEntityType": { "description": "Represents a session entity type.\n\nExtends or replaces a developer entity type at the user session level (we\nrefer to the entity types defined at the agent level as \"developer entity\ntypes\").\n\nNote: session entity types apply to all queries, regardless of the language.", "type": "object", "properties": { "name": { "description": "Required. The unique identifier of this session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/entityTypes/<Entity Type Display Name>`.\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.\n\n`<Entity Type Display Name>` must be the display name of an existing entity\ntype in the same agent that will be overridden or supplemented.", "type": "string" }, "entityOverrideMode": { "type": "string", "enumDescriptions": ["Not specified. This value should be never used.", "The collection of session entities overrides the collection of entities\nin the corresponding developer entity type.", "The collection of session entities extends the collection of entities in\nthe corresponding developer entity type.\n\nNote: Even in this override mode calls to `ListSessionEntityTypes`,\n`GetSessionEntityType`, `CreateSessionEntityType` and\n`UpdateSessionEntityType` only return the additional entities added in\nthis session entity type. If you want to get the supplemented list,\nplease call EntityTypes.GetEntityType on the developer entity type\nand merge."], "enum": ["ENTITY_OVERRIDE_MODE_UNSPECIFIED", "ENTITY_OVERRIDE_MODE_OVERRIDE", "ENTITY_OVERRIDE_MODE_SUPPLEMENT"], "description": "Required. Indicates whether the additional data should override or\nsupplement the developer entity type definition." }, "entities": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityTypeEntity" }, "description": "Required. The collection of entities associated with this session entity\ntype." } }, "id": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "GoogleCloudDialogflowV2beta1ListKnowledgeBasesResponse": { "description": "Response message for KnowledgeBases.ListKnowledgeBases.", "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" }, "knowledgeBases": { "description": "The list of knowledge bases.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" } } }, "id": "GoogleCloudDialogflowV2beta1ListKnowledgeBasesResponse" }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech": { "description": "Synthesizes speech and plays back the synthesized audio to the caller in\nTelephony Gateway.\n\nTelephony Gateway takes the synthesizer settings from\n`DetectIntentResponse.output_audio_config` which can either be set\nat request-level or can come from the agent-level synthesizer config.", "type": "object", "properties": { "text": { "description": "The raw text to be synthesized.", "type": "string" }, "ssml": { "description": "The SSML to be synthesized. For more information, see\n[SSML](https://developers.google.com/actions/reference/ssml).", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech" }, "GoogleCloudDialogflowV2beta1QueryResult": { "description": "Represents the result of conversational query or event processing.", "type": "object", "properties": { "sentimentAnalysisResult": { "description": "The sentiment analysis result, which depends on the\n`sentiment_analysis_request_config` specified in the request.", "$ref": "GoogleCloudDialogflowV2beta1SentimentAnalysisResult" }, "intentDetectionConfidence": { "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.", "format": "float", "type": "number" }, "allRequiredParamsPresent": { "description": "This field is set to:\n- `false` if the matched intent has required parameters and not all of\n   the required parameter values have been collected.\n- `true` if all required parameter values have been collected, or if the\n   matched intent doesn't contain any required parameters.", "type": "boolean" }, "speechRecognitionConfidence": { "description": "The Speech recognition confidence between 0.0 and 1.0. A higher number\nindicates an estimated greater likelihood that the recognized words are\ncorrect. The default of 0.0 is a sentinel value indicating that confidence\nwas not set.\n\nThis field is not guaranteed to be accurate or set. In particular this\nfield isn't set for StreamingDetectIntent since the streaming endpoint has\nseparate confidence estimates per portion of the audio in\nStreamingRecognitionResult.", "format": "float", "type": "number" }, "queryText": { "description": "The original conversational query text:\n- If natural language text was provided as input, `query_text` contains\n  a copy of the input.\n- If natural language speech audio was provided as input, `query_text`\n  contains the speech recognition result. If speech recognizer produced\n  multiple alternatives, a particular one is picked.\n- If an event was provided as input, `query_text` is not set.", "type": "string" }, "diagnosticInfo": { "description": "The free-form diagnostic info. For example, this field\ncould contain webhook call latency.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "outputContexts": { "description": "The collection of output contexts. If applicable,\n`output_contexts.parameters` contains entries with name\n`<parameter name>.original` containing the original parameter values\nbefore the query.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "languageCode": { "description": "The language that was triggered during intent detection.\nSee [Language Support](https://dialogflow.com/docs/reference/language)\nfor a list of the currently supported language codes.", "type": "string" }, "intent": { "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`.", "$ref": "GoogleCloudDialogflowV2beta1Intent" }, "webhookPayload": { "additionalProperties": { "type": "any", "description": "Properties of the object." }, "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `payload` field returned in the webhook response.", "type": "object" }, "fulfillmentMessages": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" }, "description": "The collection of rich messages to present to the user." }, "action": { "description": "The action name from the matched intent.", "type": "string" }, "webhookSource": { "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `source` field returned in the webhook response.", "type": "string" }, "fulfillmentText": { "description": "The text to be pronounced to the user or shown on the screen.", "type": "string" }, "parameters": { "description": "The collection of extracted parameters.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "knowledgeAnswers": { "description": "The result from Knowledge Connector (if any), ordered by decreasing\n`KnowledgeAnswers.match_confidence`.", "$ref": "GoogleCloudDialogflowV2beta1KnowledgeAnswers" } }, "id": "GoogleCloudDialogflowV2beta1QueryResult" }, "GoogleCloudDialogflowV2beta1TrainAgentRequest": { "description": "The request message for Agents.TrainAgent.", "type": "object", "properties": {}, "id": "GoogleCloudDialogflowV2beta1TrainAgentRequest" }, "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem": { "type": "object", "properties": { "title": { "description": "Required. Title of the carousel item.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage", "description": "Optional. The image to display." }, "description": { "description": "Optional. The body text of the card.", "type": "string" }, "info": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo", "description": "Required. Additional info about the option item." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem", "description": "An item in the carousel." }, "GoogleCloudDialogflowV2Context": { "description": "Represents a context.", "type": "object", "properties": { "lifespanCount": { "description": "Optional. The number of conversational query requests after which the\ncontext expires. If set to `0` (the default) the context expires\nimmediately. Contexts expire automatically after 20 minutes even if there\nare no matching queries.", "format": "int32", "type": "integer" }, "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.\n\nThe `Context ID` is always converted to lowercase, may only contain\ncharacters in [a-zA-Z0-9_-%] and may be at most 250 bytes long.", "type": "string" }, "parameters": { "additionalProperties": { "type": "any", "description": "Properties of the object." }, "description": "Optional. The collection of parameters associated with this context.\nRefer to [this doc](https://dialogflow.com/docs/actions-and-parameters) for\nsyntax.", "type": "object" } }, "id": "GoogleCloudDialogflowV2Context" }, "GoogleCloudDialogflowV2beta1HumanAgentAssistantEvent": { "id": "GoogleCloudDialogflowV2beta1HumanAgentAssistantEvent", "description": "Represents a notification sent to Cloud Pub/Sub subscribers for\nagent assistant events in a specific conversation.", "type": "object", "properties": { "type": { "description": "Required. The type of the event that this notification refers to.", "type": "string", "enumDescriptions": ["Type not set.", "A new suggestion has been sent.\nThis is fired when a suggestion comes from an agent assistant."], "enum": ["TYPE_UNSPECIFIED", "NEW_SUGGESTION"] }, "conversation": { "description": "Required. The conversation this notification refers to.\nFormat: `projects/<Project ID>/conversations/<Conversation ID>`.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer": { "description": "An answer from Knowledge Connector.", "type": "object", "properties": { "source": { "description": "Indicates which Knowledge Document this answer was extracted from.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "type": "string" }, "answer": { "description": "The piece of text from the `source` knowledge base document that answers\nthis conversational query.", "type": "string" }, "faqQuestion": { "description": "The corresponding FAQ question if the answer was extracted from a FAQ\nDocument, empty otherwise.", "type": "string" }, "matchConfidenceLevel": { "enum": ["MATCH_CONFIDENCE_LEVEL_UNSPECIFIED", "LOW", "MEDIUM", "HIGH"], "description": "The system's confidence level that this knowledge answer is a good match\nfor this conversational query.\nNOTE: The confidence level for a given `<query, answer>` pair may change\nwithout notice, as it depends on models that are constantly being\nimproved. However, it will change less frequently than the confidence\nscore below, and should be preferred for referencing the quality of an\nanswer.", "type": "string", "enumDescriptions": ["Not specified.", "Indicates that the confidence is low.", "Indicates our confidence is medium.", "Indicates our confidence is high."] }, "matchConfidence": { "description": "The system's confidence score that this Knowledge answer is a good match\nfor this converstational query, range from 0.0 (completely uncertain)\nto 1.0 (completely certain).\nNote: The confidence score is likely to vary somewhat (possibly even for\nidentical requests), as the underlying model is under constant\nimprovement, we may deprecate it in the future. We recommend using\n`match_confidence_level` which should be generally more stable.", "format": "float", "type": "number" } }, "id": "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer" }, "GoogleCloudDialogflowV2beta1ListContextsResponse": { "description": "The response message for Contexts.ListContexts.", "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" }, "contexts": { "description": "The list of contexts. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } } }, "id": "GoogleCloudDialogflowV2beta1ListContextsResponse" }, "GoogleCloudDialogflowV2beta1ListEntityTypesResponse": { "description": "The response message for EntityTypes.ListEntityTypes.", "type": "object", "properties": { "entityTypes": { "description": "The list of agent entity types. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1ListEntityTypesResponse" }, "GoogleCloudDialogflowV2beta1ListIntentsResponse": { "properties": { "intents": { "description": "The list of agent intents. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Intent" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1ListIntentsResponse", "description": "The response message for Intents.ListIntents.", "type": "object" }, "GoogleCloudDialogflowV2beta1BatchDeleteEntityTypesRequest": { "description": "The request message for EntityTypes.BatchDeleteEntityTypes.", "type": "object", "properties": { "entityTypeNames": { "description": "Required. The names entity types to delete. All names must point to the\nsame agent as `parent`.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2beta1BatchDeleteEntityTypesRequest" }, "GoogleCloudDialogflowV2BatchUpdateIntentsResponse": { "description": "The response message for Intents.BatchUpdateIntents.", "type": "object", "properties": { "intents": { "description": "The collection of updated or created intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" } } }, "id": "GoogleCloudDialogflowV2BatchUpdateIntentsResponse" }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction": { "description": "Opens the given URI.", "type": "object", "properties": { "uri": { "description": "Required. The HTTP or HTTPS scheme URI.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction" }, "GoogleCloudDialogflowV2IntentMessage": { "description": "Corresponds to the `Response` field in the Dialogflow console.", "type": "object", "properties": { "basicCard": { "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCard", "description": "The basic card response for Actions on Google." }, "carouselSelect": { "description": "The carousel card response for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageCarouselSelect" }, "linkOutSuggestion": { "description": "The link out suggestion chip for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion" }, "simpleResponses": { "description": "The voice and text-only responses for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageSimpleResponses" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "The image response." }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Returns a response containing a custom, platform-specific payload.\nSee the Intent.Message.Platform type for a description of the\nstructure that may be required for your platform.", "type": "object" }, "text": { "description": "The text response.", "$ref": "GoogleCloudDialogflowV2IntentMessageText" }, "platform": { "description": "Optional. The platform that this message is intended for.", "type": "string", "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>"], "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE"] }, "suggestions": { "description": "The suggestion chips for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageSuggestions" }, "listSelect": { "$ref": "GoogleCloudDialogflowV2IntentMessageListSelect", "description": "The list card response for Actions on Google." }, "quickReplies": { "description": "The quick replies response.", "$ref": "GoogleCloudDialogflowV2IntentMessageQuickReplies" }, "card": { "$ref": "GoogleCloudDialogflowV2IntentMessageCard", "description": "The card response." } }, "id": "GoogleCloudDialogflowV2IntentMessage" }, "GoogleCloudDialogflowV2IntentMessageBasicCard": { "description": "The basic card message. Useful for displaying information.", "type": "object", "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "Optional. The image for the card." }, "formattedText": { "description": "Required, unless image is present. The body text of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageBasicCard" }, "GoogleCloudDialogflowV2beta1Sentiment": { "type": "object", "properties": { "score": { "description": "Sentiment score between -1.0 (negative sentiment) and 1.0 (positive\nsentiment).", "format": "float", "type": "number" }, "magnitude": { "description": "A non-negative number in the [0, +inf) range, which represents the absolute\nmagnitude of sentiment, regardless of score (positive or negative).", "format": "float", "type": "number" } }, "id": "GoogleCloudDialogflowV2beta1Sentiment", "description": "The sentiment, such as positive/negative feeling or association, for a unit\nof analysis, such as the query text." }, "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse": { "description": "The response message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "entityTypes": { "description": "The collection of updated or created entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" } } }, "id": "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse" }, "GoogleCloudDialogflowV2beta1Intent": { "properties": { "displayName": { "type": "string", "description": "Required. The name of this intent." }, "rootFollowupIntentName": { "description": "Read-only. The unique identifier of the root intent in the chain of\nfollowup intents. It identifies the correct followup intents chain for\nthis intent. We populate this field only in the output.\n\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "mlDisabled": { "type": "boolean", "description": "Optional. Indicates whether Machine Learning is disabled for the intent.\nNote: If `ml_disabled` setting is set to true, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off." }, "isFallback": { "description": "Optional. Indicates whether this is a fallback intent.", "type": "boolean" }, "mlEnabled": { "description": "Optional. Indicates whether Machine Learning is enabled for the intent.\nNote: If `ml_enabled` setting is set to false, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off.\nDEPRECATED! Please use `ml_disabled` field instead.\nNOTE: If both `ml_enabled` and `ml_disabled` are either not set or false,\nthen the default value is determined as follows:\n- Before April 15th, 2018 the default is:\n  ml_enabled = false / ml_disabled = true.\n- After April 15th, 2018 the default is:\n  ml_enabled = true / ml_disabled = false.", "type": "boolean" }, "parameters": { "description": "Optional. The collection of parameters associated with the intent.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentParameter" } }, "resetContexts": { "description": "Optional. Indicates whether to delete all contexts in the current\nsession when this intent is matched.", "type": "boolean" }, "trainingPhrases": { "description": "Optional. The collection of examples/templates that the agent is\ntrained on.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentTrainingPhrase" } }, "parentFollowupIntentName": { "description": "Read-only after creation. The unique identifier of the parent intent in the\nchain of followup intents. You can set this field when creating an intent,\nfor example with CreateIntent or BatchUpdateIntents, in order to\nmake this intent a followup intent.\n\nIt identifies the parent followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "events": { "description": "Optional. The collection of event names that trigger the intent.\nIf the collection of input contexts is not empty, all of the contexts must\nbe present in the active user session for an event to trigger this intent.", "type": "array", "items": { "type": "string" } }, "priority": { "description": "Optional. The priority of this intent. Higher numbers represent higher\npriorities. If this is zero or unspecified, we use the default\npriority 500000.\n\nNegative numbers mean that the intent is disabled.", "format": "int32", "type": "integer" }, "endInteraction": { "description": "Optional. Indicates that this intent ends an interaction. Some integrations\n(e.g., Actions on Google or Dialogflow phone gateway) use this information\nto close interaction with an end user. Default is false.", "type": "boolean" }, "outputContexts": { "description": "Optional. The collection of contexts that are activated when the intent\nis matched. Context messages in this collection should not set the\nparameters field. Setting the `lifespan_count` to 0 will reset the context\nwhen the intent is matched.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "defaultResponsePlatforms": { "description": "Optional. The list of platforms for which the first response will be\ntaken from among the messages assigned to the DEFAULT_PLATFORM.", "type": "array", "items": { "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "TELEPHONY"], "type": "string" }, "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>", "Telephony Gateway."] }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of this intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "action": { "description": "Optional. The name of the action associated with the intent.\nNote: The action name must not contain whitespaces.", "type": "string" }, "messages": { "description": "Optional. The collection of rich messages corresponding to the\n`Response` field in the Dialogflow console.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" } }, "inputContextNames": { "type": "array", "items": { "type": "string" }, "description": "Optional. The list of context names required for this intent to be\ntriggered.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`." }, "webhookState": { "type": "string", "enumDescriptions": ["Webhook is disabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent. Also, each slot\nfilling prompt is forwarded to the webhook."], "enum": ["WEBHOOK_STATE_UNSPECIFIED", "WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"], "description": "Optional. Indicates whether webhooks are enabled for the intent." }, "followupIntentInfo": { "description": "Read-only. Information about all followup intents that have this intent as\na direct or indirect parent. We populate this field only in the output.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo" } } }, "id": "GoogleCloudDialogflowV2beta1Intent", "description": "Represents an intent.\nIntents convert a number of user expressions or patterns into an action. An\naction is an extraction of a user command or sentence semantics.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageSuggestion": { "id": "GoogleCloudDialogflowV2IntentMessageSuggestion", "description": "The suggestion chip message that the user can tap to quickly post a reply\nto the conversation.", "type": "object", "properties": { "title": { "description": "Required. The text shown the in the suggestion chip.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart": { "type": "object", "properties": { "entityType": { "description": "Optional. The entity type name prefixed with `@`. This field is\nrequired for the annotated part of the text and applies only to\nexamples.", "type": "string" }, "alias": { "description": "Optional. The parameter name for the value extracted from the\nannotated part of the example.", "type": "string" }, "userDefined": { "description": "Optional. Indicates whether the text was manually annotated by the\ndeveloper.", "type": "boolean" }, "text": { "type": "string", "description": "Required. The text corresponding to the example or template,\nif there are no annotations. For\nannotated examples, it is the text for one of the example's parts." } }, "id": "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart", "description": "Represents a part of a training phrase." }, "GoogleCloudDialogflowV2beta1KnowledgeBase": { "id": "GoogleCloudDialogflowV2beta1KnowledgeBase", "description": "Represents knowledge base resource.\n\nNote: resource `projects.agent.knowledgeBases` is deprecated, please use\n`projects.knowledgeBases` instead.", "type": "object", "properties": { "displayName": { "description": "Required. The display name of the knowledge base. The name must be 1024\nbytes or less; otherwise, the creation request fails.", "type": "string" }, "name": { "description": "The knowledge base resource name.\nThe name must be empty when creating a knowledge base.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1EventInput": { "description": "Events allow for matching intents by event name instead of the natural\nlanguage input. For instance, input `<event: { name: “welcome_event”,\nparameters: { name: “Sam” } }>` can trigger a personalized welcome response.\nThe parameter `name` may be used by the agent in the response:\n`“Hello #welcome_event.name! What can I do for you today?”`.", "type": "object", "properties": { "languageCode": { "description": "Required. The language of this query. See [Language\nSupport](https://dialogflow.com/docs/languages) for a list of the\ncurrently supported language codes. Note that queries in the same session\ndo not necessarily need to specify the same language.", "type": "string" }, "name": { "description": "Required. The unique identifier of the event.", "type": "string" }, "parameters": { "additionalProperties": { "type": "any", "description": "Properties of the object." }, "description": "Optional. The collection of parameters associated with the event.", "type": "object" } }, "id": "GoogleCloudDialogflowV2beta1EventInput" }, "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem": { "description": "An item in the list.", "type": "object", "properties": { "title": { "type": "string", "description": "Required. The title of the list item." }, "image": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage", "description": "Optional. The image to display." }, "description": { "description": "Optional. The main text describing the item.", "type": "string" }, "info": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo", "description": "Required. Additional information about this option." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem" }, "GoogleCloudDialogflowV2IntentTrainingPhrasePart": { "id": "GoogleCloudDialogflowV2IntentTrainingPhrasePart", "description": "Represents a part of a training phrase.", "type": "object", "properties": { "alias": { "description": "Optional. The parameter name for the value extracted from the\nannotated part of the example.", "type": "string" }, "userDefined": { "description": "Optional. Indicates whether the text was manually annotated by the\ndeveloper.", "type": "boolean" }, "text": { "description": "Required. The text corresponding to the example or template,\nif there are no annotations. For\nannotated examples, it is the text for one of the example's parts.", "type": "string" }, "entityType": { "description": "Optional. The entity type name prefixed with `@`. This field is\nrequired for the annotated part of the text and applies only to\nexamples.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata": { "description": "Metadata in google::longrunning::Operation for Knowledge operations.", "type": "object", "properties": { "state": { "description": "Required. The current state of this operation.", "type": "string", "enumDescriptions": ["State unspecified.", "The operation has been created.", "The operation is currently running.", "The operation is done, either cancelled or completed."], "enum": ["STATE_UNSPECIFIED", "PENDING", "RUNNING", "DONE"] } }, "id": "GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata" }, "GoogleCloudDialogflowV2beta1IntentMessage": { "properties": { "telephonyTransferCall": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall", "description": "Transfers the call in Telephony Gateway." }, "image": { "description": "Displays an image.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage" }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Returns a response containing a custom, platform-specific payload.\nSee the Intent.Message.Platform type for a description of the\nstructure that may be required for your platform.", "type": "object" }, "text": { "description": "Returns a text response.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageText" }, "suggestions": { "description": "Displays suggestion chips for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSuggestions" }, "platform": { "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "TELEPHONY"], "description": "Optional. The platform that this message is intended for.", "type": "string", "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>", "Telephony Gateway."] }, "telephonyPlayAudio": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio", "description": "Plays audio from a file in Telephony Gateway." }, "listSelect": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageListSelect", "description": "Displays a list card for Actions on Google." }, "quickReplies": { "description": "Displays quick replies.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies" }, "telephonySynthesizeSpeech": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech", "description": "Synthesizes speech in Telephony Gateway." }, "card": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCard", "description": "Displays a card." }, "basicCard": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCard", "description": "Displays a basic card for Actions on Google." }, "carouselSelect": { "description": "Displays a carousel card for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect" }, "linkOutSuggestion": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion", "description": "Displays a link out suggestion chip for Actions on Google." }, "simpleResponses": { "description": "Returns a voice or text-only response for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessage", "description": "Corresponds to the `Response` field in the Dialogflow console.", "type": "object" }, "GoogleCloudDialogflowV2Intent": { "type": "object", "properties": { "outputContexts": { "description": "Optional. The collection of contexts that are activated when the intent\nis matched. Context messages in this collection should not set the\nparameters field. Setting the `lifespan_count` to 0 will reset the context\nwhen the intent is matched.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "defaultResponsePlatforms": { "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>"], "description": "Optional. The list of platforms for which the first response will be\ntaken from among the messages assigned to the DEFAULT_PLATFORM.", "type": "array", "items": { "type": "string", "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE"] } }, "action": { "description": "Optional. The name of the action associated with the intent.\nNote: The action name must not contain whitespaces.", "type": "string" }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of this intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "messages": { "description": "Optional. The collection of rich messages corresponding to the\n`Response` field in the Dialogflow console.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "webhookState": { "enumDescriptions": ["Webhook is disabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent. Also, each slot\nfilling prompt is forwarded to the webhook."], "enum": ["WEBHOOK_STATE_UNSPECIFIED", "WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"], "description": "Optional. Indicates whether webhooks are enabled for the intent.", "type": "string" }, "inputContextNames": { "type": "array", "items": { "type": "string" }, "description": "Optional. The list of context names required for this intent to be\ntriggered.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`." }, "followupIntentInfo": { "description": "Read-only. Information about all followup intents that have this intent as\na direct or indirect parent. We populate this field only in the output.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentFollowupIntentInfo" } }, "rootFollowupIntentName": { "description": "Read-only. The unique identifier of the root intent in the chain of\nfollowup intents. It identifies the correct followup intents chain for\nthis intent. We populate this field only in the output.\n\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "displayName": { "description": "Required. The name of this intent.", "type": "string" }, "mlDisabled": { "description": "Optional. Indicates whether Machine Learning is disabled for the intent.\nNote: If `ml_diabled` setting is set to true, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off.", "type": "boolean" }, "isFallback": { "description": "Optional. Indicates whether this is a fallback intent.", "type": "boolean" }, "trainingPhrases": { "description": "Optional. The collection of examples/templates that the agent is\ntrained on.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentTrainingPhrase" } }, "resetContexts": { "description": "Optional. Indicates whether to delete all contexts in the current\nsession when this intent is matched.", "type": "boolean" }, "parameters": { "description": "Optional. The collection of parameters associated with the intent.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentParameter" } }, "events": { "description": "Optional. The collection of event names that trigger the intent.\nIf the collection of input contexts is not empty, all of the contexts must\nbe present in the active user session for an event to trigger this intent.", "type": "array", "items": { "type": "string" } }, "parentFollowupIntentName": { "description": "Read-only after creation. The unique identifier of the parent intent in the\nchain of followup intents. You can set this field when creating an intent,\nfor example with CreateIntent or BatchUpdateIntents, in order to\nmake this intent a followup intent.\n\nIt identifies the parent followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "priority": { "description": "Optional. The priority of this intent. Higher numbers represent higher\npriorities. If this is zero or unspecified, we use the default\npriority 500000.\n\nNegative numbers mean that the intent is disabled.", "format": "int32", "type": "integer" } }, "id": "GoogleCloudDialogflowV2Intent", "description": "Represents an intent.\nIntents convert a number of user expressions or patterns into an action. An\naction is an extraction of a user command or sentence semantics." }, "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion": { "description": "The suggestion chip message that allows the user to jump out to the app\nor website associated with this agent.", "type": "object", "properties": { "destinationName": { "description": "Required. The name of the app or site this chip is linking to.", "type": "string" }, "uri": { "description": "Required. The URI of the app or site to open when the user taps the\nsuggestion chip.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion" }, "GoogleCloudDialogflowV2beta1IntentParameter": { "description": "Represents intent parameters.", "type": "object", "properties": { "name": { "description": "The unique identifier of this parameter.", "type": "string" }, "isList": { "description": "Optional. Indicates whether the parameter represents a list of values.", "type": "boolean" }, "value": { "description": "Optional. The definition of the parameter value. It can be:\n- a constant string,\n- a parameter value defined as `$parameter_name`,\n- an original parameter value defined as `$parameter_name.original`,\n- a parameter value from some context defined as\n  `#context_name.parameter_name`.", "type": "string" }, "displayName": { "description": "Required. The name of the parameter.", "type": "string" }, "entityTypeDisplayName": { "description": "Optional. The name of the entity type, prefixed with `@`, that\ndescribes values of the parameter. If the parameter is\nrequired, this must be provided.", "type": "string" }, "prompts": { "description": "Optional. The collection of prompts that the agent can present to the\nuser in order to collect value for the parameter.", "type": "array", "items": { "type": "string" } }, "defaultValue": { "description": "Optional. The default value to use when the `value` yields an empty\nresult.\nDefault values can be extracted from contexts by using the following\nsyntax: `#context_name.parameter_name`.", "type": "string" }, "mandatory": { "description": "Optional. Indicates whether the parameter is required. That is,\nwhether the intent cannot be completed without collecting the parameter\nvalue.", "type": "boolean" } }, "id": "GoogleCloudDialogflowV2beta1IntentParameter" }, "GoogleCloudDialogflowV2IntentParameter": { "properties": { "name": { "description": "The unique identifier of this parameter.", "type": "string" }, "isList": { "description": "Optional. Indicates whether the parameter represents a list of values.", "type": "boolean" }, "value": { "description": "Optional. The definition of the parameter value. It can be:\n- a constant string,\n- a parameter value defined as `$parameter_name`,\n- an original parameter value defined as `$parameter_name.original`,\n- a parameter value from some context defined as\n  `#context_name.parameter_name`.", "type": "string" }, "displayName": { "description": "Required. The name of the parameter.", "type": "string" }, "entityTypeDisplayName": { "description": "Optional. The name of the entity type, prefixed with `@`, that\ndescribes values of the parameter. If the parameter is\nrequired, this must be provided.", "type": "string" }, "prompts": { "type": "array", "items": { "type": "string" }, "description": "Optional. The collection of prompts that the agent can present to the\nuser in order to collect value for the parameter." }, "defaultValue": { "description": "Optional. The default value to use when the `value` yields an empty\nresult.\nDefault values can be extracted from contexts by using the following\nsyntax: `#context_name.parameter_name`.", "type": "string" }, "mandatory": { "type": "boolean", "description": "Optional. Indicates whether the parameter is required. That is,\nwhether the intent cannot be completed without collecting the parameter\nvalue." } }, "id": "GoogleCloudDialogflowV2IntentParameter", "description": "Represents intent parameters.", "type": "object" }, "GoogleRpcStatus": { "description": "The `Status` type defines a logical error model that is suitable for different\nprogramming environments, including REST APIs and RPC APIs. It is used by\n[gRPC](https://github.com/grpc). The error model is designed to be:\n\n- Simple to use and understand for most users\n- Flexible enough to meet unexpected needs\n\n# Overview\n\nThe `Status` message contains three pieces of data: error code, error message,\nand error details. The error code should be an enum value of\ngoogle.rpc.Code, but it may accept additional error codes if needed.  The\nerror message should be a developer-facing English message that helps\ndevelopers *understand* and *resolve* the error. If a localized user-facing\nerror message is needed, put the localized message in the error details or\nlocalize it in the client. The optional error details may contain arbitrary\ninformation about the error. There is a predefined set of error detail types\nin the package `google.rpc` that can be used for common error conditions.\n\n# Language mapping\n\nThe `Status` message is the logical representation of the error model, but it\nis not necessarily the actual wire format. When the `Status` message is\nexposed in different client libraries and different wire protocols, it can be\nmapped differently. For example, it will likely be mapped to some exceptions\nin Java, but more likely mapped to some error codes in C.\n\n# Other uses\n\nThe error model and the `Status` message can be used in a variety of\nenvironments, either with or without APIs, to provide a\nconsistent developer experience across different environments.\n\nExample uses of this error model include:\n\n- Partial errors. If a service needs to return partial errors to the client,\n    it may embed the `Status` in the normal response to indicate the partial\n    errors.\n\n- Workflow errors. A typical workflow has multiple steps. Each step may\n    have a `Status` message for error reporting.\n\n- Batch operations. If a client uses batch request and batch response, the\n    `Status` message should be used directly inside batch response, one for\n    each error sub-response.\n\n- Asynchronous operations. If an API call embeds asynchronous operation\n    results in its response, the status of those operations should be\n    represented directly using the `Status` message.\n\n- Logging. If some API errors are stored in logs, the message `Status` could\n    be used directly after any stripping needed for security/privacy reasons.", "type": "object", "properties": { "message": { "description": "A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.", "type": "string" }, "details": { "description": "A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.", "type": "array", "items": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "type": "object" } }, "code": { "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32", "type": "integer" } }, "id": "GoogleRpcStatus" }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCard": { "description": "The basic card message. Useful for displaying information.", "type": "object", "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "image": { "description": "Optional. The image for the card.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage" }, "formattedText": { "description": "Required, unless image is present. The body text of the card.", "type": "string" }, "buttons": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton" }, "description": "Optional. The collection of card buttons." }, "subtitle": { "type": "string", "description": "Optional. The subtitle of the card." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCard" }, "GoogleCloudDialogflowV2IntentMessageCard": { "description": "The card response message.", "type": "object", "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "buttons": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageCardButton" }, "description": "Optional. The collection of card buttons." }, "subtitle": { "type": "string", "description": "Optional. The subtitle of the card." }, "imageUri": { "description": "Optional. The public URI to an image file for the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageCard" }, "GoogleCloudDialogflowV2beta1ExportAgentRequest": { "id": "GoogleCloudDialogflowV2beta1ExportAgentRequest", "description": "The request message for Agents.ExportAgent.", "type": "object", "properties": { "agentUri": { "description": "Optional. The\n[Google Cloud Storage](https://cloud.google.com/storage/docs/)\nURI to export the agent to.\nThe format of this URI must be `gs://<bucket-name>/<object-name>`.\nIf left unspecified, the serialized agent is returned inline.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1IntentMessageListSelect": { "type": "object", "properties": { "items": { "description": "Required. List items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem" } }, "title": { "description": "Optional. The overall title of the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageListSelect", "description": "The card for presenting a list of options to select from." }, "GoogleCloudDialogflowV2IntentMessageBasicCardButton": { "description": "The button object that appears at the bottom of a card.", "type": "object", "properties": { "title": { "type": "string", "description": "Required. The title of the button." }, "openUriAction": { "description": "Required. Action to take when a user taps on the button.", "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction" } }, "id": "GoogleCloudDialogflowV2IntentMessageBasicCardButton" }, "GoogleCloudDialogflowV2beta1IntentBatch": { "description": "This message is a wrapper around a collection of intents.", "type": "object", "properties": { "intents": { "description": "A collection of intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Intent" } } }, "id": "GoogleCloudDialogflowV2beta1IntentBatch" }, "GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse": { "properties": { "intents": { "description": "The collection of updated or created intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Intent" } } }, "id": "GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse", "description": "The response message for Intents.BatchUpdateIntents.", "type": "object" }, "GoogleCloudDialogflowV2beta1Context": { "description": "Represents a context.", "type": "object", "properties": { "lifespanCount": { "description": "Optional. The number of conversational query requests after which the\ncontext expires. If set to `0` (the default) the context expires\nimmediately. Contexts expire automatically after 10 minutes even if there\nare no matching queries.", "format": "int32", "type": "integer" }, "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`,\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`.\n\nThe `Context ID` is always converted to lowercase, may only contain\ncharacters in a-zA-Z0-9_-% and may be at most 250 bytes long.\n\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. The collection of parameters associated with this context.\nRefer to [this doc](https://dialogflow.com/docs/actions-and-parameters) for\nsyntax.", "type": "object" } }, "id": "GoogleCloudDialogflowV2beta1Context" }, "GoogleCloudDialogflowV2beta1ListDocumentsResponse": { "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" }, "documents": { "description": "The list of documents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Document" } } }, "id": "GoogleCloudDialogflowV2beta1ListDocumentsResponse", "description": "Response message for Documents.ListDocuments." }, "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo": { "description": "Additional info about the select item for when it is triggered in a\ndialog.", "type": "object", "properties": { "synonyms": { "description": "Optional. A list of synonyms that can also be used to trigger this\nitem in dialog.", "type": "array", "items": { "type": "string" } }, "key": { "type": "string", "description": "Required. A unique key that will be sent back to the agent if this\nresponse is given." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo" }, "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses": { "properties": { "simpleResponses": { "description": "Required. The list of simple responses.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses", "description": "The collection of simple response candidates.\nThis message in `QueryResult.fulfillment_messages` and\n`WebhookResponse.fulfillment_messages` should contain only one\n`SimpleResponse`.", "type": "object" }, "GoogleCloudDialogflowV2beta1OutputAudioConfig": { "description": "Instructs the speech synthesizer how to generate the output audio content.", "type": "object", "properties": { "sampleRateHertz": { "description": "Optional. The synthesis sample rate (in hertz) for this audio. If not\nprovided, then the synthesizer will use the default sample rate based on\nthe audio encoding. If this is different from the voice's natural sample\nrate, then the synthesizer will honor this request by converting to the\ndesired sample rate (which might result in worse audio quality).", "format": "int32", "type": "integer" }, "audioEncoding": { "enumDescriptions": ["Not specified.", "Uncompressed 16-bit signed little-endian samples (Linear PCM).\nAudio content returned as LINEAR16 also contains a WAV header.", "MP3 audio.", "Opus encoded audio wrapped in an ogg container. The result will be a\nfile which can be played natively on Android, and in browsers (at least\nChrome and Firefox). The quality of the encoding is considerably higher\nthan MP3 while using approximately the same bitrate."], "enum": ["OUTPUT_AUDIO_ENCODING_UNSPECIFIED", "OUTPUT_AUDIO_ENCODING_LINEAR_16", "OUTPUT_AUDIO_ENCODING_MP3", "OUTPUT_AUDIO_ENCODING_OGG_OPUS"], "description": "Required. Audio encoding of the synthesized audio content.", "type": "string" }, "synthesizeSpeechConfig": { "$ref": "GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig", "description": "Optional. Configuration of how speech should be synthesized." } }, "id": "GoogleCloudDialogflowV2beta1OutputAudioConfig" }, "GoogleCloudDialogflowV2beta1TextInput": { "description": "Represents the natural language text to be processed.", "type": "object", "properties": { "languageCode": { "description": "Required. The language of this conversational query. See [Language\nSupport](https://dialogflow.com/docs/languages) for a list of the\ncurrently supported language codes. Note that queries in the same session\ndo not necessarily need to specify the same language.", "type": "string" }, "text": { "description": "Required. The UTF-8 encoded natural language text to be processed.\nText length must not exceed 256 bytes.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1TextInput" }, "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect": { "description": "The card for presenting a carousel of options to select from.", "type": "object", "properties": { "items": { "description": "Required. Carousel items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect" }, "GoogleCloudDialogflowV2beta1EntityTypeBatch": { "type": "object", "properties": { "entityTypes": { "description": "A collection of entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" } } }, "id": "GoogleCloudDialogflowV2beta1EntityTypeBatch", "description": "This message is a wrapper around a collection of entity types." }, "GoogleCloudDialogflowV2beta1BatchDeleteEntitiesRequest": { "description": "The request message for EntityTypes.BatchDeleteEntities.", "type": "object", "properties": { "entityValues": { "description": "Required. The canonical `values` of the entities to delete. Note that\nthese are not fully-qualified names, i.e. they don't start with\n`projects/<Project ID>`.", "type": "array", "items": { "type": "string" } }, "languageCode": { "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1BatchDeleteEntitiesRequest" }, "GoogleCloudDialogflowV2beta1BatchUpdateEntitiesRequest": { "type": "object", "properties": { "entities": { "description": "Required. The entities to update or create.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityTypeEntity" } }, "languageCode": { "type": "string", "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used." }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1BatchUpdateEntitiesRequest", "description": "The request message for EntityTypes.BatchUpdateEntities." }, "GoogleCloudDialogflowV2beta1IntentMessageCard": { "description": "The card response message.", "type": "object", "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" }, "imageUri": { "type": "string", "description": "Optional. The public URI to an image file for the card." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCard" }, "GoogleCloudDialogflowV2EventInput": { "description": "Events allow for matching intents by event name instead of the natural\nlanguage input. For instance, input `<event: { name: “welcome_event”,\nparameters: { name: “Sam” } }>` can trigger a personalized welcome response.\nThe parameter `name` may be used by the agent in the response:\n`“Hello #welcome_event.name! What can I do for you today?”`.", "type": "object", "properties": { "name": { "description": "Required. The unique identifier of the event.", "type": "string" }, "parameters": { "description": "Optional. The collection of parameters associated with the event.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "languageCode": { "description": "Required. The language of this query. See [Language\nSupport](https://dialogflow.com/docs/languages) for a list of the\ncurrently supported language codes. Note that queries in the same session\ndo not necessarily need to specify the same language.", "type": "string" } }, "id": "GoogleCloudDialogflowV2EventInput" }, "GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig": { "description": "Configuration of how speech should be synthesized.", "type": "object", "properties": { "pitch": { "description": "Optional. Speaking pitch, in the range [-20.0, 20.0]. 20 means increase 20\nsemitones from the original pitch. -20 means decrease 20 semitones from the\noriginal pitch.", "format": "double", "type": "number" }, "voice": { "description": "Optional. The desired voice of the synthesized audio.", "$ref": "GoogleCloudDialogflowV2beta1VoiceSelectionParams" }, "speakingRate": { "description": "Optional. Speaking rate/speed, in the range [0.25, 4.0]. 1.0 is the normal\nnative speed supported by the specific voice. 2.0 is twice as fast, and\n0.5 is half as fast. If unset(0.0), defaults to the native 1.0 speed. Any\nother values < 0.25 or > 4.0 will return an error.", "format": "double", "type": "number" }, "effectsProfileId": { "description": "Optional. An identifier which selects 'audio effects' profiles that are\napplied on (post synthesized) text to speech. Effects are applied on top of\neach other in the order they are given.", "type": "array", "items": { "type": "string" } }, "volumeGainDb": { "type": "number", "description": "Optional. Volume gain (in dB) of the normal native volume supported by the\nspecific voice, in the range [-96.0, 16.0]. If unset, or set to a value of\n0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB)\nwill play at approximately half the amplitude of the normal native signal\namplitude. A value of +6.0 (dB) will play at approximately twice the\namplitude of the normal native signal amplitude. We strongly recommend not\nto exceed +10 (dB) as there's usually no effective increase in loudness for\nany value greater than that.", "format": "double" } }, "id": "GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig" }, "GoogleCloudDialogflowV2beta1IntentMessageSuggestion": { "type": "object", "properties": { "title": { "description": "Required. The text shown the in the suggestion chip.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSuggestion", "description": "The suggestion chip message that the user can tap to quickly post a reply\nto the conversation." }, "GoogleCloudDialogflowV2beta1InputAudioConfig": { "type": "object", "properties": { "sampleRateHertz": { "description": "Required. Sample rate (in Hertz) of the audio content sent in the query.\nRefer to\n[Cloud Speech API\ndocumentation](https://cloud.google.com/speech-to-text/docs/basics) for\nmore details.", "format": "int32", "type": "integer" }, "model": { "description": "Optional. Which Speech model to select for the given request. Select the\nmodel best suited to your domain to get best results. If a model is not\nexplicitly specified, then we auto-select a model based on the parameters\nin the InputAudioConfig.\nIf enhanced speech model is enabled for the agent and an enhanced\nversion of the specified model for the language does not exist, then the\nspeech is recognized using the standard version of the specified model.\nRefer to\n[Cloud Speech API\ndocumentation](https://cloud.google.com/speech-to-text/docs/basics#select-model)\nfor more details.", "type": "string" }, "languageCode": { "description": "Required. The language of the supplied audio. Dialogflow does not do\ntranslations. See [Language\nSupport](https://dialogflow.com/docs/languages) for a list of the\ncurrently supported language codes. Note that queries in the same session\ndo not necessarily need to specify the same language.", "type": "string" }, "phraseHints": { "description": "Optional. The collection of phrase hints which are used to boost accuracy\nof speech recognition.\nRefer to\n[Cloud Speech API\ndocumentation](https://cloud.google.com/speech-to-text/docs/basics#phrase-hints)\nfor more details.", "type": "array", "items": { "type": "string" } }, "audioEncoding": { "description": "Required. Audio encoding of the audio content to process.", "type": "string", "enumDescriptions": ["Not specified.", "Uncompressed 16-bit signed little-endian samples (Linear PCM).", "[`FLAC`](https://xiph.org/flac/documentation.html) (Free Lossless Audio\nCodec) is the recommended encoding because it is lossless (therefore\nrecognition is not compromised) and requires only about half the\nbandwidth of `LINEAR16`. `FLAC` stream encoding supports 16-bit and\n24-bit samples, however, not all fields in `STREAMINFO` are supported.", "8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.", "Adaptive Multi-Rate Narrowband codec. `sample_rate_hertz` must be 8000.", "Adaptive Multi-Rate Wideband codec. `sample_rate_hertz` must be 16000.", "Opus encoded audio frames in Ogg container\n([OggOpus](https://wiki.xiph.org/OggOpus)).\n`sample_rate_hertz` must be 16000.", "Although the use of lossy encodings is not recommended, if a very low\nbitrate encoding is required, `OGG_OPUS` is highly preferred over\nSpeex encoding. The [Speex](https://speex.org/) encoding supported by\nDialogflow API has a header byte in each block, as in MIME type\n`audio/x-speex-with-header-byte`.\nIt is a variant of the RTP Speex encoding defined in\n[RFC 5574](https://tools.ietf.org/html/rfc5574).\nThe stream is a sequence of blocks, one block per RTP packet. Each block\nstarts with a byte containing the length of the block, in bytes, followed\nby one or more frames of Speex data, padded to an integral number of\nbytes (octets) as specified in RFC 5574. In other words, each RTP header\nis replaced with a single byte containing the block length. Only Speex\nwideband is supported. `sample_rate_hertz` must be 16000."], "enum": ["AUDIO_ENCODING_UNSPECIFIED", "AUDIO_ENCODING_LINEAR_16", "AUDIO_ENCODING_FLAC", "AUDIO_ENCODING_MULAW", "AUDIO_ENCODING_AMR", "AUDIO_ENCODING_AMR_WB", "AUDIO_ENCODING_OGG_OPUS", "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE"] } }, "id": "GoogleCloudDialogflowV2beta1InputAudioConfig", "description": "Instructs the speech recognizer how to process the audio content." }, "GoogleCloudDialogflowV2beta1IntentTrainingPhrase": { "description": "Represents an example or template that the agent is trained on.", "type": "object", "properties": { "parts": { "description": "Required. The collection of training phrase parts (can be annotated).\nFields: `entity_type`, `alias` and `user_defined` should be populated\nonly for the annotated parts of the training phrase.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart" } }, "name": { "description": "Output only. The unique identifier of this training phrase.", "type": "string" }, "timesAddedCount": { "description": "Optional. Indicates how many times this example or template was added to\nthe intent. Each time a developer adds an existing sample by editing an\nintent or training, this counter is increased.", "format": "int32", "type": "integer" }, "type": { "enum": ["TYPE_UNSPECIFIED", "EXAMPLE", "TEMPLATE"], "description": "Required. The type of the training phrase.", "type": "string", "enumDescriptions": ["Not specified. This value should never be used.", "Examples do not contain @-prefixed entity type names, but example parts\ncan be annotated with entity types.", "Templates are not annotated with entity types, but they can contain\n@-prefixed entity type names as substrings."] } }, "id": "GoogleCloudDialogflowV2beta1IntentTrainingPhrase" }, "GoogleCloudDialogflowV2IntentMessageSuggestions": { "properties": { "suggestions": { "description": "Required. The list of suggested replies.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageSuggestion" } } }, "id": "GoogleCloudDialogflowV2IntentMessageSuggestions", "description": "The collection of suggestions.", "type": "object" }, "GoogleCloudDialogflowV2IntentMessageImage": { "type": "object", "properties": { "imageUri": { "description": "Optional. The public URI to an image file.", "type": "string" }, "accessibilityText": { "description": "Optional. A text description of the image to be used for accessibility,\ne.g., screen readers.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageImage", "description": "The image response message." }, "GoogleCloudDialogflowV2IntentMessageSimpleResponses": { "description": "The collection of simple response candidates.\nThis message in `QueryResult.fulfillment_messages` and\n`WebhookResponse.fulfillment_messages` should contain only one\n`SimpleResponse`.", "type": "object", "properties": { "simpleResponses": { "description": "Required. The list of simple responses.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageSimpleResponse" } } }, "id": "GoogleCloudDialogflowV2IntentMessageSimpleResponses" }, "GoogleCloudDialogflowV2IntentMessageText": { "description": "The text response message.", "type": "object", "properties": { "text": { "type": "array", "items": { "type": "string" }, "description": "Optional. The collection of the agent's responses." } }, "id": "GoogleCloudDialogflowV2IntentMessageText" }, "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion": { "description": "The suggestion chip message that allows the user to jump out to the app\nor website associated with this agent.", "type": "object", "properties": { "destinationName": { "description": "Required. The name of the app or site this chip is linking to.", "type": "string" }, "uri": { "description": "Required. The URI of the app or site to open when the user taps the\nsuggestion chip.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion" }, "GoogleCloudDialogflowV2EntityTypeEntity": { "description": "Optional. Represents an entity.", "type": "object", "properties": { "value": { "description": "Required.\nFor `KIND_MAP` entity types:\n  A canonical name to be used in place of synonyms.\nFor `KIND_LIST` entity types:\n  A string that can contain references to other entity types (with or\n  without aliases).", "type": "string" }, "synonyms": { "description": "Required. A collection of synonyms. For `KIND_LIST` entity types this\nmust contain exactly one synonym equal to `value`.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2EntityTypeEntity" }, "GoogleCloudDialogflowV2QueryResult": { "properties": { "diagnosticInfo": { "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "The free-form diagnostic info. For example, this field\ncould contain webhook call latency." }, "intent": { "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`.", "$ref": "GoogleCloudDialogflowV2Intent" }, "languageCode": { "description": "The language that was triggered during intent detection.\nSee [Language Support](https://dialogflow.com/docs/reference/language)\nfor a list of the currently supported language codes.", "type": "string" }, "outputContexts": { "description": "The collection of output contexts. If applicable,\n`output_contexts.parameters` contains entries with name\n`<parameter name>.original` containing the original parameter values\nbefore the query.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "webhookPayload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `payload` field returned in the webhook response.", "type": "object" }, "fulfillmentMessages": { "description": "The collection of rich messages to present to the user.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "action": { "description": "The action name from the matched intent.", "type": "string" }, "webhookSource": { "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `source` field returned in the webhook response.", "type": "string" }, "fulfillmentText": { "description": "The text to be pronounced to the user or shown on the screen.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "The collection of extracted parameters.", "type": "object" }, "intentDetectionConfidence": { "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.", "format": "float", "type": "number" }, "allRequiredParamsPresent": { "description": "This field is set to:\n- `false` if the matched intent has required parameters and not all of\n   the required parameter values have been collected.\n- `true` if all required parameter values have been collected, or if the\n   matched intent doesn't contain any required parameters.", "type": "boolean" }, "speechRecognitionConfidence": { "description": "The Speech recognition confidence between 0.0 and 1.0. A higher number\nindicates an estimated greater likelihood that the recognized words are\ncorrect. The default of 0.0 is a sentinel value indicating that confidence\nwas not set.\n\nThis field is not guaranteed to be accurate or set. In particular this\nfield isn't set for StreamingDetectIntent since the streaming endpoint has\nseparate confidence estimates per portion of the audio in\nStreamingRecognitionResult.", "format": "float", "type": "number" }, "queryText": { "description": "The original conversational query text:\n- If natural language text was provided as input, `query_text` contains\n  a copy of the input.\n- If natural language speech audio was provided as input, `query_text`\n  contains the speech recognition result. If speech recognizer produced\n  multiple alternatives, a particular one is picked.\n- If an event was provided as input, `query_text` is not set.", "type": "string" } }, "id": "GoogleCloudDialogflowV2QueryResult", "description": "Represents the result of conversational query or event processing.", "type": "object" }, "GoogleCloudDialogflowV2beta1IntentMessageText": { "type": "object", "properties": { "text": { "description": "Optional. The collection of the agent's responses.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageText", "description": "The text response message." }, "GoogleCloudDialogflowV2IntentMessageCarouselSelect": { "description": "The card for presenting a carousel of options to select from.", "type": "object", "properties": { "items": { "description": "Required. Carousel items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem" } } }, "id": "GoogleCloudDialogflowV2IntentMessageCarouselSelect" }, "GoogleTypeLatLng": { "id": "GoogleTypeLatLng", "description": "An object representing a latitude/longitude pair. This is expressed as a pair\nof doubles representing degrees latitude and degrees longitude. Unless\nspecified otherwise, this must conform to the\n<a href=\"http://www.unoosa.org/pdf/icg/2012/template/WGS_84.pdf\">WGS84\nstandard</a>. Values must be within normalized ranges.", "type": "object", "properties": { "latitude": { "description": "The latitude in degrees. It must be in the range [-90.0, +90.0].", "format": "double", "type": "number" }, "longitude": { "type": "number", "description": "The longitude in degrees. It must be in the range [-180.0, +180.0].", "format": "double" } } }, "GoogleCloudDialogflowV2IntentFollowupIntentInfo": { "id": "GoogleCloudDialogflowV2IntentFollowupIntentInfo", "description": "Represents a single followup intent in the chain.", "type": "object", "properties": { "followupIntentName": { "description": "The unique identifier of the followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "parentFollowupIntentName": { "description": "The unique identifier of the followup intent's parent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1IntentMessageSuggestions": { "properties": { "suggestions": { "description": "Required. The list of suggested replies.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSuggestion" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSuggestions", "description": "The collection of suggestions.", "type": "object" }, "GoogleCloudDialogflowV2EntityType": { "properties": { "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of the entity type. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "type": "string" }, "displayName": { "description": "Required. The name of the entity type.", "type": "string" }, "kind": { "description": "Required. Indicates the kind of entity type.", "type": "string", "enumDescriptions": ["Not specified. This value should be never used.", "Map entity types allow mapping of a group of synonyms to a canonical\nvalue.", "List entity types contain a set of entries that do not map to canonical\nvalues. However, list entity types can contain references to other entity\ntypes (with or without aliases)."], "enum": ["KIND_UNSPECIFIED", "KIND_MAP", "KIND_LIST"] }, "autoExpansionMode": { "type": "string", "enumDescriptions": ["Auto expansion disabled for the entity.", "Allows an agent to recognize values that have not been explicitly\nlisted in the entity."], "enum": ["AUTO_EXPANSION_MODE_UNSPECIFIED", "AUTO_EXPANSION_MODE_DEFAULT"], "description": "Optional. Indicates whether the entity type can be automatically\nexpanded." }, "entities": { "description": "Optional. The collection of entities associated with the entity type.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } } }, "id": "GoogleCloudDialogflowV2EntityType", "description": "Represents an entity type.\nEntity types serve as a tool for extracting parameter values from natural\nlanguage queries.", "type": "object" }, "GoogleCloudDialogflowV2beta1ListSessionEntityTypesResponse": { "description": "The response message for SessionEntityTypes.ListSessionEntityTypes.", "type": "object", "properties": { "sessionEntityTypes": { "description": "The list of session entity types. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1ListSessionEntityTypesResponse" }, "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies": { "description": "The quick replies response message.", "type": "object", "properties": { "quickReplies": { "description": "Optional. The collection of quick replies.", "type": "array", "items": { "type": "string" } }, "title": { "type": "string", "description": "Optional. The title of the collection of quick replies." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies" } }, "protocol": "rest", "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "canonicalName": "Dialogflow", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" }, "https://www.googleapis.com/auth/dialogflow": { "description": "View, manage and query your Dialogflow agents" } } } }, "rootUrl": "https://dialogflow.googleapis.com/", "ownerDomain": "google.com", "name": "dialogflow", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Dialogflow API", "ownerName": "Google", "resources": { "projects": { "resources": { "agent": { "methods": { "search": { "response": { "$ref": "GoogleCloudDialogflowV2beta1SearchAgentsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "location": "path", "description": "Required. The project to list agents from.\nFormat: `projects/<Project ID or '-'>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" }, "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" } }, "flatPath": "v2beta1/projects/{projectsId}/agent:search", "path": "v2beta1/{+parent}/agent:search", "id": "dialogflow.projects.agent.search", "description": "Returns the list of agents.\n\nSince there is at most one conversational agent per project, this method is\nuseful primarily for listing all agents across projects the caller has\naccess to. One can achieve that with a wildcard project collection id \"-\".\nRefer to [List\nSub-Collections](https://cloud.google.com/apis/design/design_patterns#list_sub-collections)." }, "train": { "description": "Trains the specified agent.\n\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2beta1TrainAgentRequest" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "description": "Required. The project that the agent to train is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent:train", "id": "dialogflow.projects.agent.train", "path": "v2beta1/{+parent}/agent:train" }, "export": { "flatPath": "v2beta1/projects/{projectsId}/agent:export", "path": "v2beta1/{+parent}/agent:export", "id": "dialogflow.projects.agent.export", "request": { "$ref": "GoogleCloudDialogflowV2beta1ExportAgentRequest" }, "description": "Exports the specified agent to a ZIP file.\n\n\nOperation <response: ExportAgentResponse,\n           metadata: google.protobuf.Struct>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "location": "path", "description": "Required. The project that the agent to export is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" } } }, "restore": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The project that the agent to restore is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent:restore", "path": "v2beta1/{+parent}/agent:restore", "id": "dialogflow.projects.agent.restore", "description": "Restores the specified agent from a ZIP file.\n\nReplaces the current agent version with a new one. All the intents and\nentity types in the older version are deleted.\n\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2beta1RestoreAgentRequest" } }, "import": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "location": "path", "description": "Required. The project that the agent to import is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/agent:import", "path": "v2beta1/{+parent}/agent:import", "id": "dialogflow.projects.agent.import", "request": { "$ref": "GoogleCloudDialogflowV2beta1ImportAgentRequest" }, "description": "Imports the specified agent from a ZIP file.\n\nUploads new intents and entity types without deleting the existing ones.\nIntents and entity types with the same name are replaced with the new\nversions from ImportAgentRequest.\n\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>" } }, "resources": { "sessions": { "methods": { "deleteContexts": { "description": "Deletes all active contexts in the specified session.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["parent"], "httpMethod": "DELETE", "parameters": { "parent": { "location": "path", "description": "Required. The name of the session to delete all contexts from. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>` or `projects/<Project\nID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session\nID>`. If `Environment ID` is not specified we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/contexts", "path": "v2beta1/{+parent}/contexts", "id": "dialogflow.projects.agent.sessions.deleteContexts" }, "detectIntent": { "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}:detectIntent", "path": "v2beta1/{+session}:detectIntent", "id": "dialogflow.projects.agent.sessions.detectIntent", "description": "Processes a natural language query and returns structured, actionable data\nas a result. This method is not idempotent, because it may cause contexts\nand session entity types to be updated, which in turn might affect\nresults of future queries.", "request": { "$ref": "GoogleCloudDialogflowV2beta1DetectIntentRequest" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1DetectIntentResponse" }, "parameterOrder": ["session"], "httpMethod": "POST", "parameters": { "session": { "location": "path", "description": "Required. The name of the session this query is sent to. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we are using\n\"-\". It’s up to the API caller to choose an appropriate `Session ID` and\n`User Id`. They can be a random numbers or some type of user and session\nidentifiers (preferably hashed). The length of the `Session ID` and\n`User ID` must not exceed 36 characters.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] } }, "resources": { "contexts": { "methods": { "delete": { "description": "Deletes the specified context.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "location": "path", "description": "Required. The name of the context to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`. If `Environment ID` is\nnot specified, we assume default 'draft' environment. If `User ID` is not\nspecified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.delete" }, "list": { "description": "Returns the list of all contexts in the specified session.", "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "GoogleCloudDialogflowV2beta1ListContextsResponse" }, "parameters": { "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer" }, "parent": { "location": "path", "description": "Required. The session to list all contexts from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we assume\ndefault '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/contexts", "id": "dialogflow.projects.agent.sessions.contexts.list", "path": "v2beta1/{+parent}/contexts" }, "get": { "description": "Retrieves the specified context.", "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "Required. The name of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`. If `Environment ID` is\nnot specified, we assume default 'draft' environment. If `User ID` is not\nspecified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.get" }, "patch": { "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`,\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`.\n\nThe `Context ID` is always converted to lowercase, may only contain\ncharacters in a-zA-Z0-9_-% and may be at most 250 bytes long.\n\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.patch", "description": "Updates the specified context.", "request": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "create": { "description": "Creates a context.\n\nIf the specified context already exists, overrides the context.", "request": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameters": { "parent": { "location": "path", "description": "Required. The session to create a context for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we assume\ndefault '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/contexts", "id": "dialogflow.projects.agent.sessions.contexts.create", "path": "v2beta1/{+parent}/contexts" } } }, "entityTypes": { "methods": { "delete": { "description": "Deletes the specified session entity type.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "description": "Required. The name of the entity type to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>` or `projects/<Project ID>/agent/environments/<Environment\nID>/users/<User ID>/sessions/<Session ID>/entityTypes/<Entity Type Display\nName>`. If `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.sessions.entityTypes.delete" }, "list": { "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "GoogleCloudDialogflowV2beta1ListSessionEntityTypesResponse" }, "parameters": { "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "description": "Required. The session to list all session entity types from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/\nsessions/<Session ID>`.\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path" }, "pageToken": { "location": "query", "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes", "id": "dialogflow.projects.agent.sessions.entityTypes.list", "path": "v2beta1/{+parent}/entityTypes", "description": "Returns the list of all session entity types in the specified session." }, "get": { "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.sessions.entityTypes.get", "description": "Retrieves the specified session entity type.", "response": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "Required. The name of the session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>` or `projects/<Project ID>/agent/environments/<Environment\nID>/users/<User ID>/sessions/<Session ID>/entityTypes/<Entity Type Display\nName>`. If `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$" } } }, "patch": { "description": "Updates the specified session entity type.", "request": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "parameters": { "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string", "location": "query" }, "name": { "location": "path", "description": "Required. The unique identifier of this session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/entityTypes/<Entity Type Display Name>`.\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.\n\n`<Entity Type Display Name>` must be the display name of an existing entity\ntype in the same agent that will be overridden or supplemented.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.sessions.entityTypes.patch", "path": "v2beta1/{+name}" }, "create": { "description": "Creates a session entity type.\n\nIf the specified session entity type already exists, overrides the\nsession entity type.", "request": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "parameters": { "parent": { "location": "path", "description": "Required. The session to create a session entity type for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/\nsessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we assume\ndefault '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes", "id": "dialogflow.projects.agent.sessions.entityTypes.create", "path": "v2beta1/{+parent}/entityTypes" } } } } }, "knowledgeBases": { "methods": { "delete": { "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "force": { "description": "Optional. Force deletes the knowledge base. When set to true, any documents\nin the knowledge base are also deleted.", "type": "boolean", "location": "query" }, "name": { "location": "path", "description": "Required. The name of the knowledge base to delete.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.knowledgeBases.delete", "description": "Deletes the specified knowledge base." }, "list": { "description": "Returns the list of all knowledge bases of the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2beta1ListKnowledgeBasesResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" }, "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 10 and at most 100.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "description": "Required. The project to list of knowledge bases for.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" } }, "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases", "path": "v2beta1/{+parent}/knowledgeBases", "id": "dialogflow.projects.agent.knowledgeBases.list" }, "get": { "description": "Retrieves the specified knowledge base.", "response": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "description": "Required. The name of the knowledge base to retrieve.\nFormat `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.knowledgeBases.get" }, "patch": { "description": "Updates the specified knowledge base.", "request": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "updateMask": { "description": "Optional. Not specified means `update all`.\nCurrently, only `display_name` can be updated, an InvalidArgument will be\nreturned for attempting to update other fields.", "format": "google-fieldmask", "type": "string", "location": "query" }, "name": { "location": "path", "description": "The knowledge base resource name.\nThe name must be empty when creating a knowledge base.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.knowledgeBases.patch" }, "create": { "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases", "path": "v2beta1/{+parent}/knowledgeBases", "id": "dialogflow.projects.agent.knowledgeBases.create", "description": "Creates a knowledge base.", "request": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The project to create a knowledge base for.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] } }, "resources": { "documents": { "methods": { "reload": { "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}:reload", "path": "v2beta1/{+name}:reload", "id": "dialogflow.projects.agent.knowledgeBases.documents.reload", "description": "Reloads the specified document from its specified source, content_uri or\ncontent. The previously loaded content of the document will be deleted.\nNote: Even when the content of the document has not changed, there still\nmay be side effects because of internal implementation changes.\nOperation <response: Document,\n           metadata: KnowledgeOperationMetadata>", "request": { "$ref": "GoogleCloudDialogflowV2beta1ReloadDocumentRequest" }, "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "description": "The name of the document to reload.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+/documents/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "get": { "description": "Retrieves the specified document.", "httpMethod": "GET", "parameterOrder": ["name"], "response": { "$ref": "GoogleCloudDialogflowV2beta1Document" }, "parameters": { "name": { "location": "path", "description": "Required. The name of the document to retrieve.\nFormat `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+/documents/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}", "id": "dialogflow.projects.agent.knowledgeBases.documents.get", "path": "v2beta1/{+name}" }, "patch": { "request": { "$ref": "GoogleCloudDialogflowV2beta1Document" }, "description": "Updates the specified document.\nOperation <response: Document,\n           metadata: KnowledgeOperationMetadata>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "updateMask": { "description": "Optional. Not specified means `update all`.\nCurrently, only `display_name` can be updated, an InvalidArgument will be\nreturned for attempting to update other fields.", "format": "google-fieldmask", "type": "string", "location": "query" }, "name": { "location": "path", "description": "The document resource name.\nThe name must be empty when creating a document.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+/documents/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.knowledgeBases.documents.patch" }, "delete": { "description": "Deletes the specified document.\n\nOperation <response: google.protobuf.Empty,\n           metadata: KnowledgeOperationMetadata>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "description": "The name of the document to delete.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+/documents/[^/]+$", "location": "path" } }, "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.knowledgeBases.documents.delete" }, "list": { "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents", "path": "v2beta1/{+parent}/documents", "id": "dialogflow.projects.agent.knowledgeBases.documents.list", "description": "Returns the list of all documents of the knowledge base.", "response": { "$ref": "GoogleCloudDialogflowV2beta1ListDocumentsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "pageToken": { "location": "query", "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string" }, "pageSize": { "location": "query", "description": "Optional. The maximum number of items to return in a single page. By\ndefault 10 and at most 100.", "format": "int32", "type": "integer" }, "parent": { "description": "Required. The knowledge base to list all documents for.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "create": { "flatPath": "v2beta1/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents", "path": "v2beta1/{+parent}/documents", "id": "dialogflow.projects.agent.knowledgeBases.documents.create", "description": "Creates a new document.\n\nOperation <response: Document,\n           metadata: KnowledgeOperationMetadata>", "request": { "$ref": "GoogleCloudDialogflowV2beta1Document" }, "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The knoweldge base to create a document for.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/knowledgeBases/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] } } } } }, "intents": { "methods": { "get": { "description": "Retrieves the specified intent.", "response": { "$ref": "GoogleCloudDialogflowV2beta1Intent" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "intentView": { "description": "Optional. The resource view to apply to the returned intent.", "type": "string", "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"] }, "languageCode": { "description": "Optional. The language to retrieve training phrases, parameters and rich\nmessages for. If not specified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string", "location": "query" }, "name": { "location": "path", "description": "Required. The name of the intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/intents/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/agent/intents/{intentsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.intents.get" }, "patch": { "response": { "$ref": "GoogleCloudDialogflowV2beta1Intent" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "intentView": { "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent.", "type": "string" }, "languageCode": { "location": "query", "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intent`. If not specified, the agent's default language is\nused. [More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of this intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/intents/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/intents/{intentsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.intents.patch", "description": "Updates the specified intent.", "request": { "$ref": "GoogleCloudDialogflowV2beta1Intent" } }, "batchUpdate": { "description": "Updates/Creates multiple intents in the specified agent.\n\nOperation <response: BatchUpdateIntentsResponse>", "request": { "$ref": "GoogleCloudDialogflowV2beta1BatchUpdateIntentsRequest" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "location": "path", "description": "Required. The name of the agent to update or create intents in.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/intents:batchUpdate", "id": "dialogflow.projects.agent.intents.batchUpdate", "path": "v2beta1/{+parent}/intents:batchUpdate" }, "delete": { "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "GoogleProtobufEmpty" }, "parameters": { "name": { "location": "path", "description": "Required. The name of the intent to delete. If this intent has direct or\nindirect followup intents, we also delete them.\n\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/intents/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/intents/{intentsId}", "id": "dialogflow.projects.agent.intents.delete", "path": "v2beta1/{+name}", "description": "Deletes the specified intent and its direct or indirect followup intents." }, "list": { "description": "Returns the list of all intents in the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2beta1ListIntentsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "languageCode": { "location": "query", "description": "Optional. The language to list training phrases, parameters and rich\nmessages for. If not specified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent before they can be used.", "type": "string" }, "pageToken": { "location": "query", "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string" }, "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "intentView": { "description": "Optional. The resource view to apply to the returned intent.", "type": "string", "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"] }, "parent": { "location": "path", "description": "Required. The agent to list all intents from.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "flatPath": "v2beta1/projects/{projectsId}/agent/intents", "path": "v2beta1/{+parent}/intents", "id": "dialogflow.projects.agent.intents.list" }, "create": { "request": { "$ref": "GoogleCloudDialogflowV2beta1Intent" }, "description": "Creates an intent in the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2beta1Intent" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "intentView": { "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent.", "type": "string" }, "parent": { "location": "path", "description": "Required. The agent to create a intent for.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" }, "languageCode": { "location": "query", "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intent`. If not specified, the agent's default language is\nused. [More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" } }, "flatPath": "v2beta1/projects/{projectsId}/agent/intents", "path": "v2beta1/{+parent}/intents", "id": "dialogflow.projects.agent.intents.create" }, "batchDelete": { "description": "Deletes intents in the specified agent.\n\nOperation <response: google.protobuf.Empty>", "request": { "$ref": "GoogleCloudDialogflowV2beta1BatchDeleteIntentsRequest" }, "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The name of the agent to delete all entities types for. Format:\n`projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/intents:batchDelete", "path": "v2beta1/{+parent}/intents:batchDelete", "id": "dialogflow.projects.agent.intents.batchDelete" } } }, "entityTypes": { "methods": { "get": { "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.entityTypes.get", "path": "v2beta1/{+name}", "description": "Retrieves the specified entity type.", "httpMethod": "GET", "parameterOrder": ["name"], "response": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" }, "parameters": { "languageCode": { "description": "Optional. The language to retrieve entity synonyms for. If not specified,\nthe agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string", "location": "query" }, "name": { "location": "path", "description": "Required. The name of the entity type.\nFormat: `projects/<Project ID>/agent/entityTypes/<EntityType ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "patch": { "description": "Updates the specified entity type.", "request": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" }, "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" }, "parameters": { "languageCode": { "location": "query", "description": "Optional. The language of entity synonyms defined in `entity_type`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string" }, "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "description": "Required for all methods except `create` (`create` populates the name\nautomatically.\nThe unique identifier of the entity type. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.entityTypes.patch", "path": "v2beta1/{+name}" }, "batchUpdate": { "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes:batchUpdate", "path": "v2beta1/{+parent}/entityTypes:batchUpdate", "id": "dialogflow.projects.agent.entityTypes.batchUpdate", "request": { "$ref": "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesRequest" }, "description": "Updates/Creates multiple entity types in the specified agent.\n\nOperation <response: BatchUpdateEntityTypesResponse,\n           metadata: google.protobuf.Struct>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "description": "Required. The name of the agent to update or create entity types in.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" } } }, "delete": { "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes/{entityTypesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.entityTypes.delete", "description": "Deletes the specified entity type.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "location": "path", "description": "Required. The name of the entity type to delete.\nFormat: `projects/<Project ID>/agent/entityTypes/<EntityType ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "list": { "description": "Returns the list of all entity types in the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2beta1ListEntityTypesResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "languageCode": { "description": "Optional. The language to list entity synonyms for. If not specified,\nthe agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string", "location": "query" }, "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" }, "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "description": "Required. The agent to list all entity types from.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes", "path": "v2beta1/{+parent}/entityTypes", "id": "dialogflow.projects.agent.entityTypes.list" }, "create": { "description": "Creates an entity type in the specified agent.", "request": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "languageCode": { "description": "Optional. The language of entity synonyms defined in `entity_type`. If not\nspecified, the agent's default language is used.\n[More than a dozen\nlanguages](https://dialogflow.com/docs/reference/language) are supported.\nNote: languages must be enabled in the agent, before they can be used.", "type": "string", "location": "query" }, "parent": { "location": "path", "description": "Required. The agent to create a entity type for.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes", "path": "v2beta1/{+parent}/entityTypes", "id": "dialogflow.projects.agent.entityTypes.create" }, "batchDelete": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The name of the agent to delete all entities types for. Format:\n`projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes:batchDelete", "path": "v2beta1/{+parent}/entityTypes:batchDelete", "id": "dialogflow.projects.agent.entityTypes.batchDelete", "description": "Deletes entity types in the specified agent.\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2beta1BatchDeleteEntityTypesRequest" } } }, "resources": { "entities": { "methods": { "batchCreate": { "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchCreate", "path": "v2beta1/{+parent}/entities:batchCreate", "id": "dialogflow.projects.agent.entityTypes.entities.batchCreate", "description": "Creates multiple new entities in the specified entity type.\n\nOperation <response: google.protobuf.Empty>", "request": { "$ref": "GoogleCloudDialogflowV2beta1BatchCreateEntitiesRequest" }, "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The name of the entity type to create entities in. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "batchUpdate": { "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchUpdate", "path": "v2beta1/{+parent}/entities:batchUpdate", "id": "dialogflow.projects.agent.entityTypes.entities.batchUpdate", "description": "Updates or creates multiple entities in the specified entity type. This\nmethod does not affect entities in the entity type that aren't explicitly\nspecified in the request.\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2beta1BatchUpdateEntitiesRequest" }, "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The name of the entity type to update or create entities in.\nFormat: `projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "batchDelete": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The name of the entity type to delete entries for. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchDelete", "path": "v2beta1/{+parent}/entities:batchDelete", "id": "dialogflow.projects.agent.entityTypes.entities.batchDelete", "description": "Deletes entities in the specified entity type.\n\nOperation <response: google.protobuf.Empty,\n           metadata: google.protobuf.Struct>", "request": { "$ref": "GoogleCloudDialogflowV2beta1BatchDeleteEntitiesRequest" } } } } } }, "environments": { "resources": { "users": { "resources": { "sessions": { "methods": { "deleteContexts": { "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts", "path": "v2beta1/{+parent}/contexts", "id": "dialogflow.projects.agent.environments.users.sessions.deleteContexts", "description": "Deletes all active contexts in the specified session.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["parent"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "description": "Required. The name of the session to delete all contexts from. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>` or `projects/<Project\nID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session\nID>`. If `Environment ID` is not specified we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$", "location": "path" } } }, "detectIntent": { "description": "Processes a natural language query and returns structured, actionable data\nas a result. This method is not idempotent, because it may cause contexts\nand session entity types to be updated, which in turn might affect\nresults of future queries.", "request": { "$ref": "GoogleCloudDialogflowV2beta1DetectIntentRequest" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1DetectIntentResponse" }, "parameterOrder": ["session"], "httpMethod": "POST", "parameters": { "session": { "description": "Required. The name of the session this query is sent to. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we are using\n\"-\". It’s up to the API caller to choose an appropriate `Session ID` and\n`User Id`. They can be a random numbers or some type of user and session\nidentifiers (preferably hashed). The length of the `Session ID` and\n`User ID` must not exceed 36 characters.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}:detectIntent", "path": "v2beta1/{+session}:detectIntent", "id": "dialogflow.projects.agent.environments.users.sessions.detectIntent" } }, "resources": { "contexts": { "methods": { "delete": { "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.environments.users.sessions.contexts.delete", "description": "Deletes the specified context.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "Required. The name of the context to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`. If `Environment ID` is\nnot specified, we assume default 'draft' environment. If `User ID` is not\nspecified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$" } } }, "list": { "response": { "$ref": "GoogleCloudDialogflowV2beta1ListContextsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "description": "Required. The session to list all contexts from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we assume\ndefault '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$", "location": "path" }, "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts", "path": "v2beta1/{+parent}/contexts", "id": "dialogflow.projects.agent.environments.users.sessions.contexts.list", "description": "Returns the list of all contexts in the specified session." }, "get": { "description": "Retrieves the specified context.", "httpMethod": "GET", "parameterOrder": ["name"], "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameters": { "name": { "description": "Required. The name of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`. If `Environment ID` is\nnot specified, we assume default 'draft' environment. If `User ID` is not\nspecified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}", "id": "dialogflow.projects.agent.environments.users.sessions.contexts.get", "path": "v2beta1/{+name}" }, "patch": { "description": "Updates the specified context.", "request": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`,\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`.\n\nThe `Context ID` is always converted to lowercase, may only contain\ncharacters in a-zA-Z0-9_-% and may be at most 250 bytes long.\n\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.environments.users.sessions.contexts.patch" }, "create": { "description": "Creates a context.\n\nIf the specified context already exists, overrides the context.", "request": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The session to create a context for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we assume\ndefault '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts", "path": "v2beta1/{+parent}/contexts", "id": "dialogflow.projects.agent.environments.users.sessions.contexts.create" } } }, "entityTypes": { "methods": { "list": { "response": { "$ref": "GoogleCloudDialogflowV2beta1ListSessionEntityTypesResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "location": "path", "description": "Required. The session to list all session entity types from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/\nsessions/<Session ID>`.\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$" }, "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes", "path": "v2beta1/{+parent}/entityTypes", "id": "dialogflow.projects.agent.environments.users.sessions.entityTypes.list", "description": "Returns the list of all session entity types in the specified session." }, "get": { "description": "Retrieves the specified session entity type.", "httpMethod": "GET", "parameterOrder": ["name"], "response": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "parameters": { "name": { "location": "path", "description": "Required. The name of the session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>` or `projects/<Project ID>/agent/environments/<Environment\nID>/users/<User ID>/sessions/<Session ID>/entityTypes/<Entity Type Display\nName>`. If `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.environments.users.sessions.entityTypes.get", "path": "v2beta1/{+name}" }, "patch": { "description": "Updates the specified session entity type.", "request": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "parameters": { "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "description": "Required. The unique identifier of this session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/entityTypes/<Entity Type Display Name>`.\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.\n\n`<Entity Type Display Name>` must be the display name of an existing entity\ntype in the same agent that will be overridden or supplemented.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.environments.users.sessions.entityTypes.patch", "path": "v2beta1/{+name}" }, "create": { "description": "Creates a session entity type.\n\nIf the specified session entity type already exists, overrides the\nsession entity type.", "request": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleCloudDialogflowV2beta1SessionEntityType" }, "parameters": { "parent": { "description": "Required. The session to create a session entity type for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/\nsessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we assume\ndefault '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes", "id": "dialogflow.projects.agent.environments.users.sessions.entityTypes.create", "path": "v2beta1/{+parent}/entityTypes" }, "delete": { "description": "Deletes the specified session entity type.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "Required. The name of the entity type to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>` or `projects/<Project ID>/agent/environments/<Environment\nID>/users/<User ID>/sessions/<Session ID>/entityTypes/<Entity Type Display\nName>`. If `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.agent.environments.users.sessions.entityTypes.delete" } } } } } } } } } } }, "environments": { "resources": { "users": { "resources": { "conversations": { "methods": { "deleteContexts": { "description": "Deletes all active contexts in the specified session.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["parent"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "location": "path", "description": "Required. The name of the session to delete all contexts from. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>` or `projects/<Project\nID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session\nID>`. If `Environment ID` is not specified we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/environments/[^/]+/users/[^/]+/conversations/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/environments/{environmentsId}/users/{usersId}/conversations/{conversationsId}/contexts", "path": "v2beta1/{+parent}/contexts", "id": "dialogflow.projects.environments.users.conversations.deleteContexts" } }, "resources": { "contexts": { "methods": { "delete": { "flatPath": "v2beta1/projects/{projectsId}/environments/{environmentsId}/users/{usersId}/conversations/{conversationsId}/contexts/{contextsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.environments.users.conversations.contexts.delete", "description": "Deletes the specified context.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "location": "path", "description": "Required. The name of the context to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`. If `Environment ID` is\nnot specified, we assume default 'draft' environment. If `User ID` is not\nspecified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/environments/[^/]+/users/[^/]+/conversations/[^/]+/contexts/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "list": { "description": "Returns the list of all contexts in the specified session.", "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "GoogleCloudDialogflowV2beta1ListContextsResponse" }, "parameters": { "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "description": "Required. The session to list all contexts from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we assume\ndefault '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/environments/[^/]+/users/[^/]+/conversations/[^/]+$", "location": "path" }, "pageToken": { "location": "query", "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/environments/{environmentsId}/users/{usersId}/conversations/{conversationsId}/contexts", "id": "dialogflow.projects.environments.users.conversations.contexts.list", "path": "v2beta1/{+parent}/contexts" }, "get": { "description": "Retrieves the specified context.", "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "description": "Required. The name of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`. If `Environment ID` is\nnot specified, we assume default 'draft' environment. If `User ID` is not\nspecified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/environments/[^/]+/users/[^/]+/conversations/[^/]+/contexts/[^/]+$", "location": "path" } }, "flatPath": "v2beta1/projects/{projectsId}/environments/{environmentsId}/users/{usersId}/conversations/{conversationsId}/contexts/{contextsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.environments.users.conversations.contexts.get" }, "patch": { "flatPath": "v2beta1/projects/{projectsId}/environments/{environmentsId}/users/{usersId}/conversations/{conversationsId}/contexts/{contextsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.environments.users.conversations.contexts.patch", "description": "Updates the specified context.", "request": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string", "location": "query" }, "name": { "location": "path", "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`,\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`.\n\nThe `Context ID` is always converted to lowercase, may only contain\ncharacters in a-zA-Z0-9_-% and may be at most 250 bytes long.\n\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/environments/[^/]+/users/[^/]+/conversations/[^/]+/contexts/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "create": { "description": "Creates a context.\n\nIf the specified context already exists, overrides the context.", "request": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "response": { "$ref": "GoogleCloudDialogflowV2beta1Context" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The session to create a context for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>` or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`. If `Environment ID` is not specified, we assume\ndefault 'draft' environment. If `User ID` is not specified, we assume\ndefault '-' user.", "required": true, "type": "string", "pattern": "^projects/[^/]+/environments/[^/]+/users/[^/]+/conversations/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/environments/{environmentsId}/users/{usersId}/conversations/{conversationsId}/contexts", "path": "v2beta1/{+parent}/contexts", "id": "dialogflow.projects.environments.users.conversations.contexts.create" } } } } } } } } }, "operations": { "methods": { "get": { "flatPath": "v2beta1/projects/{projectsId}/operations/{operationsId}", "id": "dialogflow.projects.operations.get", "path": "v2beta1/{+name}", "description": "Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice.", "httpMethod": "GET", "parameterOrder": ["name"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "name": { "description": "The name of the operation resource.", "required": true, "type": "string", "pattern": "^projects/[^/]+/operations/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] } } }, "knowledgeBases": { "methods": { "delete": { "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "force": { "description": "Optional. Force deletes the knowledge base. When set to true, any documents\nin the knowledge base are also deleted.", "type": "boolean", "location": "query" }, "name": { "pattern": "^projects/[^/]+/knowledgeBases/[^/]+$", "location": "path", "description": "Required. The name of the knowledge base to delete.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.knowledgeBases.delete", "description": "Deletes the specified knowledge base." }, "list": { "description": "Returns the list of all knowledge bases of the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2beta1ListKnowledgeBasesResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project to list of knowledge bases for.\nFormat: `projects/<Project ID>`." }, "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "Optional. The maximum number of items to return in a single page. By\ndefault 10 and at most 100.", "format": "int32", "type": "integer" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases", "path": "v2beta1/{+parent}/knowledgeBases", "id": "dialogflow.projects.knowledgeBases.list" }, "get": { "path": "v2beta1/{+name}", "id": "dialogflow.projects.knowledgeBases.get", "description": "Retrieves the specified knowledge base.", "response": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "Required. The name of the knowledge base to retrieve.\nFormat `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/knowledgeBases/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}" }, "patch": { "request": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "description": "Updates the specified knowledge base.", "response": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "description": "The knowledge base resource name.\nThe name must be empty when creating a knowledge base.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/knowledgeBases/[^/]+$", "location": "path" }, "updateMask": { "location": "query", "description": "Optional. Not specified means `update all`.\nCurrently, only `display_name` can be updated, an InvalidArgument will be\nreturned for attempting to update other fields.", "format": "google-fieldmask", "type": "string" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.knowledgeBases.patch" }, "create": { "response": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "location": "path", "description": "Required. The project to create a knowledge base for.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases", "path": "v2beta1/{+parent}/knowledgeBases", "id": "dialogflow.projects.knowledgeBases.create", "request": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeBase" }, "description": "Creates a knowledge base." } }, "resources": { "documents": { "methods": { "delete": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "The name of the document to delete.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.knowledgeBases.documents.delete", "description": "Deletes the specified document.\n\nOperation <response: google.protobuf.Empty,\n           metadata: KnowledgeOperationMetadata>" }, "list": { "description": "Returns the list of all documents of the knowledge base.", "response": { "$ref": "GoogleCloudDialogflowV2beta1ListDocumentsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "pageToken": { "location": "query", "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string" }, "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 10 and at most 100.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "location": "path", "description": "Required. The knowledge base to list all documents for.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/knowledgeBases/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents", "path": "v2beta1/{+parent}/documents", "id": "dialogflow.projects.knowledgeBases.documents.list" }, "create": { "request": { "$ref": "GoogleCloudDialogflowV2beta1Document" }, "description": "Creates a new document.\n\nOperation <response: Document,\n           metadata: KnowledgeOperationMetadata>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "pattern": "^projects/[^/]+/knowledgeBases/[^/]+$", "location": "path", "description": "Required. The knoweldge base to create a document for.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base ID>`.", "required": true, "type": "string" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents", "path": "v2beta1/{+parent}/documents", "id": "dialogflow.projects.knowledgeBases.documents.create" }, "patch": { "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "updateMask": { "description": "Optional. Not specified means `update all`.\nCurrently, only `display_name` can be updated, an InvalidArgument will be\nreturned for attempting to update other fields.", "format": "google-fieldmask", "type": "string", "location": "query" }, "name": { "description": "The document resource name.\nThe name must be empty when creating a document.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}", "id": "dialogflow.projects.knowledgeBases.documents.patch", "path": "v2beta1/{+name}", "description": "Updates the specified document.\nOperation <response: Document,\n           metadata: KnowledgeOperationMetadata>", "request": { "$ref": "GoogleCloudDialogflowV2beta1Document" } }, "reload": { "request": { "$ref": "GoogleCloudDialogflowV2beta1ReloadDocumentRequest" }, "description": "Reloads the specified document from its specified source, content_uri or\ncontent. The previously loaded content of the document will be deleted.\nNote: Even when the content of the document has not changed, there still\nmay be side effects because of internal implementation changes.\nOperation <response: Document,\n           metadata: KnowledgeOperationMetadata>", "httpMethod": "POST", "parameterOrder": ["name"], "response": { "$ref": "GoogleLongrunningOperation" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "The name of the document to reload.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`", "required": true, "type": "string", "pattern": "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}:reload", "id": "dialogflow.projects.knowledgeBases.documents.reload", "path": "v2beta1/{+name}:reload" }, "get": { "description": "Retrieves the specified document.", "response": { "$ref": "GoogleCloudDialogflowV2beta1Document" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "description": "Required. The name of the document to retrieve.\nFormat `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$", "location": "path" } }, "flatPath": "v2beta1/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}", "path": "v2beta1/{+name}", "id": "dialogflow.projects.knowledgeBases.documents.get" } } } } } }, "methods": { "getAgent": { "response": { "$ref": "GoogleCloudDialogflowV2beta1Agent" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "description": "Required. The project that the agent to fetch is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path" } }, "flatPath": "v2beta1/projects/{projectsId}/agent", "path": "v2beta1/{+parent}/agent", "id": "dialogflow.projects.getAgent", "description": "Retrieves the specified agent." } } } }, "parameters": { "$.xgafv": { "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"] }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "alt": { "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"] }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "type": "string", "location": "query" } }, "version": "v2beta1", "baseUrl": "https://dialogflow.googleapis.com/", "kind": "discovery#restDescription", "description": "Builds conversational interfaces (for example, chatbots, and voice-powered apps and devices).", "servicePath": "", "basePath": "", "revision": "20181202", "documentationLink": "https://cloud.google.com/dialogflow-enterprise/", "id": "dialogflow:v2beta1" };
//# sourceMappingURL=dialogflow-v2beta1.js.map