"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "id": "driveactivity:v2", "documentationLink": "https://developers.google.com/drive/activity/", "revision": "20181207", "discoveryVersion": "v1", "version_module": true, "schemas": { "Impersonation": { "id": "Impersonation", "description": "Information about an impersonation, where an admin acts on behalf of an end\nuser. Information about the acting admin is not currently available.", "type": "object", "properties": { "impersonatedUser": { "description": "The impersonated user.", "$ref": "User" } } }, "DataLeakPreventionChange": { "description": "A change in the object's data leak prevention status.", "type": "object", "properties": { "type": { "enumDescriptions": ["An update to the DLP state that is neither FLAGGED or CLEARED.", "Document has been flagged as containing sensitive content.", "Document is no longer flagged as containing sensitive content."], "enum": ["TYPE_UNSPECIFIED", "FLAGGED", "CLEARED"], "description": "The type of Data Leak Prevention (DLP) change.", "type": "string" } }, "id": "DataLeakPreventionChange" }, "ConsolidationStrategy": { "type": "object", "properties": { "none": { "$ref": "NoConsolidation", "description": "The individual activities are not consolidated." }, "legacy": { "$ref": "Legacy", "description": "The individual activities are consolidated using the legacy strategy." } }, "id": "ConsolidationStrategy", "description": "How the individual activities are consolidated. A set of activities may be\nconsolidated into one combined activity if they are related in some way, such\nas one actor performing the same action on multiple targets, or multiple\nactors performing the same action on a single target. The strategy defines\nthe rules for which activities are related." }, "DriveItem": { "type": "object", "properties": { "file": { "$ref": "File", "description": "The Drive item is a file." }, "title": { "description": "The title of the Drive item.", "type": "string" }, "folder": { "description": "The Drive item is a folder.", "$ref": "Folder" }, "owner": { "$ref": "Owner", "description": "Information about the owner of this Drive item." }, "name": { "description": "The target Drive item. The format is \"items/ITEM_ID\".", "type": "string" }, "mimeType": { "description": "The MIME type of the Drive item.  See\nhttps://developers.google.com/drive/v3/web/mime-types.", "type": "string" } }, "id": "DriveItem", "description": "A Drive item, such as a file or folder." }, "QueryDriveActivityResponse": { "description": "Response message for querying Drive activity.", "type": "object", "properties": { "activities": { "description": "List of activity requested.", "type": "array", "items": { "$ref": "DriveActivity" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or\nempty if there are no more results in the list.", "type": "string" } }, "id": "QueryDriveActivityResponse" }, "New": { "description": "An object was created from scratch.", "type": "object", "properties": {}, "id": "New" }, "UnknownUser": { "description": "A user about whom nothing is currently known.", "type": "object", "properties": {}, "id": "UnknownUser" }, "Delete": { "description": "An object was deleted.", "type": "object", "properties": { "type": { "enumDescriptions": ["Deletion type is not available.", "An object was put into the trash.", "An object was deleted permanently."], "enum": ["TYPE_UNSPECIFIED", "TRASH", "PERMANENT_DELETE"], "description": "The type of delete action taken.", "type": "string" } }, "id": "Delete" }, "Post": { "description": "A regular posted comment.", "type": "object", "properties": { "subtype": { "enumDescriptions": ["Subtype not available.", "A post was added.", "A post was deleted.", "A reply was added.", "A reply was deleted.", "A posted comment was resolved.", "A posted comment was reopened."], "enum": ["SUBTYPE_UNSPECIFIED", "ADDED", "DELETED", "REPLY_ADDED", "REPLY_DELETED", "RESOLVED", "REOPENED"], "description": "The sub-type of this event.", "type": "string" } }, "id": "Post" }, "Domain": { "id": "Domain", "description": "Information about a domain.", "type": "object", "properties": { "legacyId": { "description": "An opaque string used to identify this domain.", "type": "string" }, "name": { "description": "The name of the domain, e.g. \"google.com\".", "type": "string" } } }, "SystemEvent": { "properties": { "type": { "enumDescriptions": ["The event type is unspecified.", "The event is a consequence of a user account being deleted.", "The event is due to the system automatically purging trash."], "enum": ["TYPE_UNSPECIFIED", "USER_DELETION", "TRASH_AUTO_PURGE"], "description": "The type of the system event that may triggered activity.", "type": "string" } }, "id": "SystemEvent", "description": "Event triggered by system operations instead of end users.", "type": "object" }, "Upload": { "description": "An object was uploaded into Drive.", "type": "object", "properties": {}, "id": "Upload" }, "SettingsChange": { "description": "Information about settings changes.", "type": "object", "properties": { "restrictionChanges": { "description": "The set of changes made to restrictions.", "type": "array", "items": { "$ref": "RestrictionChange" } } }, "id": "SettingsChange" }, "ActionDetail": { "id": "ActionDetail", "description": "Data describing the type and additional information of an action.", "type": "object", "properties": { "rename": { "$ref": "Rename", "description": "An object was renamed." }, "move": { "description": "An object was moved.", "$ref": "Move" }, "delete": { "$ref": "Delete", "description": "An object was deleted." }, "settingsChange": { "description": "Settings were changed.", "$ref": "SettingsChange" }, "create": { "description": "An object was created.", "$ref": "Create" }, "edit": { "description": "An object was edited.", "$ref": "Edit" }, "comment": { "$ref": "Comment", "description": "A change about comments was made." }, "permissionChange": { "$ref": "PermissionChange", "description": "The permission on an object was changed." }, "restore": { "$ref": "Restore", "description": "A deleted object was restored." }, "dlpChange": { "$ref": "DataLeakPreventionChange", "description": "A change happened in data leak prevention status." }, "reference": { "$ref": "ApplicationReference", "description": "An object was referenced in an application outside of Drive/Docs." } } }, "FileComment": { "description": "A comment on a file.", "type": "object", "properties": { "parent": { "description": "The Drive item containing this comment.", "$ref": "DriveItem" }, "legacyCommentId": { "description": "The comment in the discussion thread. This identifier is an opaque string\ncompatible with the Drive API; see\nhttps://developers.google.com/drive/v3/reference/comments/get", "type": "string" }, "linkToDiscussion": { "description": "The link to the discussion thread containing this comment, for example,\n\"https://docs.google.com/DOCUMENT_ID/edit?disco=THREAD_ID\".", "type": "string" }, "legacyDiscussionId": { "description": "The discussion thread to which the comment was added. This identifier is an\nopaque string compatible with the Drive API and references the first\ncomment in a discussion; see\nhttps://developers.google.com/drive/v3/reference/comments/get", "type": "string" } }, "id": "FileComment" }, "Create": { "description": "An object was created.", "type": "object", "properties": { "new": { "$ref": "New", "description": "If present, indicates the object was newly created (e.g. as a blank\ndocument), not derived from a Drive object or external object." }, "upload": { "$ref": "Upload", "description": "If present, indicates the object originated externally and was uploaded\nto Drive." }, "copy": { "$ref": "Copy", "description": "If present, indicates the object was created by copying an existing Drive\nobject." } }, "id": "Create" }, "Anyone": { "properties": {}, "id": "Anyone", "description": "Represents any user (including a logged out user).", "type": "object" }, "DriveItemReference": { "properties": { "folder": { "description": "The Drive item is a folder.", "$ref": "Folder" }, "title": { "description": "The title of the Drive item.", "type": "string" }, "file": { "description": "The Drive item is a file.", "$ref": "File" }, "name": { "description": "The target Drive item. The format is \"items/ITEM_ID\".", "type": "string" } }, "id": "DriveItemReference", "description": "A lightweight reference to a Drive item, such as a file or folder.", "type": "object" }, "QueryDriveActivityRequest": { "description": "The request message for querying Drive activity.", "type": "object", "properties": { "consolidationStrategy": { "description": "Details on how to consolidate related actions that make up the activity. If\nnot set, then related actions will not be consolidated.", "$ref": "ConsolidationStrategy" }, "itemName": { "description": "Return activities for this Drive item. The format is\n\"items/ITEM_ID\".", "type": "string" }, "filter": { "description": "The filtering for items returned from this query request. The format of the\nfilter string is a sequence of expressions, joined by an optional \"AND\",\nwhere each expression is of the form \"field operator value\".\n\nSupported fields:\n\n  - <tt>time</tt>: Uses numerical operators on date values either in\n    terms of milliseconds since Jan 1, 1970 or in RFC 3339 format.\n    Examples:\n      - <tt>time > 1452409200000 AND time <= 1492812924310</tt>\n      - <tt>time >= \"2016-01-10T01:02:03-05:00\"</tt>\n\n  - <tt>detail.action_detail_case</tt>: Uses the \"has\" operator (:) and\n    either a singular value or a list of allowed action types enclosed in\n    parentheses.\n    Examples:\n      - <tt>detail.action_detail_case: RENAME</tt>\n      - <tt>detail.action_detail_case:(CREATE UPLOAD)</tt>\n      - <tt>-detail.action_detail_case:MOVE</tt>", "type": "string" }, "pageToken": { "description": "The next_page_token value returned from a previous QueryDriveActivity\nrequest, if any.", "type": "string" }, "pageSize": { "description": "The requested number of activity to return. If not set, a default value\nwill be used.", "format": "int32", "type": "integer" }, "ancestorName": { "description": "Return activities for this Drive folder and all children and descendants.\nThe format is \"items/ITEM_ID\".", "type": "string" } }, "id": "QueryDriveActivityRequest" }, "Assignment": { "description": "A comment with an assignment.", "type": "object", "properties": { "subtype": { "enumDescriptions": ["Subtype not available.", "An assignment was added.", "An assignment was deleted.", "An assignment reply was added.", "An assignment reply was deleted.", "An assignment was resolved.", "A resolved assignment was reopened.", "An assignment was reassigned."], "enum": ["SUBTYPE_UNSPECIFIED", "ADDED", "DELETED", "REPLY_ADDED", "REPLY_DELETED", "RESOLVED", "REOPENED", "REASSIGNED"], "description": "The sub-type of this event.", "type": "string" } }, "id": "Assignment" }, "Target": { "description": "Information about the target of activity.", "type": "object", "properties": { "teamDrive": { "$ref": "TeamDrive", "description": "The target is a Team Drive." }, "fileComment": { "$ref": "FileComment", "description": "The target is a comment on a Drive file." }, "driveItem": { "description": "The target is a Drive item.", "$ref": "DriveItem" } }, "id": "Target" }, "Folder": { "description": "A Drive item which is a folder.", "type": "object", "properties": { "type": { "description": "The type of Drive folder.", "type": "string", "enumDescriptions": ["The folder type is unknown.", "The folder is the root of a user's MyDrive.", "The folder is the root of a Team Drive. Note that this folder is\na Drive item, and is a distinct entity from the Team Drive itself.", "The folder is a standard, non-root, folder."], "enum": ["TYPE_UNSPECIFIED", "MY_DRIVE_ROOT", "TEAM_DRIVE_ROOT", "STANDARD_FOLDER"] } }, "id": "Folder" }, "Owner": { "description": "Information about the owner of a Drive item.", "type": "object", "properties": { "teamDrive": { "$ref": "TeamDriveReference", "description": "The Team Drive that owns the Drive item." }, "domain": { "description": "The domain of the Drive item owner.", "$ref": "Domain" }, "user": { "$ref": "User", "description": "The user that owns the Drive item." } }, "id": "Owner" }, "Actor": { "description": "The actor of a Drive activity.", "type": "object", "properties": { "impersonation": { "description": "An account acting on behalf of another.", "$ref": "Impersonation" }, "system": { "description": "A non-user actor (i.e. system triggered).", "$ref": "SystemEvent" }, "administrator": { "$ref": "Administrator", "description": "An administrator." }, "anonymous": { "$ref": "AnonymousUser", "description": "An anonymous user." }, "user": { "$ref": "User", "description": "An end user." } }, "id": "Actor" }, "Action": { "description": "Information about the action.", "type": "object", "properties": { "actor": { "$ref": "Actor", "description": "The actor responsible for this action (or empty if all actors are\nresponsible)." }, "detail": { "$ref": "ActionDetail", "description": "The type and detailed information about the action." }, "timestamp": { "description": "The action occurred at this specific time.", "format": "google-datetime", "type": "string" }, "target": { "$ref": "Target", "description": "The target this action affects (or empty if affecting all targets). This\nrepresents the state of the target immediately after this action occurred." }, "timeRange": { "description": "The action occurred over this time range.", "$ref": "TimeRange" } }, "id": "Action" }, "PermissionChange": { "description": "A change of the permission setting on an item.", "type": "object", "properties": { "addedPermissions": { "description": "The set of permissions added by this change.", "type": "array", "items": { "$ref": "Permission" } }, "removedPermissions": { "description": "The set of permissions removed by this change.", "type": "array", "items": { "$ref": "Permission" } } }, "id": "PermissionChange" }, "RestrictionChange": { "description": "Information about restriction policy changes to a feature.", "type": "object", "properties": { "newRestriction": { "description": "The restriction in place after the change.", "type": "string", "enumDescriptions": ["The type of restriction is not available.", "The feature is available without restriction.", "The use of this feature is fully restricted."], "enum": ["RESTRICTION_UNSPECIFIED", "UNRESTRICTED", "FULLY_RESTRICTED"] }, "feature": { "enum": ["FEATURE_UNSPECIFIED", "SHARING_OUTSIDE_DOMAIN", "DIRECT_SHARING", "ITEM_DUPLICATION", "DRIVE_FILE_STREAM"], "description": "The feature which had a change in restriction policy.", "type": "string", "enumDescriptions": ["The feature which changed restriction settings was not available.", "When restricted, this prevents items from being shared outside the\ndomain.", "When restricted, this prevents direct sharing of individual items.", "When restricted, this prevents actions like copy, download, and print\nthat might result in uncontrolled duplicates of items.", "When restricted, this prevents use of Drive File Stream."] } }, "id": "RestrictionChange" }, "Rename": { "description": "An object was renamed.", "type": "object", "properties": { "newTitle": { "description": "The new title of the drive object.", "type": "string" }, "oldTitle": { "description": "The previous title of the drive object.", "type": "string" } }, "id": "Rename" }, "Copy": { "description": "An object was created by copying an existing object.", "type": "object", "properties": { "originalObject": { "description": "The the original object.", "$ref": "TargetReference" } }, "id": "Copy" }, "Comment": { "description": "A change about comments on an object.", "type": "object", "properties": { "suggestion": { "description": "A change on a suggestion.", "$ref": "Suggestion" }, "post": { "description": "A change on a regular posted comment.", "$ref": "Post" }, "mentionedUsers": { "description": "Users who are mentioned in this comment.", "type": "array", "items": { "$ref": "User" } }, "assignment": { "description": "A change on an assignment.", "$ref": "Assignment" } }, "id": "Comment" }, "TargetReference": { "description": "A lightweight reference to the target of activity.", "type": "object", "properties": { "teamDrive": { "$ref": "TeamDriveReference", "description": "The target is a Team Drive." }, "driveItem": { "$ref": "DriveItemReference", "description": "The target is a Drive item." } }, "id": "TargetReference" }, "Group": { "type": "object", "properties": { "email": { "description": "The email address of the group.", "type": "string" }, "title": { "description": "The title of the group.", "type": "string" } }, "id": "Group", "description": "Information about a group." }, "Restore": { "description": "A deleted object was restored.", "type": "object", "properties": { "type": { "enumDescriptions": ["The type is not available.", "An object was restored from the trash."], "enum": ["TYPE_UNSPECIFIED", "UNTRASH"], "description": "The type of restore action taken.", "type": "string" } }, "id": "Restore" }, "Legacy": { "description": "A strategy which consolidates activities using the grouping rules from the\nlegacy V1 Activity API. Similar actions occurring within a window of time\ncan be grouped across multiple targets (such as moving a set of files at\nonce) or multiple actors (such as several users editing the same item).\nGrouping rules for this strategy are specific to each type of action.", "type": "object", "properties": {}, "id": "Legacy" }, "Suggestion": { "id": "Suggestion", "description": "A suggestion.", "type": "object", "properties": { "subtype": { "type": "string", "enumDescriptions": ["Subtype not available.", "A suggestion was added.", "A suggestion was deleted.", "A suggestion reply was added.", "A suggestion reply was deleted.", "A suggestion was accepted.", "A suggestion was rejected.", "An accepted suggestion was deleted.", "A rejected suggestion was deleted."], "enum": ["SUBTYPE_UNSPECIFIED", "ADDED", "DELETED", "REPLY_ADDED", "REPLY_DELETED", "ACCEPTED", "REJECTED", "ACCEPT_DELETED", "REJECT_DELETED"], "description": "The sub-type of this event." } } }, "Move": { "description": "An object was moved.", "type": "object", "properties": { "addedParents": { "description": "The added parent object(s).", "type": "array", "items": { "$ref": "TargetReference" } }, "removedParents": { "description": "The removed parent object(s).", "type": "array", "items": { "$ref": "TargetReference" } } }, "id": "Move" }, "DriveActivity": { "description": "A single Drive activity comprising one or more Actions by one or more\nActors on one or more Targets. Some Action groupings occur spontaneously,\nsuch as moving an item into a shared folder triggering a permission change.\nOther groupings of related Actions, such as multiple Actors editing one item\nor moving multiple files into a new folder, are controlled by the selection\nof a ConsolidationStrategy in the QueryDriveActivityRequest.", "type": "object", "properties": { "targets": { "description": "All Drive objects this activity is about (e.g. file, folder, Team Drive).\nThis represents the state of the target immediately after the actions\noccurred.", "type": "array", "items": { "$ref": "Target" } }, "timeRange": { "$ref": "TimeRange", "description": "The activity occurred over this time range." }, "actions": { "description": "Details on all actions in this activity.", "type": "array", "items": { "$ref": "Action" } }, "timestamp": { "description": "The activity occurred at this specific time.", "format": "google-datetime", "type": "string" }, "primaryActionDetail": { "$ref": "ActionDetail", "description": "Key information about the primary action for this activity. This is either\nrepresentative, or the most important, of all actions in the activity,\naccording to the ConsolidationStrategy in the request." }, "actors": { "description": "All actor(s) responsible for the activity.", "type": "array", "items": { "$ref": "Actor" } } }, "id": "DriveActivity" }, "TimeRange": { "properties": { "endTime": { "description": "The end of the time range.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "The start of the time range.", "format": "google-datetime", "type": "string" } }, "id": "TimeRange", "description": "Information about time ranges.", "type": "object" }, "NoConsolidation": { "description": "A strategy which does no consolidation of individual activities.", "type": "object", "properties": {}, "id": "NoConsolidation" }, "Administrator": { "id": "Administrator", "description": "Empty message representing an administrator.", "type": "object", "properties": {} }, "TeamDrive": { "description": "Information about a Team Drive.", "type": "object", "properties": { "root": { "$ref": "DriveItem", "description": "The root of this Team Drive." }, "title": { "description": "The title of the Team Drive.", "type": "string" }, "name": { "description": "The resource name of the Team Drive. The format is\n\"teamDrives/TEAM_DRIVE_ID\".", "type": "string" } }, "id": "TeamDrive" }, "Edit": { "id": "Edit", "description": "An empty message indicating an object was edited.", "type": "object", "properties": {} }, "DeletedUser": { "id": "DeletedUser", "description": "A user whose account has since been deleted.", "type": "object", "properties": {} }, "ApplicationReference": { "description": "Activity in applications other than Drive.", "type": "object", "properties": { "type": { "enumDescriptions": ["The type is not available.", "The links of one or more Drive items were posted.", "Comments were made regarding a Drive item."], "enum": ["UNSPECIFIED_REFERENCE_TYPE", "LINK", "DISCUSS"], "description": "The reference type corresponding to this event.", "type": "string" } }, "id": "ApplicationReference" }, "Permission": { "id": "Permission", "description": "The permission setting of an object.", "type": "object", "properties": { "domain": { "description": "The domain to whom this permission applies.", "$ref": "Domain" }, "user": { "description": "The user to whom this permission applies.", "$ref": "User" }, "allowDiscovery": { "type": "boolean", "description": "If true, the item can be discovered (e.g. in the user's \"Shared with me\"\ncollection) without needing a link to the item." }, "anyone": { "$ref": "Anyone", "description": "If set, this permission applies to anyone, even logged out users." }, "group": { "description": "The group to whom this permission applies.", "$ref": "Group" }, "role": { "enum": ["ROLE_UNSPECIFIED", "OWNER", "ORGANIZER", "FILE_ORGANIZER", "EDITOR", "COMMENTER", "VIEWER", "PUBLISHED_VIEWER"], "description": "Indicates the\n<a href=\"/drive/web/manage-sharing#roles\">Google Drive permissions\nrole</a>. The role determines a user's ability to read, write, and\ncomment on items.", "type": "string", "enumDescriptions": ["The role is not available.", "A role granting full access.", "A role granting the ability to manage people and settings.", "A role granting the ability to contribute and manage content.", "A role granting the ability to contribute content. This role is sometimes\nalso known as \"writer\".", "A role granting the ability to view and comment on content.", "A role granting the ability to view content. This role is sometimes also\nknown as \"reader\".", "A role granting the ability to view content only after it has been\npublished to the web. This role is sometimes also known as \"published\nreader\". See https://support.google.com/sites/answer/6372880 for more\ninformation."] } } }, "User": { "description": "Information about an end user.", "type": "object", "properties": { "knownUser": { "$ref": "KnownUser", "description": "A known user." }, "unknownUser": { "$ref": "UnknownUser", "description": "A user about whom nothing is currently known." }, "deletedUser": { "description": "A user whose account has since been deleted.", "$ref": "DeletedUser" } }, "id": "User" }, "File": { "description": "A Drive item which is a file.", "type": "object", "properties": {}, "id": "File" }, "AnonymousUser": { "description": "Empty message representing an anonymous user or indicating the authenticated\nuser should be anonymized.", "type": "object", "properties": {}, "id": "AnonymousUser" }, "TeamDriveReference": { "description": "A lightweight reference to a Team Drive.", "type": "object", "properties": { "title": { "description": "The title of the Team Drive.", "type": "string" }, "name": { "type": "string", "description": "The resource name of the Team Drive. The format is\n\"teamDrives/TEAM_DRIVE_ID\"." } }, "id": "TeamDriveReference" }, "KnownUser": { "description": "A known user.", "type": "object", "properties": { "isCurrentUser": { "type": "boolean", "description": "True if this is the user making the request." }, "personName": { "description": "The identifier for this user that can be used with the People API to get\nmore information. The format is \"people/ACCOUNT_ID\". See\nhttps://developers.google.com/people/.", "type": "string" } }, "id": "KnownUser" } }, "protocol": "rest", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "canonicalName": "Drive Activity", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/drive.activity": { "description": "View and add to the activity record of files in your Google Drive" }, "https://www.googleapis.com/auth/drive.activity.readonly": { "description": "View the activity record of files in your Google Drive" } } } }, "rootUrl": "https://driveactivity.googleapis.com/", "ownerDomain": "google.com", "name": "driveactivity", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Drive Activity API", "ownerName": "Google", "resources": { "activity": { "methods": { "query": { "description": "Query past activity in Google Drive.", "request": { "$ref": "QueryDriveActivityRequest" }, "httpMethod": "POST", "parameterOrder": [], "response": { "$ref": "QueryDriveActivityResponse" }, "parameters": {}, "scopes": ["https://www.googleapis.com/auth/drive.activity", "https://www.googleapis.com/auth/drive.activity.readonly"], "flatPath": "v2/activity:query", "id": "driveactivity.activity.query", "path": "v2/activity:query" } } } }, "parameters": { "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "$.xgafv": { "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"] }, "alt": { "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string" }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "key": { "type": "string", "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token." }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "prettyPrint": { "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true", "location": "query" }, "fields": { "type": "string", "location": "query", "description": "Selector specifying which fields to include in a partial response." }, "uploadType": { "type": "string", "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\")." } }, "version": "v2", "baseUrl": "https://driveactivity.googleapis.com/", "kind": "discovery#restDescription", "description": "Provides a historical view of activity in Google Drive.", "servicePath": "", "basePath": "" };
//# sourceMappingURL=driveactivity-v2.js.map