"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "documentationLink": "https://developers.google.com/apps-script/api/", "revision": "20181207", "id": "script:v1", "discoveryVersion": "v1", "schemas": { "Deployment": { "description": "Representation of a single script deployment.", "type": "object", "properties": { "deploymentId": { "description": "The deployment ID for this deployment.", "type": "string" }, "deploymentConfig": { "description": "The deployment configuration.", "$ref": "DeploymentConfig" }, "updateTime": { "description": "Last modified date time stamp.", "format": "google-datetime", "type": "string" }, "entryPoints": { "description": "The deployment's entry points.", "type": "array", "items": { "$ref": "EntryPoint" } } }, "id": "Deployment" }, "GoogleAppsScriptTypeAddOnEntryPoint": { "description": "An add-on entry point.", "type": "object", "properties": { "helpUrl": { "description": "The add-on's optional help URL.", "type": "string" }, "title": { "description": "The add-on's required title.", "type": "string" }, "reportIssueUrl": { "description": "The add-on's optional report issue URL.", "type": "string" }, "postInstallTipUrl": { "description": "The add-on's required post install tip URL.", "type": "string" }, "description": { "description": "The add-on's optional description.", "type": "string" }, "addOnType": { "enum": ["UNKNOWN_ADDON_TYPE", "GMAIL", "DATA_STUDIO"], "description": "The add-on's required list of supported container types.", "type": "string", "enumDescriptions": ["Default value, unknown add-on type.", "Add-on type for Gmail.", "Add-on type for Data Studio."] } }, "id": "GoogleAppsScriptTypeAddOnEntryPoint" }, "ScriptStackTraceElement": { "properties": { "function": { "description": "The name of the function that failed.", "type": "string" }, "lineNumber": { "description": "The line number where the script failed.", "format": "int32", "type": "integer" } }, "id": "ScriptStackTraceElement", "description": "A stack trace through the script that shows where the execution failed.", "type": "object" }, "ListScriptProcessesResponse": { "properties": { "processes": { "description": "List of processes matching request parameters.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeProcess" } }, "nextPageToken": { "description": "Token for the next page of results. If empty, there are no more pages\nremaining.", "type": "string" } }, "id": "ListScriptProcessesResponse", "description": "Response with the list of\nProcess resources.", "type": "object" }, "GoogleAppsScriptTypeWebAppConfig": { "properties": { "access": { "enumDescriptions": ["Default value, should not be used.", "Only the user who deployed the web app or executable can access it.\nNote that this is not necessarily the owner of the script project.", "Only users in the same domain as the user who deployed the web app or\nexecutable can access it.", "Any logged in user can access the web app or executable.", "Any user, logged in or not, can access the web app or executable."], "enum": ["UNKNOWN_ACCESS", "MYSELF", "DOMAIN", "ANYONE", "ANYONE_ANONYMOUS"], "description": "Who has permission to run the web app.", "type": "string" }, "executeAs": { "enum": ["UNKNOWN_EXECUTE_AS", "USER_ACCESSING", "USER_DEPLOYING"], "description": "Who to execute the web app as.", "type": "string", "enumDescriptions": ["Default value, should not be used.", "The script runs as the user accessing the web app.", "The script runs as the user who deployed the web app. Note that this is\nnot necessarily the owner of the script project."] } }, "id": "GoogleAppsScriptTypeWebAppConfig", "description": "Web app entry point configuration.", "type": "object" }, "Project": { "properties": { "scriptId": { "description": "The script project's Drive ID.", "type": "string" }, "title": { "description": "The title for the project.", "type": "string" }, "lastModifyUser": { "$ref": "GoogleAppsScriptTypeUser", "description": "User who last modified the script." }, "createTime": { "description": "When the script was created.", "format": "google-datetime", "type": "string" }, "parentId": { "description": "The parent's Drive ID that the script will be attached to. This is usually\nthe ID of a Google Document or Google Sheet. This filed is optional, and\nif not set, a stand-alone script will be created.", "type": "string" }, "updateTime": { "description": "When the script was last updated.", "format": "google-datetime", "type": "string" }, "creator": { "description": "User who originally created the script.", "$ref": "GoogleAppsScriptTypeUser" } }, "id": "Project", "description": "The script project resource.", "type": "object" }, "ListDeploymentsResponse": { "properties": { "deployments": { "description": "The list of deployments.", "type": "array", "items": { "$ref": "Deployment" } }, "nextPageToken": { "description": "The token that can be used in the next call to get the next page of\nresults.", "type": "string" } }, "id": "ListDeploymentsResponse", "description": "Response with the list of deployments for the specified Apps Script project.", "type": "object" }, "File": { "description": "An individual file within a script project.\nA file is a third-party source code created by one or more\ndevelopers. It can be a server-side JS code, HTML, or a\nconfiguration file. Each script project can contain multiple files.", "type": "object", "properties": { "source": { "description": "The file content.", "type": "string" }, "lastModifyUser": { "$ref": "GoogleAppsScriptTypeUser", "description": "The user who modified the file most recently.\nThis read-only field is only visible to users who have WRITER\npermission for the script project." }, "createTime": { "description": "Creation date timestamp.\nThis read-only field is only visible to users who have WRITER\npermission for the script project.", "format": "google-datetime", "type": "string" }, "functionSet": { "description": "The defined set of functions in the script file, if any.", "$ref": "GoogleAppsScriptTypeFunctionSet" }, "updateTime": { "description": "Last modified date timestamp.\nThis read-only field is only visible to users who have WRITER\npermission for the script project.", "format": "google-datetime", "type": "string" }, "name": { "description": "The name of the file. The file extension is not part of the file\nname, which can be identified from the type field.", "type": "string" }, "type": { "enum": ["ENUM_TYPE_UNSPECIFIED", "SERVER_JS", "HTML", "JSON"], "description": "The type of the file.", "type": "string", "enumDescriptions": ["Undetermined file type; never actually used.", "An Apps Script server-side code file.", "A file containing client-side HTML.", "A file in JSON format. This type is only used for the script\nproject's manifest. The manifest file content must match the\nstructure of a valid\n[ScriptManifest](/apps-script/concepts/manifests)"] } }, "id": "File" }, "ExecutionResponse": { "properties": { "result": { "description": "The return value of the script function. The type matches the object type\nreturned in Apps Script. Functions called using the Apps Script API cannot\nreturn Apps Script-specific objects (such as a `Document` or a `Calendar`);\nthey can only return primitive types such as a `string`, `number`, `array`,\n`object`, or `boolean`.", "type": "any" } }, "id": "ExecutionResponse", "description": "An object that provides the return value of a function executed using the\nApps Script API. If the script function returns successfully, the response\nbody's response field contains this\n`ExecutionResponse` object.", "type": "object" }, "ListVersionsResponse": { "description": "Response with the list of the versions for the specified script project.", "type": "object", "properties": { "versions": { "description": "The list of versions.", "type": "array", "items": { "$ref": "Version" } }, "nextPageToken": { "description": "The token use to fetch the next page of records. if not exist in the\nresponse, that means no more versions to list.", "type": "string" } }, "id": "ListVersionsResponse" }, "Metrics": { "properties": { "totalExecutions": { "description": "Number of total executions.", "type": "array", "items": { "$ref": "MetricsValue" } }, "failedExecutions": { "description": "Number of failed executions.", "type": "array", "items": { "$ref": "MetricsValue" } }, "activeUsers": { "description": "Number of active users.", "type": "array", "items": { "$ref": "MetricsValue" } } }, "id": "Metrics", "description": "Resource containing usage stats for a given script, based on the supplied\nfilter and mask present in the request.", "type": "object" }, "GoogleAppsScriptTypeFunctionSet": { "description": "A set of functions. No duplicates are permitted.", "type": "object", "properties": { "values": { "description": "A list of functions composing the set.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeFunction" } } }, "id": "GoogleAppsScriptTypeFunctionSet" }, "Content": { "description": "The Content resource.", "type": "object", "properties": { "files": { "description": "The list of script project files.\nOne of the files is a script manifest; it must be named \"appsscript\",\nmust have type of JSON, and include the manifest configurations for the\nproject.", "type": "array", "items": { "$ref": "File" } }, "scriptId": { "description": "The script project's Drive ID.", "type": "string" } }, "id": "Content" }, "GoogleAppsScriptTypeWebAppEntryPoint": { "properties": { "url": { "description": "The URL for the web application.", "type": "string" }, "entryPointConfig": { "description": "The entry point's configuration.", "$ref": "GoogleAppsScriptTypeWebAppConfig" } }, "id": "GoogleAppsScriptTypeWebAppEntryPoint", "description": "A web application entry point.", "type": "object" }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "Empty" }, "UpdateDeploymentRequest": { "description": "Request with deployment information to update an existing deployment.", "type": "object", "properties": { "deploymentConfig": { "description": "The deployment configuration.", "$ref": "DeploymentConfig" } }, "id": "UpdateDeploymentRequest" }, "GoogleAppsScriptTypeExecutionApiEntryPoint": { "description": "An API executable entry point.", "type": "object", "properties": { "entryPointConfig": { "description": "The entry point's configuration.", "$ref": "GoogleAppsScriptTypeExecutionApiConfig" } }, "id": "GoogleAppsScriptTypeExecutionApiEntryPoint" }, "ExecutionError": { "description": "An object that provides information about the nature of an error resulting\nfrom an attempted execution of a script function using the Apps Script API.\nIf a run call\nsucceeds but the script function (or Apps Script itself) throws an exception,\nthe response body's error field\ncontains a\nStatus object. The `Status` object's `details` field\ncontains an array with a single one of these `ExecutionError` objects.", "type": "object", "properties": { "errorType": { "description": "The error type, for example `TypeError` or `ReferenceError`. If the error\ntype is unavailable, this field is not included.", "type": "string" }, "errorMessage": { "description": "The error message thrown by Apps Script, usually localized into the user's\nlanguage.", "type": "string" }, "scriptStackTraceElements": { "description": "An array of objects that provide a stack trace through the script to show\nwhere the execution failed, with the deepest call first.", "type": "array", "items": { "$ref": "ScriptStackTraceElement" } } }, "id": "ExecutionError" }, "ListUserProcessesResponse": { "description": "Response with the list of\nProcess resources.", "type": "object", "properties": { "nextPageToken": { "description": "Token for the next page of results. If empty, there are no more pages\nremaining.", "type": "string" }, "processes": { "description": "List of processes matching request parameters.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeProcess" } } }, "id": "ListUserProcessesResponse" }, "GoogleAppsScriptTypeUser": { "properties": { "domain": { "description": "The user's domain.", "type": "string" }, "photoUrl": { "description": "The user's photo.", "type": "string" }, "email": { "description": "The user's identifying email address.", "type": "string" }, "name": { "description": "The user's display name.", "type": "string" } }, "id": "GoogleAppsScriptTypeUser", "description": "A simple user profile resource.", "type": "object" }, "ExecutionRequest": { "properties": { "sessionState": { "description": "For Android add-ons only. An ID that represents the user's current session\nin the Android app for Google Docs or Sheets, included as extra data in the\n[Intent](https://developer.android.com/guide/components/intents-filters.html)\nthat launches the add-on. When an Android add-on is run with a session\nstate, it gains the privileges of a\n[bound](https://developers.google.com/apps-script/guides/bound)\nscript&mdash;that is, it can access information like the user's current\ncursor position (in Docs) or selected cell (in Sheets). To retrieve the\nstate, call\n`Intent.getStringExtra(\"com.google.android.apps.docs.addons.SessionState\")`.\nOptional.", "type": "string" }, "function": { "description": "The name of the function to execute in the given script. The name does not\ninclude parentheses or parameters.", "type": "string" }, "devMode": { "description": "If `true` and the user is an owner of the script, the script runs at the\nmost recently saved version rather than the version deployed for use with\nthe Apps Script API. Optional; default is `false`.", "type": "boolean" }, "parameters": { "description": "The parameters to be passed to the function being executed. The object type\nfor each parameter should match the expected type in Apps Script.\nParameters cannot be Apps Script-specific object types (such as a\n`Document` or a `Calendar`); they can only be primitive types such as\n`string`, `number`, `array`, `object`, or `boolean`. Optional.", "type": "array", "items": { "type": "any" } } }, "id": "ExecutionRequest", "description": "A request to run the function in a script. The script is identified by the\nspecified `script_id`. Executing a function on a script returns results\nbased on the implementation of the script.", "type": "object" }, "EntryPoint": { "properties": { "executionApi": { "description": "An entry point specification for Apps Script API execution calls.", "$ref": "GoogleAppsScriptTypeExecutionApiEntryPoint" }, "entryPointType": { "enumDescriptions": ["An unspecified entry point.", "A web application entry point.", "An API executable entry point.", "An Add-On entry point."], "enum": ["ENTRY_POINT_TYPE_UNSPECIFIED", "WEB_APP", "EXECUTION_API", "ADD_ON"], "description": "The type of the entry point.", "type": "string" }, "addOn": { "description": "Add-on properties.", "$ref": "GoogleAppsScriptTypeAddOnEntryPoint" }, "webApp": { "$ref": "GoogleAppsScriptTypeWebAppEntryPoint", "description": "An entry point specification for web apps." } }, "id": "EntryPoint", "description": "A configuration that defines how a deployment is accessed externally.", "type": "object" }, "Version": { "description": "A resource representing a script project version. A version is a \"snapshot\"\nof a script project and is similar to a read-only branched release. When\ncreating deployments, the version to use must be specified.", "type": "object", "properties": { "description": { "description": "The description for this version.", "type": "string" }, "versionNumber": { "description": "The incremental ID that is created by Apps Script when a version is\ncreated. This is system assigned number and is immutable once created.", "format": "int32", "type": "integer" }, "scriptId": { "description": "The script project's Drive ID.", "type": "string" }, "createTime": { "description": "When the version was created.", "format": "google-datetime", "type": "string" } }, "id": "Version" }, "GoogleAppsScriptTypeExecutionApiConfig": { "properties": { "access": { "enum": ["UNKNOWN_ACCESS", "MYSELF", "DOMAIN", "ANYONE", "ANYONE_ANONYMOUS"], "description": "Who has permission to run the API executable.", "type": "string", "enumDescriptions": ["Default value, should not be used.", "Only the user who deployed the web app or executable can access it.\nNote that this is not necessarily the owner of the script project.", "Only users in the same domain as the user who deployed the web app or\nexecutable can access it.", "Any logged in user can access the web app or executable.", "Any user, logged in or not, can access the web app or executable."] } }, "id": "GoogleAppsScriptTypeExecutionApiConfig", "description": "API executable entry point configuration.", "type": "object" }, "GoogleAppsScriptTypeProcess": { "description": "Representation of a single script process execution that was started from\nthe script editor, a trigger, an application, or using the Apps Script API.\nThis is distinct from the `Operation`\nresource, which only represents executions started via the Apps Script API.", "type": "object", "properties": { "userAccessLevel": { "enumDescriptions": ["User access level unspecified", "The user has no access.", "The user has read-only access.", "The user has write access.", "The user is an owner."], "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "The executing users access level to the script.", "type": "string" }, "executingUser": { "description": "User-facing name for the user executing the script.", "type": "string" }, "processType": { "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU", "BATCH_TASK"], "description": "The executions type.", "type": "string", "enumDescriptions": ["Unspecified type.", "The process was started from an add-on entry point.", "The process was started using the Apps Script API.", "The process was started from a time-based trigger.", "The process was started from an event-based trigger.", "The process was started from a web app entry point.", "The process was started using the Apps Script IDE.", "The process was started from a G Suite simple trigger.", "The process was started from a G Suite menu item.", "The process was started as a task in a batch job."] }, "projectName": { "description": "Name of the script being executed.", "type": "string" }, "processStatus": { "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"], "description": "The executions status.", "type": "string", "enumDescriptions": ["Unspecified status.", "The process is currently running.", "The process has paused.", "The process has completed.", "The process was cancelled.", "The process failed.", "The process timed out.", "Process status unknown.", "The process is delayed, waiting for quota."] }, "duration": { "description": "Duration the execution spent executing.", "format": "google-duration", "type": "string" }, "functionName": { "description": "Name of the function the started the execution.", "type": "string" }, "startTime": { "description": "Time the execution started.", "format": "google-datetime", "type": "string" } }, "id": "GoogleAppsScriptTypeProcess" }, "DeploymentConfig": { "description": "Metadata the defines how a deployment is configured.", "type": "object", "properties": { "scriptId": { "description": "The script project's Drive ID.", "type": "string" }, "manifestFileName": { "description": "The manifest file name for this deployment.", "type": "string" }, "description": { "description": "The description for this deployment.", "type": "string" }, "versionNumber": { "description": "The version number on which this deployment is based.", "format": "int32", "type": "integer" } }, "id": "DeploymentConfig" }, "CreateProjectRequest": { "description": "Request to create a script project.", "type": "object", "properties": { "parentId": { "description": "The Drive ID of a parent file that the created script project is bound to.\nThis is usually the ID of a Google Doc, Google Sheet, Google Form, or\nGoogle Slides file. If not set, a standalone script project is created.", "type": "string" }, "title": { "description": "The title for the project.", "type": "string" } }, "id": "CreateProjectRequest" }, "Operation": { "description": "A representation of an execution of an Apps Script function started with run. The execution response does not arrive until the function finishes executing. The maximum execution runtime is listed in the [Apps Script quotas guide](/apps-script/guides/services/quotas#current_limitations). <p>After execution has started, it can have one of four outcomes:</p> <ul> <li> If the script function returns successfully, the\n  response field contains an\n  ExecutionResponse object\n  with the function's return value in the object's `result` field.</li>\n<li> If the script function (or Apps Script itself) throws an exception, the\n  error field contains a\n  Status object. The `Status` object's `details`\n  field contains an array with a single\n  ExecutionError object that\n  provides information about the nature of the error.</li>\n<li> If the execution has not yet completed,\n  the done field is `false` and\n  the neither the `response` nor `error` fields are present.</li>\n<li> If the `run` call itself fails (for example, because of a\n  malformed request or an authorization error), the method returns an HTTP\n  response code in the 4XX range with a different format for the response\n  body. Client libraries automatically convert a 4XX response into an\n  exception class.</li>\n</ul>", "type": "object", "properties": { "response": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "If the script function returns successfully, this field contains an ExecutionResponse object with the function's return value.", "type": "object" }, "error": { "$ref": "Status", "description": "If a `run` call succeeds but the script function (or Apps Script itself) throws an exception, this field contains a Status object. The `Status` object's `details` field contains an array with a single ExecutionError object that provides information about the nature of the error." }, "done": { "description": "This field indicates whether the script execution has completed. A completed execution has a populated `response` field containing the ExecutionResponse from function that was executed.", "type": "boolean" } }, "id": "Operation" }, "Status": { "properties": { "message": { "description": "A developer-facing error message, which is in English. Any user-facing error message is localized and sent in the details field, or localized by the client.", "type": "string" }, "details": { "description": "An array that contains a single ExecutionError object that provides information about the nature of the error.", "type": "array", "items": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "type": "object" } }, "code": { "description": "The status code. For this API, this value either: <ul> <li> 10, indicating a `SCRIPT_TIMEOUT` error,</li> <li> 3, indicating an `INVALID_ARGUMENT` error, or</li> <li> 1, indicating a `CANCELLED` execution.</li> </ul>", "format": "int32", "type": "integer" } }, "id": "Status", "description": "If a `run` call succeeds but the script function (or Apps Script itself) throws an exception, the response body's error field contains this `Status` object.", "type": "object" }, "MetricsValue": { "description": "Metrics value that holds number of executions counted.", "type": "object", "properties": { "startTime": { "description": "Required field indicating the start time of the interval.", "format": "google-datetime", "type": "string" }, "value": { "description": "Indicates the number of executions counted.", "format": "uint64", "type": "string" }, "endTime": { "description": "Required field indicating the end time of the interval.", "format": "google-datetime", "type": "string" } }, "id": "MetricsValue" }, "GoogleAppsScriptTypeFunction": { "description": "Represents a function in a script project.", "type": "object", "properties": { "name": { "description": "The function name in the script project.", "type": "string" } }, "id": "GoogleAppsScriptTypeFunction" } }, "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "protocol": "rest", "canonicalName": "Script", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/documents": { "description": "View and manage your Google Docs documents" }, "https://www.google.com/calendar/feeds": { "description": "See, edit, share, and permanently delete all the calendars you can access using Google Calendar" }, "https://www.googleapis.com/auth/script.projects.readonly": { "description": "View Google Apps Script projects" }, "https://www.googleapis.com/auth/script.projects": { "description": "Create and update Google Apps Script projects" }, "https://www.googleapis.com/auth/drive": { "description": "See, edit, create, and delete all of your Google Drive files" }, "https://mail.google.com/": { "description": "Read, compose, send, and permanently delete all your email from Gmail" }, "https://www.googleapis.com/auth/admin.directory.user": { "description": "View and manage the provisioning of users on your domain" }, "https://www.googleapis.com/auth/userinfo.email": { "description": "View your email address" }, "https://www.googleapis.com/auth/script.metrics": { "description": "View Google Apps Script project's metrics" }, "https://www.googleapis.com/auth/groups": { "description": "View and manage your Google Groups" }, "https://www.googleapis.com/auth/script.deployments": { "description": "Create and update Google Apps Script deployments" }, "https://www.googleapis.com/auth/forms.currentonly": { "description": "View and manage forms that this application has been installed in" }, "https://www.googleapis.com/auth/script.processes": { "description": "View Google Apps Script processes" }, "https://www.googleapis.com/auth/script.deployments.readonly": { "description": "View Google Apps Script deployments" }, "https://www.googleapis.com/auth/spreadsheets": { "description": "See, edit, create, and delete your spreadsheets in Google Drive" }, "https://www.googleapis.com/auth/admin.directory.group": { "description": "View and manage the provisioning of groups on your domain" }, "https://www.googleapis.com/auth/forms": { "description": "View and manage your forms in Google Drive" }, "https://www.google.com/m8/feeds": { "description": "See, edit, download, and permanently delete your contacts" } } } }, "rootUrl": "https://script.googleapis.com/", "ownerDomain": "google.com", "name": "script", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Apps Script API", "ownerName": "Google", "resources": { "scripts": { "methods": { "run": { "description": "Runs a function in an Apps Script project. The script project must be\ndeployed for use with the Apps Script API and the calling application must\nshare the same Cloud Platform project.\n\nThis method requires authorization with an OAuth 2.0 token that includes at\nleast one of the scopes listed in the [Authorization](#authorization)\nsection; script projects that do not require authorization cannot be\nexecuted through this API. To find the correct scopes to include in the\nauthentication token, open the project in the script editor, then select\n**File > Project properties** and click the **Scopes** tab.\n\nThe error `403, PERMISSION_DENIED: The caller does not have permission`\nindicates that the Cloud Platform project used to authorize the request is\nnot the same as the one used by the script.", "request": { "$ref": "ExecutionRequest" }, "response": { "$ref": "Operation" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "parameters": { "scriptId": { "description": "The script ID of the script to be executed. To find the script ID, open\nthe project in the script editor and select **File > Project properties**.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://mail.google.com/", "https://www.google.com/calendar/feeds", "https://www.google.com/m8/feeds", "https://www.googleapis.com/auth/admin.directory.group", "https://www.googleapis.com/auth/admin.directory.user", "https://www.googleapis.com/auth/documents", "https://www.googleapis.com/auth/drive", "https://www.googleapis.com/auth/forms", "https://www.googleapis.com/auth/forms.currentonly", "https://www.googleapis.com/auth/groups", "https://www.googleapis.com/auth/spreadsheets", "https://www.googleapis.com/auth/userinfo.email"], "flatPath": "v1/scripts/{scriptId}:run", "path": "v1/scripts/{scriptId}:run", "id": "script.scripts.run" } } }, "projects": { "resources": { "deployments": { "methods": { "update": { "description": "Updates a deployment of an Apps Script project.", "request": { "$ref": "UpdateDeploymentRequest" }, "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "PUT", "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" }, "deploymentId": { "location": "path", "description": "The deployment ID for this deployment.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/script.deployments"], "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}", "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.update" }, "create": { "request": { "$ref": "DeploymentConfig" }, "description": "Creates a deployment of an Apps Script project.", "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/script.deployments"], "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/deployments", "path": "v1/projects/{scriptId}/deployments", "id": "script.projects.deployments.create" }, "delete": { "description": "Deletes a deployment of an Apps Script project.", "response": { "$ref": "Empty" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "DELETE", "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" }, "deploymentId": { "location": "path", "description": "The deployment ID to be undeployed.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/script.deployments"], "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}", "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.delete" }, "get": { "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "GET", "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" }, "deploymentId": { "location": "path", "description": "The deployment ID.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/script.deployments", "https://www.googleapis.com/auth/script.deployments.readonly"], "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}", "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.get", "description": "Gets a deployment of an Apps Script project." }, "list": { "description": "Lists the deployments of an Apps Script project.", "response": { "$ref": "ListDeploymentsResponse" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.deployments", "https://www.googleapis.com/auth/script.deployments.readonly"], "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" }, "pageToken": { "location": "query", "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string" }, "pageSize": { "description": "The maximum number of deployments on each returned page. Defaults to 50.", "format": "int32", "type": "integer", "location": "query" } }, "flatPath": "v1/projects/{scriptId}/deployments", "path": "v1/projects/{scriptId}/deployments", "id": "script.projects.deployments.list" } } }, "versions": { "methods": { "get": { "response": { "$ref": "Version" }, "parameterOrder": ["scriptId", "versionNumber"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.projects", "https://www.googleapis.com/auth/script.projects.readonly"], "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" }, "versionNumber": { "description": "The version number.", "format": "int32", "required": true, "type": "integer", "location": "path" } }, "flatPath": "v1/projects/{scriptId}/versions/{versionNumber}", "path": "v1/projects/{scriptId}/versions/{versionNumber}", "id": "script.projects.versions.get", "description": "Gets a version of a script project." }, "list": { "id": "script.projects.versions.list", "path": "v1/projects/{scriptId}/versions", "description": "List the versions of a script project.", "httpMethod": "GET", "response": { "$ref": "ListVersionsResponse" }, "parameterOrder": ["scriptId"], "parameters": { "pageToken": { "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string", "location": "query" }, "pageSize": { "description": "The maximum number of versions on each returned page. Defaults to 50.", "format": "int32", "type": "integer", "location": "query" }, "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/script.projects", "https://www.googleapis.com/auth/script.projects.readonly"], "flatPath": "v1/projects/{scriptId}/versions" }, "create": { "path": "v1/projects/{scriptId}/versions", "id": "script.projects.versions.create", "description": "Creates a new immutable version using the current code, with a unique\nversion number.", "request": { "$ref": "Version" }, "response": { "$ref": "Version" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/script.projects"], "flatPath": "v1/projects/{scriptId}/versions" } } } }, "methods": { "updateContent": { "path": "v1/projects/{scriptId}/content", "id": "script.projects.updateContent", "description": "Updates the content of the specified script project.\nThis content is stored as the HEAD version, and is used when the script is\nexecuted as a trigger, in the script editor, in add-on preview mode, or as\na web app or Apps Script API in development mode. This clears all the\nexisting files in the project.", "request": { "$ref": "Content" }, "response": { "$ref": "Content" }, "parameterOrder": ["scriptId"], "httpMethod": "PUT", "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/script.projects"], "flatPath": "v1/projects/{scriptId}/content" }, "create": { "httpMethod": "POST", "parameterOrder": [], "response": { "$ref": "Project" }, "parameters": {}, "scopes": ["https://www.googleapis.com/auth/script.projects"], "flatPath": "v1/projects", "id": "script.projects.create", "path": "v1/projects", "description": "Creates a new, empty script project with no script files and a base\nmanifest file.", "request": { "$ref": "CreateProjectRequest" } }, "getContent": { "path": "v1/projects/{scriptId}/content", "id": "script.projects.getContent", "description": "Gets the content of the script project, including the code source and\nmetadata for each script file.", "response": { "$ref": "Content" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "parameters": { "versionNumber": { "location": "query", "description": "The version number of the project to retrieve. If not provided, the\nproject's HEAD version is returned.", "format": "int32", "type": "integer" }, "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/script.projects", "https://www.googleapis.com/auth/script.projects.readonly"], "flatPath": "v1/projects/{scriptId}/content" }, "getMetrics": { "response": { "$ref": "Metrics" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.metrics"], "parameters": { "scriptId": { "description": "Required field indicating the script to get metrics for.", "required": true, "type": "string", "location": "path" }, "metricsGranularity": { "location": "query", "enum": ["UNSPECIFIED_GRANULARITY", "WEEKLY", "DAILY"], "description": "Required field indicating what granularity of metrics are returned.", "type": "string" }, "metricsFilter.deploymentId": { "location": "query", "description": "Optional field indicating a specific deployment to retrieve metrics from.", "type": "string" } }, "flatPath": "v1/projects/{scriptId}/metrics", "path": "v1/projects/{scriptId}/metrics", "id": "script.projects.getMetrics", "description": "Get metrics data for scripts, such as number of executions and\nactive users." }, "get": { "response": { "$ref": "Project" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.projects", "https://www.googleapis.com/auth/script.projects.readonly"], "parameters": { "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/projects/{scriptId}", "path": "v1/projects/{scriptId}", "id": "script.projects.get", "description": "Gets a script project's metadata." } } }, "processes": { "methods": { "listScriptProcesses": { "path": "v1/processes:listScriptProcesses", "id": "script.processes.listScriptProcesses", "description": "List information about a script's executed processes, such as process type\nand current status.", "response": { "$ref": "ListScriptProcessesResponse" }, "parameterOrder": [], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.processes"], "parameters": { "pageToken": { "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string", "location": "query" }, "pageSize": { "description": "The maximum number of returned processes per page of results. Defaults to\n50.", "format": "int32", "type": "integer", "location": "query" }, "scriptProcessFilter.endTime": { "description": "Optional field used to limit returned processes to those that completed\non or before the given timestamp.", "format": "google-datetime", "type": "string", "location": "query" }, "scriptProcessFilter.userAccessLevels": { "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "Optional field used to limit returned processes to those having one of\nthe specified user access levels.", "type": "string", "repeated": true, "location": "query" }, "scriptProcessFilter.statuses": { "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process statuses.", "type": "string", "repeated": true, "location": "query" }, "scriptProcessFilter.startTime": { "location": "query", "description": "Optional field used to limit returned processes to those that were\nstarted on or after the given timestamp.", "format": "google-datetime", "type": "string" }, "scriptProcessFilter.functionName": { "description": "Optional field used to limit returned processes to those originating from\na script function with the given function name.", "type": "string", "location": "query" }, "scriptProcessFilter.types": { "repeated": true, "location": "query", "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU", "BATCH_TASK"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process types.", "type": "string" }, "scriptId": { "description": "The script ID of the project whose processes are listed.", "type": "string", "location": "query" }, "scriptProcessFilter.deploymentId": { "location": "query", "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific deployment ID.", "type": "string" } }, "flatPath": "v1/processes:listScriptProcesses" }, "list": { "response": { "$ref": "ListUserProcessesResponse" }, "parameterOrder": [], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.processes"], "parameters": { "userProcessFilter.deploymentId": { "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific deployment ID.", "type": "string", "location": "query" }, "userProcessFilter.endTime": { "location": "query", "description": "Optional field used to limit returned processes to those that completed\non or before the given timestamp.", "format": "google-datetime", "type": "string" }, "pageToken": { "location": "query", "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string" }, "pageSize": { "description": "The maximum number of returned processes per page of results. Defaults to\n50.", "format": "int32", "type": "integer", "location": "query" }, "userProcessFilter.startTime": { "location": "query", "description": "Optional field used to limit returned processes to those that were\nstarted on or after the given timestamp.", "format": "google-datetime", "type": "string" }, "userProcessFilter.userAccessLevels": { "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "Optional field used to limit returned processes to those having one of\nthe specified user access levels.", "type": "string", "repeated": true, "location": "query" }, "userProcessFilter.projectName": { "description": "Optional field used to limit returned processes to those originating from\nprojects with project names containing a specific string.", "type": "string", "location": "query" }, "userProcessFilter.functionName": { "description": "Optional field used to limit returned processes to those originating from\na script function with the given function name.", "type": "string", "location": "query" }, "userProcessFilter.scriptId": { "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific script ID.", "type": "string", "location": "query" }, "userProcessFilter.types": { "repeated": true, "location": "query", "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU", "BATCH_TASK"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process types.", "type": "string" }, "userProcessFilter.statuses": { "repeated": true, "location": "query", "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process statuses.", "type": "string" } }, "flatPath": "v1/processes", "path": "v1/processes", "id": "script.processes.list", "description": "List information about processes made by or on behalf of a user,\nsuch as process type and current status." } } } }, "parameters": { "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string", "location": "query" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "uploadType": { "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string" }, "callback": { "description": "JSONP", "type": "string", "location": "query" }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "$.xgafv": { "enum": ["1", "2"], "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query" }, "alt": { "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string" } }, "version": "v1", "baseUrl": "https://script.googleapis.com/", "servicePath": "", "description": "Manages and executes Google Apps Script projects.\n", "kind": "discovery#restDescription", "basePath": "" };
//# sourceMappingURL=script-v1.js.map