export default {"discoveryVersion":"v1","version_module":true,"schemas":{"TestIamPermissionsRequest":{"description":"Request message for `TestIamPermissions` method.","type":"object","properties":{"permissions":{"description":"The set of permissions to check for the `resource`. Permissions with\nwildcards (such as '*' or 'storage.*') are not allowed. For more\ninformation see\n[IAM Overview](https://cloud.google.com/iam/docs/overview#permissions).","type":"array","items":{"type":"string"}}},"id":"TestIamPermissionsRequest"},"StateNotificationConfig":{"description":"The configuration for notification of new states received from the device.","type":"object","properties":{"pubsubTopicName":{"description":"A Cloud Pub/Sub topic name. For example,\n`projects/myProject/topics/deviceEvents`.","type":"string"}},"id":"StateNotificationConfig"},"RegistryCredential":{"description":"A server-stored registry credential used to validate device credentials.","type":"object","properties":{"publicKeyCertificate":{"$ref":"PublicKeyCertificate","description":"A public key certificate used to verify the device credentials."}},"id":"RegistryCredential"},"Policy":{"type":"object","properties":{"etag":{"description":"`etag` is used for optimistic concurrency control as a way to help\nprevent simultaneous updates of a policy from overwriting each other.\nIt is strongly suggested that systems make use of the `etag` in the\nread-modify-write cycle to perform policy updates in order to avoid race\nconditions: An `etag` is returned in the response to `getIamPolicy`, and\nsystems are expected to put that etag in the request to `setIamPolicy` to\nensure that their change will be applied to the same version of the policy.\n\nIf no `etag` is provided in the call to `setIamPolicy`, then the existing\npolicy is overwritten blindly.","format":"byte","type":"string"},"version":{"description":"Deprecated.","format":"int32","type":"integer"},"bindings":{"description":"Associates a list of `members` to a `role`.\n`bindings` with no members will result in an error.","type":"array","items":{"$ref":"Binding"}}},"id":"Policy","description":"Defines an Identity and Access Management (IAM) policy. It is used to\nspecify access control policies for Cloud Platform resources.\n\n\nA `Policy` consists of a list of `bindings`. A `binding` binds a list of\n`members` to a `role`, where the members can be user accounts, Google groups,\nGoogle domains, and service accounts. A `role` is a named list of permissions\ndefined by IAM.\n\n**JSON Example**\n\n    {\n      \"bindings\": [\n        {\n          \"role\": \"roles/owner\",\n          \"members\": [\n            \"user:mike@example.com\",\n            \"group:admins@example.com\",\n            \"domain:google.com\",\n            \"serviceAccount:my-other-app@appspot.gserviceaccount.com\"\n          ]\n        },\n        {\n          \"role\": \"roles/viewer\",\n          \"members\": [\"user:sean@example.com\"]\n        }\n      ]\n    }\n\n**YAML Example**\n\n    bindings:\n    - members:\n      - user:mike@example.com\n      - group:admins@example.com\n      - domain:google.com\n      - serviceAccount:my-other-app@appspot.gserviceaccount.com\n      role: roles/owner\n    - members:\n      - user:sean@example.com\n      role: roles/viewer\n\n\nFor a description of IAM and its features, see the\n[IAM developer's guide](https://cloud.google.com/iam/docs)."},"ListDeviceRegistriesResponse":{"description":"Response for `ListDeviceRegistries`.","type":"object","properties":{"nextPageToken":{"type":"string","description":"If not empty, indicates that there may be more registries that match the\nrequest; this value should be passed in a new\n`ListDeviceRegistriesRequest`."},"deviceRegistries":{"description":"The registries that matched the query.","type":"array","items":{"$ref":"DeviceRegistry"}}},"id":"ListDeviceRegistriesResponse"},"GatewayConfig":{"description":"Gateway-related configuration and state.","type":"object","properties":{"gatewayAuthMethod":{"enumDescriptions":["No authentication/authorization method specified. No devices are allowed to\naccess the gateway.","The device is authenticated through the gateway association only. Device\ncredentials are ignored even if provided.","The device is authenticated through its own credentials. Gateway\nassociation is not checked.","The device is authenticated through both device credentials and gateway\nassociation. The device must be bound to the gateway and must provide its\nown credentials."],"enum":["GATEWAY_AUTH_METHOD_UNSPECIFIED","ASSOCIATION_ONLY","DEVICE_AUTH_TOKEN_ONLY","ASSOCIATION_AND_DEVICE_AUTH_TOKEN"],"description":"Indicates how to authorize and/or authenticate devices to access the\ngateway.","type":"string"},"lastAccessedGatewayTime":{"description":"[Output only] The most recent time at which the device accessed the gateway\nspecified in `last_accessed_gateway`.","format":"google-datetime","type":"string"},"gatewayType":{"description":"Indicates whether the device is a gateway.","type":"string","enumDescriptions":["If unspecified, the device is considered a non-gateway device.","The device is a gateway.","The device is not a gateway."],"enum":["GATEWAY_TYPE_UNSPECIFIED","GATEWAY","NON_GATEWAY"]},"lastAccessedGatewayId":{"description":"[Output only] The ID of the gateway the device accessed most recently.","type":"string"}},"id":"GatewayConfig"},"BindDeviceToGatewayRequest":{"description":"Request for `BindDeviceToGateway`.","type":"object","properties":{"deviceId":{"description":"The device to associate with the specified gateway. The value of\n`device_id` can be either the device numeric ID or the user-defined device\nidentifier.","type":"string"},"gatewayId":{"description":"The value of `gateway_id` can be either the device numeric ID or the\nuser-defined device identifier.","type":"string"}},"id":"BindDeviceToGatewayRequest"},"DeviceRegistry":{"description":"A container for a group of devices.","type":"object","properties":{"mqttConfig":{"$ref":"MqttConfig","description":"The MQTT configuration for this device registry."},"stateNotificationConfig":{"$ref":"StateNotificationConfig","description":"The configuration for notification of new states received from the device.\nState updates are guaranteed to be stored in the state history, but\nnotifications to Cloud Pub/Sub are not guaranteed. For example, if\npermissions are misconfigured or the specified topic doesn't exist, no\nnotification will be published but the state will still be stored in Cloud\nIoT Core."},"credentials":{"description":"The credentials used to verify the device credentials. No more than 10\ncredentials can be bound to a single registry at a time. The verification\nprocess occurs at the time of device creation or update. If this field is\nempty, no verification is performed. Otherwise, the credentials of a newly\ncreated device or added credentials of an updated device should be signed\nwith one of these registry credentials.\n\nNote, however, that existing devices will never be affected by\nmodifications to this list of credentials: after a device has been\nsuccessfully created in a registry, it should be able to connect even if\nits registry credentials are revoked, deleted, or modified.","type":"array","items":{"$ref":"RegistryCredential"}},"name":{"description":"The resource path name. For example,\n`projects/example-project/locations/us-central1/registries/my-registry`.","type":"string"},"eventNotificationConfigs":{"description":"The configuration for notification of telemetry events received from the\ndevice. All telemetry events that were successfully published by the\ndevice and acknowledged by Cloud IoT Core are guaranteed to be\ndelivered to Cloud Pub/Sub. If multiple configurations match a message,\nonly the first matching configuration is used. If you try to publish a\ndevice telemetry event using MQTT without specifying a Cloud Pub/Sub topic\nfor the device's registry, the connection closes automatically. If you try\nto do so using an HTTP connection, an error is returned. Up to 10\nconfigurations may be provided.","type":"array","items":{"$ref":"EventNotificationConfig"}},"logLevel":{"type":"string","enumDescriptions":["No logging specified. If not specified, logging will be disabled.","Disables logging.","Error events will be logged.","Informational events will be logged, such as connections and\ndisconnections.","All events will be logged."],"enum":["LOG_LEVEL_UNSPECIFIED","NONE","ERROR","INFO","DEBUG"],"description":"**Beta Feature**\n\nThe default logging verbosity for activity from devices in this registry.\nThe verbosity level can be overridden by Device.log_level."},"httpConfig":{"description":"The DeviceService (HTTP) configuration for this device registry.","$ref":"HttpConfig"},"id":{"description":"The identifier of this device registry. For example, `myRegistry`.","type":"string"}},"id":"DeviceRegistry"},"ListDevicesResponse":{"description":"Response for `ListDevices`.","type":"object","properties":{"nextPageToken":{"description":"If not empty, indicates that there may be more devices that match the\nrequest; this value should be passed in a new `ListDevicesRequest`.","type":"string"},"devices":{"description":"The devices that match the request.","type":"array","items":{"$ref":"Device"}}},"id":"ListDevicesResponse"},"DeviceCredential":{"type":"object","properties":{"expirationTime":{"type":"string","description":"[Optional] The time at which this credential becomes invalid. This\ncredential will be ignored for new client authentication requests after\nthis timestamp; however, it will not be automatically deleted.","format":"google-datetime"},"publicKey":{"$ref":"PublicKeyCredential","description":"A public key used to verify the signature of JSON Web Tokens (JWTs).\nWhen adding a new device credential, either via device creation or via\nmodifications, this public key credential may be required to be signed by\none of the registry level certificates. More specifically, if the\nregistry contains at least one certificate, any new device credential\nmust be signed by one of the registry certificates. As a result,\nwhen the registry contains certificates, only X.509 certificates are\naccepted as device credentials. However, if the registry does\nnot contain a certificate, self-signed certificates and public keys will\nbe accepted. New device credentials must be different from every\nregistry-level certificate."}},"id":"DeviceCredential","description":"A server-stored device credential used for authentication."},"HttpConfig":{"description":"The configuration of the HTTP bridge for a device registry.","type":"object","properties":{"httpEnabledState":{"description":"If enabled, allows devices to use DeviceService via the HTTP protocol.\nOtherwise, any requests to DeviceService will fail for this registry.","type":"string","enumDescriptions":["No HTTP state specified. If not specified, DeviceService will be\nenabled by default.","Enables DeviceService (HTTP) service for the registry.","Disables DeviceService (HTTP) service for the registry."],"enum":["HTTP_STATE_UNSPECIFIED","HTTP_ENABLED","HTTP_DISABLED"]}},"id":"HttpConfig"},"SendCommandToDeviceRequest":{"type":"object","properties":{"subfolder":{"description":"Optional subfolder for the command. If empty, the command will be delivered\nto the /devices/{device-id}/commands topic, otherwise it will be delivered\nto the /devices/{device-id}/commands/{subfolder} topic. Multi-level\nsubfolders are allowed. This field must not have more than 256 characters,\nand must not contain any MQTT wildcards (\"+\" or \"#\") or null characters.","type":"string"},"binaryData":{"description":"The command data to send to the device.","format":"byte","type":"string"}},"id":"SendCommandToDeviceRequest","description":"Request for `SendCommandToDevice`."},"DeviceConfig":{"description":"The device configuration. Eventually delivered to devices.","type":"object","properties":{"version":{"description":"[Output only] The version of this update. The version number is assigned by\nthe server, and is always greater than 0 after device creation. The\nversion must be 0 on the `CreateDevice` request if a `config` is\nspecified; the response of `CreateDevice` will always have a value of 1.","format":"int64","type":"string"},"cloudUpdateTime":{"type":"string","description":"[Output only] The time at which this configuration version was updated in\nCloud IoT Core. This timestamp is set by the server.","format":"google-datetime"},"deviceAckTime":{"type":"string","description":"[Output only] The time at which Cloud IoT Core received the\nacknowledgment from the device, indicating that the device has received\nthis configuration version. If this field is not present, the device has\nnot yet acknowledged that it received this version. Note that when\nthe config was sent to the device, many config versions may have been\navailable in Cloud IoT Core while the device was disconnected, and on\nconnection, only the latest version is sent to the device. Some\nversions may never be sent to the device, and therefore are never\nacknowledged. This timestamp is set by Cloud IoT Core.","format":"google-datetime"},"binaryData":{"description":"The device configuration data.","format":"byte","type":"string"}},"id":"DeviceConfig"},"MqttConfig":{"description":"The configuration of MQTT for a device registry.","type":"object","properties":{"mqttEnabledState":{"enumDescriptions":["No MQTT state specified. If not specified, MQTT will be enabled by default.","Enables a MQTT connection.","Disables a MQTT connection."],"enum":["MQTT_STATE_UNSPECIFIED","MQTT_ENABLED","MQTT_DISABLED"],"description":"If enabled, allows connections using the MQTT protocol. Otherwise, MQTT\nconnections to this registry will fail.","type":"string"}},"id":"MqttConfig"},"Status":{"type":"object","properties":{"details":{"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.","type":"array","items":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"type":"object"}},"code":{"description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32","type":"integer"},"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"}},"id":"Status","description":"The `Status` type defines a logical error model that is suitable for different\nprogramming environments, including REST APIs and RPC APIs. It is used by\n[gRPC](https://github.com/grpc). The error model is designed to be:\n\n- Simple to use and understand for most users\n- Flexible enough to meet unexpected needs\n\n# Overview\n\nThe `Status` message contains three pieces of data: error code, error message,\nand error details. The error code should be an enum value of\ngoogle.rpc.Code, but it may accept additional error codes if needed.  The\nerror message should be a developer-facing English message that helps\ndevelopers *understand* and *resolve* the error. If a localized user-facing\nerror message is needed, put the localized message in the error details or\nlocalize it in the client. The optional error details may contain arbitrary\ninformation about the error. There is a predefined set of error detail types\nin the package `google.rpc` that can be used for common error conditions.\n\n# Language mapping\n\nThe `Status` message is the logical representation of the error model, but it\nis not necessarily the actual wire format. When the `Status` message is\nexposed in different client libraries and different wire protocols, it can be\nmapped differently. For example, it will likely be mapped to some exceptions\nin Java, but more likely mapped to some error codes in C.\n\n# Other uses\n\nThe error model and the `Status` message can be used in a variety of\nenvironments, either with or without APIs, to provide a\nconsistent developer experience across different environments.\n\nExample uses of this error model include:\n\n- Partial errors. If a service needs to return partial errors to the client,\n    it may embed the `Status` in the normal response to indicate the partial\n    errors.\n\n- Workflow errors. A typical workflow has multiple steps. Each step may\n    have a `Status` message for error reporting.\n\n- Batch operations. If a client uses batch request and batch response, the\n    `Status` message should be used directly inside batch response, one for\n    each error sub-response.\n\n- Asynchronous operations. If an API call embeds asynchronous operation\n    results in its response, the status of those operations should be\n    represented directly using the `Status` message.\n\n- Logging. If some API errors are stored in logs, the message `Status` could\n    be used directly after any stripping needed for security/privacy reasons."},"Binding":{"description":"Associates `members` with a `role`.","type":"object","properties":{"condition":{"description":"Unimplemented. The condition that is associated with this binding.\nNOTE: an unsatisfied condition will not allow user access via current\nbinding. Different bindings, including their conditions, are examined\nindependently.","$ref":"Expr"},"members":{"description":"Specifies the identities requesting access for a Cloud Platform resource.\n`members` can have the following values:\n\n* `allUsers`: A special identifier that represents anyone who is\n   on the internet; with or without a Google account.\n\n* `allAuthenticatedUsers`: A special identifier that represents anyone\n   who is authenticated with a Google account or a service account.\n\n* `user:{emailid}`: An email address that represents a specific Google\n   account. For example, `alice@gmail.com` .\n\n\n* `serviceAccount:{emailid}`: An email address that represents a service\n   account. For example, `my-other-app@appspot.gserviceaccount.com`.\n\n* `group:{emailid}`: An email address that represents a Google group.\n   For example, `admins@example.com`.\n\n\n* `domain:{domain}`: A Google Apps domain name that represents all the\n   users of that domain. For example, `google.com` or `example.com`.\n\n","type":"array","items":{"type":"string"}},"role":{"description":"Role that is assigned to `members`.\nFor example, `roles/viewer`, `roles/editor`, or `roles/owner`.","type":"string"}},"id":"Binding"},"Expr":{"type":"object","properties":{"description":{"description":"An optional description of the expression. This is a longer text which\ndescribes the expression, e.g. when hovered over it in a UI.","type":"string"},"expression":{"description":"Textual representation of an expression in\nCommon Expression Language syntax.\n\nThe application context of the containing message determines which\nwell-known feature set of CEL is supported.","type":"string"},"title":{"type":"string","description":"An optional title for the expression, i.e. a short string describing\nits purpose. This can be used e.g. in UIs which allow to enter the\nexpression."},"location":{"description":"An optional string indicating the location of the expression for error\nreporting, e.g. a file name and a position in the file.","type":"string"}},"id":"Expr","description":"Represents an expression text. Example:\n\n    title: \"User account presence\"\n    description: \"Determines whether the request has a user account\"\n    expression: \"size(request.user) > 0\""},"BindDeviceToGatewayResponse":{"description":"Response for `BindDeviceToGateway`.","type":"object","properties":{},"id":"BindDeviceToGatewayResponse"},"ModifyCloudToDeviceConfigRequest":{"description":"Request for `ModifyCloudToDeviceConfig`.","type":"object","properties":{"versionToUpdate":{"description":"The version number to update. If this value is zero, it will not check the\nversion number of the server and will always update the current version;\notherwise, this update will fail if the version number found on the server\ndoes not match this version number. This is used to support multiple\nsimultaneous updates without losing data.","format":"int64","type":"string"},"binaryData":{"description":"The configuration data for the device.","format":"byte","type":"string"}},"id":"ModifyCloudToDeviceConfigRequest"},"ListDeviceStatesResponse":{"description":"Response for `ListDeviceStates`.","type":"object","properties":{"deviceStates":{"description":"The last few device states. States are listed in descending order of server\nupdate time, starting from the most recent one.","type":"array","items":{"$ref":"DeviceState"}}},"id":"ListDeviceStatesResponse"},"TestIamPermissionsResponse":{"description":"Response message for `TestIamPermissions` method.","type":"object","properties":{"permissions":{"description":"A subset of `TestPermissionsRequest.permissions` that the caller is\nallowed.","type":"array","items":{"type":"string"}}},"id":"TestIamPermissionsResponse"},"GetIamPolicyRequest":{"type":"object","properties":{},"id":"GetIamPolicyRequest","description":"Request message for `GetIamPolicy` method."},"Device":{"description":"The device resource.","type":"object","properties":{"lastConfigSendTime":{"description":"[Output only] The last time a cloud-to-device config version was sent to\nthe device.","format":"google-datetime","type":"string"},"lastErrorStatus":{"description":"[Output only] The error message of the most recent error, such as a failure\nto publish to Cloud Pub/Sub. 'last_error_time' is the timestamp of this\nfield. If no errors have occurred, this field has an empty message\nand the status code 0 == OK. Otherwise, this field is expected to have a\nstatus code other than OK.","$ref":"Status"},"lastStateTime":{"description":"[Output only] The last time a state event was received. Timestamps are\nperiodically collected and written to storage; they may be stale by a few\nminutes.","format":"google-datetime","type":"string"},"config":{"$ref":"DeviceConfig","description":"The most recent device configuration, which is eventually sent from\nCloud IoT Core to the device. If not present on creation, the\nconfiguration will be initialized with an empty payload and version value\nof `1`. To update this field after creation, use the\n`DeviceManager.ModifyCloudToDeviceConfig` method."},"state":{"$ref":"DeviceState","description":"[Output only] The state most recently received from the device. If no state\nhas been reported, this field is not present."},"name":{"type":"string","description":"The resource path name. For example,\n`projects/p1/locations/us-central1/registries/registry0/devices/dev0` or\n`projects/p1/locations/us-central1/registries/registry0/devices/{num_id}`.\nWhen `name` is populated as a response from the service, it always ends\nin the device numeric ID."},"credentials":{"type":"array","items":{"$ref":"DeviceCredential"},"description":"The credentials used to authenticate this device. To allow credential\nrotation without interruption, multiple device credentials can be bound to\nthis device. No more than 3 credentials can be bound to a single device at\na time. When new credentials are added to a device, they are verified\nagainst the registry credentials. For details, see the description of the\n`DeviceRegistry.credentials` field."},"lastErrorTime":{"description":"[Output only] The time the most recent error occurred, such as a failure to\npublish to Cloud Pub/Sub. This field is the timestamp of\n'last_error_status'.","format":"google-datetime","type":"string"},"metadata":{"additionalProperties":{"type":"string"},"description":"The metadata key-value pairs assigned to the device. This metadata is not\ninterpreted or indexed by Cloud IoT Core. It can be used to add contextual\ninformation for the device.\n\nKeys must conform to the regular expression a-zA-Z+ and\nbe less than 128 bytes in length.\n\nValues are free-form strings. Each value must be less than or equal to 32\nKB in size.\n\nThe total size of all keys and values must be less than 256 KB, and the\nmaximum number of key-value pairs is 500.","type":"object"},"logLevel":{"description":"**Beta Feature**\n\nThe logging verbosity for device activity. If unspecified,\nDeviceRegistry.log_level will be used.","type":"string","enumDescriptions":["No logging specified. If not specified, logging will be disabled.","Disables logging.","Error events will be logged.","Informational events will be logged, such as connections and\ndisconnections.","All events will be logged."],"enum":["LOG_LEVEL_UNSPECIFIED","NONE","ERROR","INFO","DEBUG"]},"id":{"description":"The user-defined device identifier. The device ID must be unique\nwithin a device registry.","type":"string"},"lastConfigAckTime":{"description":"[Output only] The last time a cloud-to-device config version acknowledgment\nwas received from the device. This field is only for configurations\nsent through MQTT.","format":"google-datetime","type":"string"},"gatewayConfig":{"$ref":"GatewayConfig","description":"Gateway-related configuration and state."},"numId":{"description":"[Output only] A server-defined unique numeric ID for the device. This is a\nmore compact way to identify devices, and it is globally unique.","format":"uint64","type":"string"},"blocked":{"description":"If a device is blocked, connections or requests from this device will fail.\nCan be used to temporarily prevent the device from connecting if, for\nexample, the sensor is generating bad data and needs maintenance.","type":"boolean"},"lastHeartbeatTime":{"description":"[Output only] The last time an MQTT `PINGREQ` was received. This field\napplies only to devices connecting through MQTT. MQTT clients usually only\nsend `PINGREQ` messages if the connection is idle, and no other messages\nhave been sent. Timestamps are periodically collected and written to\nstorage; they may be stale by a few minutes.","format":"google-datetime","type":"string"},"lastEventTime":{"description":"[Output only] The last time a telemetry event was received. Timestamps are\nperiodically collected and written to storage; they may be stale by a few\nminutes.","format":"google-datetime","type":"string"}},"id":"Device"},"ListDeviceConfigVersionsResponse":{"properties":{"deviceConfigs":{"description":"The device configuration for the last few versions. Versions are listed\nin decreasing order, starting from the most recent one.","type":"array","items":{"$ref":"DeviceConfig"}}},"id":"ListDeviceConfigVersionsResponse","description":"Response for `ListDeviceConfigVersions`.","type":"object"},"X509CertificateDetails":{"properties":{"signatureAlgorithm":{"type":"string","description":"The algorithm used to sign the certificate."},"startTime":{"description":"The time the certificate becomes valid.","format":"google-datetime","type":"string"},"expiryTime":{"description":"The time the certificate becomes invalid.","format":"google-datetime","type":"string"},"subject":{"description":"The entity the certificate and public key belong to.","type":"string"},"issuer":{"description":"The entity that signed the certificate.","type":"string"},"publicKeyType":{"description":"The type of public key in the certificate.","type":"string"}},"id":"X509CertificateDetails","description":"Details of an X.509 certificate. For informational purposes only.","type":"object"},"SendCommandToDeviceResponse":{"type":"object","properties":{},"id":"SendCommandToDeviceResponse","description":"Response for `SendCommandToDevice`."},"SetIamPolicyRequest":{"properties":{"policy":{"$ref":"Policy","description":"REQUIRED: The complete policy to be applied to the `resource`. The size of\nthe policy is limited to a few 10s of KB. An empty policy is a\nvalid policy but certain Cloud Platform services (such as Projects)\nmight reject them."}},"id":"SetIamPolicyRequest","description":"Request message for `SetIamPolicy` method.","type":"object"},"EventNotificationConfig":{"description":"The configuration for forwarding telemetry events.","type":"object","properties":{"subfolderMatches":{"description":"If the subfolder name matches this string exactly, this configuration will\nbe used. The string must not include the leading '/' character. If empty,\nall strings are matched. This field is used only for telemetry events;\nsubfolders are not supported for state changes.","type":"string"},"pubsubTopicName":{"description":"A Cloud Pub/Sub topic name. For example,\n`projects/myProject/topics/deviceEvents`.","type":"string"}},"id":"EventNotificationConfig"},"UnbindDeviceFromGatewayRequest":{"id":"UnbindDeviceFromGatewayRequest","description":"Request for `UnbindDeviceFromGateway`.","type":"object","properties":{"deviceId":{"description":"The device to disassociate from the specified gateway. The value of\n`device_id` can be either the device numeric ID or the user-defined device\nidentifier.","type":"string"},"gatewayId":{"description":"The value of `gateway_id` can be either the device numeric ID or the\nuser-defined device identifier.","type":"string"}}},"Empty":{"description":"A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.","type":"object","properties":{},"id":"Empty"},"UnbindDeviceFromGatewayResponse":{"description":"Response for `UnbindDeviceFromGateway`.","type":"object","properties":{},"id":"UnbindDeviceFromGatewayResponse"},"PublicKeyCredential":{"description":"A public key format and data.","type":"object","properties":{"key":{"description":"The key data.","type":"string"},"format":{"enumDescriptions":["The format has not been specified. This is an invalid default value and\nmust not be used.","An RSA public key encoded in base64, and wrapped by\n`-----BEGIN PUBLIC KEY-----` and `-----END PUBLIC KEY-----`. This can be\nused to verify `RS256` signatures in JWT tokens ([RFC7518](\nhttps://www.ietf.org/rfc/rfc7518.txt)).","As RSA_PEM, but wrapped in an X.509v3 certificate ([RFC5280](\nhttps://www.ietf.org/rfc/rfc5280.txt)), encoded in base64, and wrapped by\n`-----BEGIN CERTIFICATE-----` and `-----END CERTIFICATE-----`.","Public key for the ECDSA algorithm using P-256 and SHA-256, encoded in\nbase64, and wrapped by `-----BEGIN PUBLIC KEY-----` and `-----END\nPUBLIC KEY-----`. This can be used to verify JWT tokens with the `ES256`\nalgorithm ([RFC7518](https://www.ietf.org/rfc/rfc7518.txt)). This curve is\ndefined in [OpenSSL](https://www.openssl.org/) as the `prime256v1` curve.","As ES256_PEM, but wrapped in an X.509v3 certificate ([RFC5280](\nhttps://www.ietf.org/rfc/rfc5280.txt)), encoded in base64, and wrapped by\n`-----BEGIN CERTIFICATE-----` and `-----END CERTIFICATE-----`."],"enum":["UNSPECIFIED_PUBLIC_KEY_FORMAT","RSA_PEM","RSA_X509_PEM","ES256_PEM","ES256_X509_PEM"],"description":"The format of the key.","type":"string"}},"id":"PublicKeyCredential"},"PublicKeyCertificate":{"description":"A public key certificate format and data.","type":"object","properties":{"certificate":{"description":"The certificate data.","type":"string"},"x509Details":{"$ref":"X509CertificateDetails","description":"[Output only] The certificate details. Used only for X.509 certificates."},"format":{"enumDescriptions":["The format has not been specified. This is an invalid default value and\nmust not be used.","An X.509v3 certificate ([RFC5280](https://www.ietf.org/rfc/rfc5280.txt)),\nencoded in base64, and wrapped by `-----BEGIN CERTIFICATE-----` and\n`-----END CERTIFICATE-----`."],"enum":["UNSPECIFIED_PUBLIC_KEY_CERTIFICATE_FORMAT","X509_CERTIFICATE_PEM"],"description":"The certificate format.","type":"string"}},"id":"PublicKeyCertificate"},"DeviceState":{"description":"The device state, as reported by the device.","type":"object","properties":{"updateTime":{"description":"[Output only] The time at which this state version was updated in Cloud\nIoT Core.","format":"google-datetime","type":"string"},"binaryData":{"type":"string","description":"The device state data.","format":"byte"}},"id":"DeviceState"}},"protocol":"rest","icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"canonicalName":"Cloud Iot","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloudiot":{"description":"Register and manage devices in the Google Cloud IoT service"},"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"}}}},"rootUrl":"https://cloudiot.googleapis.com/","ownerDomain":"google.com","name":"cloudiot","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Cloud IoT API","ownerName":"Google","resources":{"projects":{"resources":{"locations":{"resources":{"registries":{"methods":{"getIamPolicy":{"response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"resource":{"pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}:getIamPolicy","path":"v1/{+resource}:getIamPolicy","id":"cloudiot.projects.locations.registries.getIamPolicy","request":{"$ref":"GetIamPolicyRequest"},"description":"Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset."},"patch":{"httpMethod":"PATCH","parameterOrder":["name"],"response":{"$ref":"DeviceRegistry"},"parameters":{"updateMask":{"description":"Only updates the `device_registry` fields indicated by this mask.\nThe field mask must not be empty, and it must not contain fields that\nare immutable or only set by the server.\nMutable top-level fields: `event_notification_config`, `http_config`,\n`mqtt_config`, and `state_notification_config`.","format":"google-fieldmask","type":"string","location":"query"},"name":{"description":"The resource path name. For example,\n`projects/example-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}","id":"cloudiot.projects.locations.registries.patch","path":"v1/{+name}","description":"Updates a device registry configuration.","request":{"$ref":"DeviceRegistry"}},"get":{"description":"Gets a device registry configuration.","response":{"$ref":"DeviceRegistry"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"location":"path","description":"The name of the device registry. For example,\n`projects/example-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}","path":"v1/{+name}","id":"cloudiot.projects.locations.registries.get"},"testIamPermissions":{"request":{"$ref":"TestIamPermissionsRequest"},"description":"Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.","response":{"$ref":"TestIamPermissionsResponse"},"parameterOrder":["resource"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"resource":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field."}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}:testIamPermissions","path":"v1/{+resource}:testIamPermissions","id":"cloudiot.projects.locations.registries.testIamPermissions"},"unbindDeviceFromGateway":{"request":{"$ref":"UnbindDeviceFromGatewayRequest"},"description":"Deletes the association between the device and the gateway.","response":{"$ref":"UnbindDeviceFromGatewayResponse"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"parent":{"location":"path","description":"The name of the registry. For example,\n`projects/example-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}:unbindDeviceFromGateway","path":"v1/{+parent}:unbindDeviceFromGateway","id":"cloudiot.projects.locations.registries.unbindDeviceFromGateway"},"delete":{"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}","path":"v1/{+name}","id":"cloudiot.projects.locations.registries.delete","description":"Deletes a device registry configuration.","response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"name":{"location":"path","description":"The name of the device registry. For example,\n`projects/example-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$"}}},"list":{"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"pageToken":{"location":"query","description":"The value returned by the last `ListDeviceRegistriesResponse`; indicates\nthat this is a continuation of a prior `ListDeviceRegistries` call and\nthe system should return the next page of data.","type":"string"},"pageSize":{"location":"query","description":"The maximum number of registries to return in the response. If this value\nis zero, the service will select a default size. A call may return fewer\nobjects than requested. A non-empty `next_page_token` in the response\nindicates that more data is available.","format":"int32","type":"integer"},"parent":{"location":"path","description":"The project and cloud region path. For example,\n`projects/example-project/locations/us-central1`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+$"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries","path":"v1/{+parent}/registries","id":"cloudiot.projects.locations.registries.list","description":"Lists device registries.","response":{"$ref":"ListDeviceRegistriesResponse"},"parameterOrder":["parent"],"httpMethod":"GET"},"setIamPolicy":{"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}:setIamPolicy","path":"v1/{+resource}:setIamPolicy","id":"cloudiot.projects.locations.registries.setIamPolicy","description":"Sets the access control policy on the specified resource. Replaces any\nexisting policy.","request":{"$ref":"SetIamPolicyRequest"},"response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"POST","parameters":{"resource":{"description":"REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"]},"create":{"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"DeviceRegistry"},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"parent":{"location":"path","description":"The project and cloud region where this device registry must be created.\nFor example, `projects/example-project/locations/us-central1`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+$"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries","id":"cloudiot.projects.locations.registries.create","path":"v1/{+parent}/registries","request":{"$ref":"DeviceRegistry"},"description":"Creates a device registry that contains devices."},"bindDeviceToGateway":{"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"BindDeviceToGatewayResponse"},"parameters":{"parent":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$","location":"path","description":"The name of the registry. For example,\n`projects/example-project/locations/us-central1/registries/my-registry`."}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}:bindDeviceToGateway","id":"cloudiot.projects.locations.registries.bindDeviceToGateway","path":"v1/{+parent}:bindDeviceToGateway","description":"Associates the device with the gateway.","request":{"$ref":"BindDeviceToGatewayRequest"}}},"resources":{"groups":{"methods":{"setIamPolicy":{"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}:setIamPolicy","path":"v1/{+resource}:setIamPolicy","id":"cloudiot.projects.locations.registries.groups.setIamPolicy","description":"Sets the access control policy on the specified resource. Replaces any\nexisting policy.","request":{"$ref":"SetIamPolicyRequest"},"response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"POST","parameters":{"resource":{"description":"REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"]},"testIamPermissions":{"path":"v1/{+resource}:testIamPermissions","id":"cloudiot.projects.locations.registries.groups.testIamPermissions","request":{"$ref":"TestIamPermissionsRequest"},"description":"Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.","response":{"$ref":"TestIamPermissionsResponse"},"parameterOrder":["resource"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"resource":{"description":"REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+$","location":"path"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}:testIamPermissions"},"bindDeviceToGateway":{"response":{"$ref":"BindDeviceToGatewayResponse"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"parent":{"description":"The name of the registry. For example,\n`projects/example-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+$","location":"path"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}:bindDeviceToGateway","path":"v1/{+parent}:bindDeviceToGateway","id":"cloudiot.projects.locations.registries.groups.bindDeviceToGateway","request":{"$ref":"BindDeviceToGatewayRequest"},"description":"Associates the device with the gateway."},"getIamPolicy":{"description":"Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset.","request":{"$ref":"GetIamPolicyRequest"},"httpMethod":"POST","parameterOrder":["resource"],"response":{"$ref":"Policy"},"parameters":{"resource":{"description":"REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}:getIamPolicy","id":"cloudiot.projects.locations.registries.groups.getIamPolicy","path":"v1/{+resource}:getIamPolicy"},"unbindDeviceFromGateway":{"description":"Deletes the association between the device and the gateway.","request":{"$ref":"UnbindDeviceFromGatewayRequest"},"response":{"$ref":"UnbindDeviceFromGatewayResponse"},"parameterOrder":["parent"],"httpMethod":"POST","parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+$","location":"path","description":"The name of the registry. For example,\n`projects/example-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}:unbindDeviceFromGateway","path":"v1/{+parent}:unbindDeviceFromGateway","id":"cloudiot.projects.locations.registries.groups.unbindDeviceFromGateway"}},"resources":{"devices":{"methods":{"get":{"path":"v1/{+name}","id":"cloudiot.projects.locations.registries.groups.devices.get","description":"Gets details about a device.","response":{"$ref":"Device"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"name":{"description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+/devices/[^/]+$","location":"path"},"fieldMask":{"location":"query","description":"The fields of the `Device` resource to be returned in the response. If the\nfield mask is unset or empty, all fields are returned.","format":"google-fieldmask","type":"string"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}/devices/{devicesId}"},"patch":{"parameters":{"name":{"description":"The resource path name. For example,\n`projects/p1/locations/us-central1/registries/registry0/devices/dev0` or\n`projects/p1/locations/us-central1/registries/registry0/devices/{num_id}`.\nWhen `name` is populated as a response from the service, it always ends\nin the device numeric ID.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+/devices/[^/]+$","location":"path"},"updateMask":{"location":"query","description":"Only updates the `device` fields indicated by this mask.\nThe field mask must not be empty, and it must not contain fields that\nare immutable or only set by the server.\nMutable top-level fields: `credentials`, `blocked`, and `metadata`","format":"google-fieldmask","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}/devices/{devicesId}","path":"v1/{+name}","id":"cloudiot.projects.locations.registries.groups.devices.patch","description":"Updates a device.","request":{"$ref":"Device"},"response":{"$ref":"Device"},"parameterOrder":["name"],"httpMethod":"PATCH"},"list":{"httpMethod":"GET","response":{"$ref":"ListDevicesResponse"},"parameterOrder":["parent"],"parameters":{"gatewayListOptions.gatewayType":{"location":"query","enum":["GATEWAY_TYPE_UNSPECIFIED","GATEWAY","NON_GATEWAY"],"description":"If `GATEWAY` is specified, only gateways are returned. If `NON_GATEWAY`\nis specified, only non-gateway devices are returned. If\n`GATEWAY_TYPE_UNSPECIFIED` is specified, all devices are returned.","type":"string"},"gatewayListOptions.associationsGatewayId":{"type":"string","location":"query","description":"If set, only devices associated with the specified gateway are returned.\nThe gateway ID can be numeric (`num_id`) or the user-defined string\n(`id`). For example, if `123` is specified, only devices bound to the\ngateway with `num_id` 123 are returned."},"fieldMask":{"type":"string","location":"query","description":"The fields of the `Device` resource to be returned in the response. The\nfields `id` and `num_id` are always returned, along with any\nother fields specified.","format":"google-fieldmask"},"pageToken":{"location":"query","description":"The value returned by the last `ListDevicesResponse`; indicates\nthat this is a continuation of a prior `ListDevices` call and\nthe system should return the next page of data.","type":"string"},"pageSize":{"location":"query","description":"The maximum number of devices to return in the response. If this value\nis zero, the service will select a default size. A call may return fewer\nobjects than requested. A non-empty `next_page_token` in the response\nindicates that more data is available.","format":"int32","type":"integer"},"deviceIds":{"type":"string","repeated":true,"location":"query","description":"A list of device string IDs. For example, `['device0', 'device12']`.\nIf empty, this field is ignored. Maximum IDs: 10,000"},"parent":{"description":"The device registry path. Required. For example,\n`projects/my-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+$","location":"path"},"gatewayListOptions.associationsDeviceId":{"description":"If set, returns only the gateways with which the specified device is\nassociated. The device ID can be numeric (`num_id`) or the user-defined\nstring (`id`). For example, if `456` is specified, returns only the\ngateways to which the device with `num_id` 456 is bound.","type":"string","location":"query"},"deviceNumIds":{"repeated":true,"location":"query","description":"A list of device numeric IDs. If empty, this field is ignored. Maximum\nIDs: 10,000.","format":"uint64","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}/devices","id":"cloudiot.projects.locations.registries.groups.devices.list","path":"v1/{+parent}/devices","description":"List devices in a device registry."},"modifyCloudToDeviceConfig":{"path":"v1/{+name}:modifyCloudToDeviceConfig","id":"cloudiot.projects.locations.registries.groups.devices.modifyCloudToDeviceConfig","description":"Modifies the configuration for the device, which is eventually sent from\nthe Cloud IoT Core servers. Returns the modified configuration version and\nits metadata.","request":{"$ref":"ModifyCloudToDeviceConfigRequest"},"response":{"$ref":"DeviceConfig"},"parameterOrder":["name"],"httpMethod":"POST","parameters":{"name":{"location":"path","description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+/devices/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}/devices/{devicesId}:modifyCloudToDeviceConfig"},"sendCommandToDevice":{"request":{"$ref":"SendCommandToDeviceRequest"},"description":"Sends a command to the specified device. In order for a device to be able\nto receive commands, it must:\n1) be connected to Cloud IoT Core using the MQTT protocol, and\n2) be subscribed to the group of MQTT topics specified by\n   /devices/{device-id}/commands/#. This subscription will receive commands\n   at the top-level topic /devices/{device-id}/commands as well as commands\n   for subfolders, like /devices/{device-id}/commands/subfolder.\n   Note that subscribing to specific subfolders is not supported.\nIf the command could not be delivered to the device, this method will\nreturn an error; in particular, if the device is not subscribed, this\nmethod will return FAILED_PRECONDITION. Otherwise, this method will\nreturn OK. If the subscription is QoS 1, at least once delivery will be\nguaranteed; for QoS 0, no acknowledgment will be expected from the device.","response":{"$ref":"SendCommandToDeviceResponse"},"parameterOrder":["name"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"name":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+/devices/[^/]+$","location":"path","description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`."}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}/devices/{devicesId}:sendCommandToDevice","path":"v1/{+name}:sendCommandToDevice","id":"cloudiot.projects.locations.registries.groups.devices.sendCommandToDevice"}},"resources":{"configVersions":{"methods":{"list":{"httpMethod":"GET","response":{"$ref":"ListDeviceConfigVersionsResponse"},"parameterOrder":["name"],"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+/devices/[^/]+$","location":"path","description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string"},"numVersions":{"description":"The number of versions to list. Versions are listed in decreasing order of\nthe version number. The maximum number of versions retained is 10. If this\nvalue is zero, it will return all the versions available.","format":"int32","type":"integer","location":"query"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}/devices/{devicesId}/configVersions","id":"cloudiot.projects.locations.registries.groups.devices.configVersions.list","path":"v1/{+name}/configVersions","description":"Lists the last few versions of the device configuration in descending\norder (i.e.: newest first)."}}},"states":{"methods":{"list":{"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/groups/{groupsId}/devices/{devicesId}/states","id":"cloudiot.projects.locations.registries.groups.devices.states.list","path":"v1/{+name}/states","description":"Lists the last few versions of the device state in descending order (i.e.:\nnewest first).","httpMethod":"GET","response":{"$ref":"ListDeviceStatesResponse"},"parameterOrder":["name"],"parameters":{"name":{"location":"path","description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/groups/[^/]+/devices/[^/]+$"},"numStates":{"type":"integer","location":"query","description":"The number of states to list. States are listed in descending order of\nupdate time. The maximum number of states retained is 10. If this\nvalue is zero, it will return all the states available.","format":"int32"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"]}}}}}}},"devices":{"methods":{"delete":{"description":"Deletes a device.","response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"name":{"location":"path","description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/devices/[^/]+$"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices/{devicesId}","path":"v1/{+name}","id":"cloudiot.projects.locations.registries.devices.delete"},"list":{"description":"List devices in a device registry.","response":{"$ref":"ListDevicesResponse"},"parameterOrder":["parent"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"parent":{"description":"The device registry path. Required. For example,\n`projects/my-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$","location":"path"},"deviceIds":{"description":"A list of device string IDs. For example, `['device0', 'device12']`.\nIf empty, this field is ignored. Maximum IDs: 10,000","type":"string","repeated":true,"location":"query"},"gatewayListOptions.associationsDeviceId":{"location":"query","description":"If set, returns only the gateways with which the specified device is\nassociated. The device ID can be numeric (`num_id`) or the user-defined\nstring (`id`). For example, if `456` is specified, returns only the\ngateways to which the device with `num_id` 456 is bound.","type":"string"},"deviceNumIds":{"location":"query","description":"A list of device numeric IDs. If empty, this field is ignored. Maximum\nIDs: 10,000.","format":"uint64","type":"string","repeated":true},"gatewayListOptions.gatewayType":{"enum":["GATEWAY_TYPE_UNSPECIFIED","GATEWAY","NON_GATEWAY"],"description":"If `GATEWAY` is specified, only gateways are returned. If `NON_GATEWAY`\nis specified, only non-gateway devices are returned. If\n`GATEWAY_TYPE_UNSPECIFIED` is specified, all devices are returned.","type":"string","location":"query"},"gatewayListOptions.associationsGatewayId":{"location":"query","description":"If set, only devices associated with the specified gateway are returned.\nThe gateway ID can be numeric (`num_id`) or the user-defined string\n(`id`). For example, if `123` is specified, only devices bound to the\ngateway with `num_id` 123 are returned.","type":"string"},"fieldMask":{"location":"query","description":"The fields of the `Device` resource to be returned in the response. The\nfields `id` and `num_id` are always returned, along with any\nother fields specified.","format":"google-fieldmask","type":"string"},"pageToken":{"location":"query","description":"The value returned by the last `ListDevicesResponse`; indicates\nthat this is a continuation of a prior `ListDevices` call and\nthe system should return the next page of data.","type":"string"},"pageSize":{"location":"query","description":"The maximum number of devices to return in the response. If this value\nis zero, the service will select a default size. A call may return fewer\nobjects than requested. A non-empty `next_page_token` in the response\nindicates that more data is available.","format":"int32","type":"integer"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices","path":"v1/{+parent}/devices","id":"cloudiot.projects.locations.registries.devices.list"},"create":{"response":{"$ref":"Device"},"parameterOrder":["parent"],"httpMethod":"POST","parameters":{"parent":{"location":"path","description":"The name of the device registry where this device should be created.\nFor example,\n`projects/example-project/locations/us-central1/registries/my-registry`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices","path":"v1/{+parent}/devices","id":"cloudiot.projects.locations.registries.devices.create","description":"Creates a device in a device registry.","request":{"$ref":"Device"}},"modifyCloudToDeviceConfig":{"description":"Modifies the configuration for the device, which is eventually sent from\nthe Cloud IoT Core servers. Returns the modified configuration version and\nits metadata.","request":{"$ref":"ModifyCloudToDeviceConfigRequest"},"response":{"$ref":"DeviceConfig"},"parameterOrder":["name"],"httpMethod":"POST","parameters":{"name":{"description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/devices/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices/{devicesId}:modifyCloudToDeviceConfig","path":"v1/{+name}:modifyCloudToDeviceConfig","id":"cloudiot.projects.locations.registries.devices.modifyCloudToDeviceConfig"},"sendCommandToDevice":{"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices/{devicesId}:sendCommandToDevice","id":"cloudiot.projects.locations.registries.devices.sendCommandToDevice","path":"v1/{+name}:sendCommandToDevice","description":"Sends a command to the specified device. In order for a device to be able\nto receive commands, it must:\n1) be connected to Cloud IoT Core using the MQTT protocol, and\n2) be subscribed to the group of MQTT topics specified by\n   /devices/{device-id}/commands/#. This subscription will receive commands\n   at the top-level topic /devices/{device-id}/commands as well as commands\n   for subfolders, like /devices/{device-id}/commands/subfolder.\n   Note that subscribing to specific subfolders is not supported.\nIf the command could not be delivered to the device, this method will\nreturn an error; in particular, if the device is not subscribed, this\nmethod will return FAILED_PRECONDITION. Otherwise, this method will\nreturn OK. If the subscription is QoS 1, at least once delivery will be\nguaranteed; for QoS 0, no acknowledgment will be expected from the device.","request":{"$ref":"SendCommandToDeviceRequest"},"httpMethod":"POST","parameterOrder":["name"],"response":{"$ref":"SendCommandToDeviceResponse"},"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/devices/[^/]+$","location":"path","description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"]},"get":{"response":{"$ref":"Device"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/devices/[^/]+$","location":"path","description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string"},"fieldMask":{"location":"query","description":"The fields of the `Device` resource to be returned in the response. If the\nfield mask is unset or empty, all fields are returned.","format":"google-fieldmask","type":"string"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices/{devicesId}","path":"v1/{+name}","id":"cloudiot.projects.locations.registries.devices.get","description":"Gets details about a device."},"patch":{"response":{"$ref":"Device"},"parameterOrder":["name"],"httpMethod":"PATCH","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"updateMask":{"location":"query","description":"Only updates the `device` fields indicated by this mask.\nThe field mask must not be empty, and it must not contain fields that\nare immutable or only set by the server.\nMutable top-level fields: `credentials`, `blocked`, and `metadata`","format":"google-fieldmask","type":"string"},"name":{"description":"The resource path name. For example,\n`projects/p1/locations/us-central1/registries/registry0/devices/dev0` or\n`projects/p1/locations/us-central1/registries/registry0/devices/{num_id}`.\nWhen `name` is populated as a response from the service, it always ends\nin the device numeric ID.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/devices/[^/]+$","location":"path"}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices/{devicesId}","path":"v1/{+name}","id":"cloudiot.projects.locations.registries.devices.patch","request":{"$ref":"Device"},"description":"Updates a device."}},"resources":{"configVersions":{"methods":{"list":{"httpMethod":"GET","parameterOrder":["name"],"response":{"$ref":"ListDeviceConfigVersionsResponse"},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"parameters":{"numVersions":{"type":"integer","location":"query","description":"The number of versions to list. Versions are listed in decreasing order of\nthe version number. The maximum number of versions retained is 10. If this\nvalue is zero, it will return all the versions available.","format":"int32"},"name":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/devices/[^/]+$","location":"path","description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`."}},"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices/{devicesId}/configVersions","id":"cloudiot.projects.locations.registries.devices.configVersions.list","path":"v1/{+name}/configVersions","description":"Lists the last few versions of the device configuration in descending\norder (i.e.: newest first)."}}},"states":{"methods":{"list":{"response":{"$ref":"ListDeviceStatesResponse"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"description":"The name of the device. For example,\n`projects/p0/locations/us-central1/registries/registry0/devices/device0` or\n`projects/p0/locations/us-central1/registries/registry0/devices/{num_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/registries/[^/]+/devices/[^/]+$","location":"path"},"numStates":{"description":"The number of states to list. States are listed in descending order of\nupdate time. The maximum number of states retained is 10. If this\nvalue is zero, it will return all the states available.","format":"int32","type":"integer","location":"query"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloudiot"],"flatPath":"v1/projects/{projectsId}/locations/{locationsId}/registries/{registriesId}/devices/{devicesId}/states","path":"v1/{+name}/states","id":"cloudiot.projects.locations.registries.devices.states.list","description":"Lists the last few versions of the device state in descending order (i.e.:\nnewest first)."}}}}}}}}}}}},"parameters":{"upload_protocol":{"description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string","location":"query"},"prettyPrint":{"description":"Returns response with indentations and line breaks.","type":"boolean","default":"true","location":"query"},"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"uploadType":{"description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string","location":"query"},"fields":{"description":"Selector specifying which fields to include in a partial response.","type":"string","location":"query"},"$.xgafv":{"enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"],"description":"V1 error format.","type":"string"},"oauth_token":{"location":"query","description":"OAuth 2.0 token for the current user.","type":"string"},"callback":{"description":"JSONP","type":"string","location":"query"},"alt":{"enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json"},"key":{"location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string"},"access_token":{"type":"string","location":"query","description":"OAuth access token."}},"version":"v1","baseUrl":"https://cloudiot.googleapis.com/","servicePath":"","description":"Registers and manages IoT (Internet of Things) devices that connect to the Google Cloud Platform.\n","kind":"discovery#restDescription","basePath":"","id":"cloudiot:v1","documentationLink":"https://cloud.google.com/iot","revision":"20181204"};